#
# spec file for package java-11-openjdk
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?aarch64:%global aarch64 aarch64 arm64 armv8}
%{!?arm6:%global arm6 armv3l armv4b armv4l armv4tl armv5b armv5l armv5teb armv5tel armv5tejl armv6l armv6hl}
%global jit_arches %{ix86} x86_64 ppc64 ppc64le %{aarch64} %{arm} s390x
%global debug 0
%global add_back_javaee_modules 1
%global buildoutputdir build
# Convert an absolute path to a relative path.  Each symbolic link is
# specified relative to the directory in which it is installed so that
# it will resolve properly within chrooted installations.
%global script 'use File::Spec; print File::Spec->abs2rel($ARGV[0], $ARGV[1])'
%global abs2rel perl -e %{script}
%global syslibdir       %{_libdir}
%global archname        %{name}
# Standard JPackage naming and versioning defines.
%global featurever      11
%global interimver      0
%global updatever       7
%global patchver        0
%global datever         2020-04-14
%global buildver        10
%global hg_project      jdk-updates
%global hg_repository   jdk11u
%global hg_revision     44ce940b344b
%global icedtea_sound_version 1.0.1
# JavaEE modules
%global java_atk_wrapper_version 0.33.2
%global java_activation_repository activation
%global java_activation_tag JAF-1_2_0
%global java_xml_bind_repository jaxb-spec
%global java_xml_bind_tag 2.4.0
%global java_xml_soap_repository javax.xml.soap
%global java_xml_soap_tag 1.4.0
%global java_annotation_repository javax.annotation
%global java_annotation_tag 1.3.2
%global java_xml_ws_repository jax-ws-spec
%global java_xml_ws_tag 2.4.0
%global com_sun_xml_fastinfoset_repository metro-fi
%global com_sun_xml_fastinfoset_tag 1.2.15-RELEASE
%global org_jvnet_staxex_repository metro-stax-ex
%global org_jvnet_staxex_tag 1.8
%global com_sun_istack_runtime_repository jaxb-istack-commons
%global com_sun_istack_runtime_tag 3.0.7-RELEASE
%global jaxb_ri_repository jaxb-v2
%global jaxb_ri_tag 2.3.1
# priority must be 6 digits in total
%global priority        2105
%global javaver         %{featurever}
# Standard JPackage directories and symbolic links.
%global sdklnk          java-%{javaver}-openjdk
%global archname        %{sdklnk}
%global jrelnk          jre-%{javaver}-openjdk
%global jrebindir       %{_jvmdir}/%{jrelnk}/bin
%global sdkdir          %{sdklnk}-%{javaver}
%global sdkbindir       %{_jvmdir}/%{sdklnk}/bin
# Prevent brp-java-repack-jars from being run.
%global __jar_repack 0
# cacert symlink
%global cacerts  %{_jvmdir}/%{sdkdir}/lib/security/cacerts
# real file made by update-ca-certificates
%global javacacerts %{_var}/lib/ca-certificates/java-cacerts
%global bootcycle 1
# turn zero on non jit arches by default
%ifnarch %{jit_arches}
%global _with_zero 1
%endif
%if %{debug}
%global debugbuild slowdebug
%else
%global debugbuild release
%endif
%if %{bootcycle}
%global imagesdir bootcycle-build/images
%global imagestarget bootcycle-images all
%else
%global imagesdir images
%global imagestarget all
%endif
# bnc#542545
# 32-bit versus 64-bit specific provides:
%ifarch %{ix86} ppc s390
%global bits 32
%endif
%ifarch x86_64 ia64 s390x
%global bits 64
%endif
%if 0%{?__isa_bits}
%global bits %{__isa_bits}
%endif
# Turn on/off some features depending on openSUSE version
%if 0%{?suse_version} > 1320
%global with_system_pcsc 1
%else
%global with_system_pcsc 0
%endif
%global with_pulseaudio 1
%bcond_with zero
%bcond_with aot
%if ! %{with zero}
%ifarch x86_64 %{aarch64}
%global _with_aot 1
%endif
%endif
%if ! %{with zero}
%global with_systemtap 1
%else
%global with_systemtap 0
%endif
%if %{with_systemtap}
%global tapsetroot      %{_datadir}/systemtap
%global tapsetdir %{tapsetroot}/tapset/%{_build_cpu}
%endif
%if %{with_systemtap}
# Where to install systemtap tapset (links)
# We would like these to be in a package specific subdir,
# but currently systemtap doesn't support that, so we have to
# use the root tapset dir for now. To distinquish between 64
# and 32 bit architectures we place the tapsets under the arch
# specific dir (note that systemtap will only pickup the tapset
# for the primary arch for now). Systemtap uses the machine name
# aka build_cpu as architecture specific directory name.
%global tapsetroot %{_datadir}/systemtap
%global tapsetdir %{tapsetroot}/tapset/%{_build_cpu}
%endif
Name:           java-%{featurever}-openjdk
Version:        %{featurever}.%{interimver}.%{updatever}.%{patchver}
Release:        lp152.1.2
Summary:        OpenJDK %{featurever} Runtime Environment
License:        Apache-1.1 AND Apache-2.0 AND GPL-1.0-or-later AND GPL-2.0-only AND GPL-2.0-only WITH Classpath-exception-2.0 AND LGPL-2.0-only AND MPL-1.0 AND MPL-1.1 AND SUSE-Public-Domain AND W3C
Group:          Development/Languages/Java
URL:            https://openjdk.java.net/
# Sources from upstream OpenJDK project.
Source0:        http://hg.openjdk.java.net/%{hg_project}/%{hg_repository}/archive/%{hg_revision}.tar.bz2
# Accessibility support
Source8:        ftp://ftp.gnome.org/pub/GNOME/sources/java-atk-wrapper/0.33/java-atk-wrapper-%{java_atk_wrapper_version}.tar.xz
# Pulseaudio support
Source9:        http://icedtea.classpath.org/download/source/icedtea-sound-%{icedtea_sound_version}.tar.xz
# Systemtap tapsets. Zipped up to keep it small.
Source10:       systemtap-tapset.tar.xz
# Desktop files. Adapted from IcedTea.
Source11:       jconsole.desktop.in
# nss configuration file
Source13:       nss.cfg
# Ensure we aren't using the limited crypto policy
Source14:       TestCryptoLevel.java
# Ensure ECDSA is working
Source15:       TestECDSA.java
# https://codeload.github.com/javaee/%{java_activation_repository}/tar.gz/%{java_activation_tag}
Source20:       %{java_activation_repository}-%{java_activation_tag}.tar.gz
# https://codeload.github.com/javaee/%{java_xml_bind_repository}/tar.gz/%{java_xml_bind_tag}
Source21:       %{java_xml_bind_repository}-%{java_xml_bind_tag}.tar.gz
# https://codeload.github.com/javaee/%{java_xml_soap_repository}/tar.gz/%{java_xml_soap_tag}
Source22:       %{java_xml_soap_repository}-%{java_xml_soap_tag}.tar.gz
# https://codeload.github.com/javaee/%{java_annotation_repository}/tar.gz/%{java_annotation_tag}
Source23:       %{java_annotation_repository}-%{java_annotation_tag}.tar.gz
# https://codeload.github.com/javaee/%{java_xml_ws_repository}/tar.gz/%{java_xml_ws_tag}
Source24:       %{java_xml_ws_repository}-%{java_xml_ws_tag}.tar.gz
# https://codeload.github.com/javaee/%{com_sun_xml_fastinfoset_repository}/tar.gz/%{com_sun_xml_fastinfoset_tag}
Source25:       %{com_sun_xml_fastinfoset_repository}-%{com_sun_xml_fastinfoset_tag}.tar.gz
# https://codeload.github.com/javaee/%{org_jvnet_staxex_repository}/tar.gz/%{org_jvnet_staxex_tag}
Source26:       %{org_jvnet_staxex_repository}-%{org_jvnet_staxex_tag}.tar.gz
# https://codeload.github.com/javaee/%{com_sun_istack_runtime_repository}/tar.gz/%{com_sun_istack_runtime_tag}
Source27:       %{com_sun_istack_runtime_repository}-%{com_sun_istack_runtime_tag}.tar.gz
# https://codeload.github.com/javaee/%{jaxb_ri_repository}/tar.gz/%{jaxb_ri_tag}
Source28:       %{jaxb_ri_repository}-%{jaxb_ri_tag}.tar.gz
# Fresh config.guess and config.sub files
# wget -O config.guess 'http://git.savannah.gnu.org/gitweb/?p=config.git;a=blob_plain;f=config.guess;hb=HEAD'
Source100:      config.guess
# wget -O config.sub 'http://git.savannah.gnu.org/gitweb/?p=config.git;a=blob_plain;f=config.sub;hb=HEAD'
Source101:      config.sub
# RPM/distribution specific patches
Patch1:         icedtea-sound-1.0.1-jdk9.patch
Patch2:         icedtea-sound-soundproperties.patch
# Restrict access to java-atk-wrapper classes
Patch3:         java-atk-wrapper-security.patch
# RHBZ 808293
Patch4:         PStack-808293.patch
# Allow multiple initialization of PKCS11 libraries
Patch5:         multiple-pkcs11-library-init.patch
# Fix instantiation of VM on ZERO
Patch8:         zero-ranges.patch
# From icedtea: Increase default memory limits
Patch10:        memory-limits.patch
# Fix use of unintialized memory in adlc parser
Patch12:        adlc-parser.patch
# Fix: implicit-pointer-decl
Patch13:        implicit-pointer-decl.patch
#
Patch15:        system-pcsclite.patch
Patch16:        missing-return.patch
#
Patch20:        loadAssistiveTechnologies.patch
#
Patch30:        JDK-8208602.patch
# 8228407: JVM crashes with shared archive file mismatch
# Summary: Stop processing other header fields if initial header check has failed.
Patch31:        JDK-8228407.patch
Patch32:        gcc-fno-common-fix.patch
#
# OpenJDK specific patches
#
Patch100:       s390-java-opts.patch
Patch101:       s390-size_t.patch
#
Patch200:       ppc_stack_overflow_fix.patch
Patch201:       fix_armv6_build.patch
#
Patch302:       disable-doclint-by-default.patch
Patch303:       alternative-tzdb_dat.patch
#
Patch400:       jaw-misc.patch
Patch401:       jaw-jdk10.patch
Patch402:       jaw-nogtk.patch
#
Patch500:       activation-module.patch
Patch501:       annotation-module.patch
BuildRequires:  alsa-lib-devel
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bc
BuildRequires:  binutils
BuildRequires:  cups-devel
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  fontconfig-devel
BuildRequires:  freetype2-devel
BuildRequires:  gcc-c++
BuildRequires:  giflib-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  java-ca-certificates
BuildRequires:  libX11-devel
BuildRequires:  libXi-devel
BuildRequires:  libXinerama-devel
BuildRequires:  libXrandr-devel
BuildRequires:  libXrender-devel
BuildRequires:  libXt-devel
BuildRequires:  libXtst-devel
BuildRequires:  libjpeg-devel
BuildRequires:  liblcms2-devel
BuildRequires:  libpng-devel
BuildRequires:  libtool
BuildRequires:  libxslt
BuildRequires:  pkgconfig
BuildRequires:  unzip
BuildRequires:  update-desktop-files
BuildRequires:  xorg-x11-proto-devel
BuildRequires:  xprop
BuildRequires:  zip
BuildRequires:  pkgconfig(atk) >= 2.14.0
BuildRequires:  pkgconfig(atk-bridge-2.0)
BuildRequires:  pkgconfig(atspi-2) >= 2.14.0
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(glib-2.0) >= 2.32.0
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gthread-2.0)
# Requires rest of java
Requires:       %{name}-headless = %{version}-%{release}
Requires:       fontconfig
# mozilla-nss has to be installed to prevent
# java.security.ProviderException: Could not initialize NSS
# ...
# java.io.FileNotFoundException: /usr/lib64/libnss3.so
#was bnc#634793
Requires:       mozilla-nss
Requires(post): file
# Standard JPackage base provides.
Provides:       java = %{javaver}
Provides:       java-%{javaver} = %{version}-%{release}
Provides:       java-openjdk = %{version}-%{release}
Provides:       jre = %{javaver}
Provides:       jre-%{javaver} = %{version}-%{release}
Provides:       jre-%{javaver}-openjdk = %{version}-%{release}
Provides:       jre-openjdk = %{version}-%{release}
# Standard JPackage extensions provides.
Provides:       java-fonts = %{version}
# Required at least by fop
Provides:       java-%{bits} = %{javaver}
Provides:       java-%{javaver}-%{bits}
Provides:       java-10-openjdk = %{version}-%{release}
Provides:       java-openjdk-%{bits} = %{version}-%{release}
Provides:       jre-%{bits} = %{javaver}
Provides:       jre-%{javaver}-%{bits}
Provides:       jre-%{javaver}-openjdk-%{bits} = %{version}-%{release}
Provides:       jre-openjdk-%{bits} = %{version}-%{release}
Provides:       jre1.10.x
Provides:       jre1.3.x
Provides:       jre1.4.x
Provides:       jre1.5.x
Provides:       jre1.6.x
Provides:       jre1.7.x
Provides:       jre1.8.x
Provides:       jre1.9.x
Obsoletes:      java-10-openjdk < %{version}-%{release}
%if %{bootcycle}
BuildRequires:  java-devel >= 10
BuildConflicts: java-devel >= 12
%else
BuildRequires:  %{name}-devel
%endif
# Zero-assembler build requirement.
%if %{with zero}
BuildRequires:  libffi-devel
%endif
%if %{with_systemtap}
BuildRequires:  systemtap-sdt-devel
%endif
# pulse audio requirements
%if %{with_pulseaudio}
BuildRequires:  libpulse-devel >= 0.9.11
BuildRequires:  pulseaudio >= 0.9.11
%endif
%if %{with_system_pcsc}
BuildRequires:  pcsc-lite-devel
%endif
%if %{with aot}
BuildRequires:  libelf-devel
%endif

%description
The OpenJDK %{featurever} runtime environment.

%package headless
Summary:        OpenJDK %{featurever} Runtime Environment
Group:          Development/Languages/Java
Requires:       jpackage-utils
Requires(post): java-ca-certificates
# Post requires update-alternatives to install tool update-alternatives.
Requires(post): update-alternatives
# Postun requires update-alternatives to uninstall tool update-alternatives.
Requires(postun): update-alternatives
Recommends:     tzdata-java8
# Standard JPackage base provides.
Provides:       java-%{javaver}-headless = %{version}-%{release}
Provides:       java-headless = %{javaver}
Provides:       java-openjdk-headless = %{version}-%{release}
Provides:       jre-%{javaver}-headless = %{version}-%{release}
Provides:       jre-%{javaver}-openjdk-headless = %{version}-%{release}
Provides:       jre-headless = %{javaver}
Provides:       jre-openjdk-headless = %{version}-%{release}
# Standard JPackage extensions provides.
Provides:       jaas = %{version}
Provides:       java-10-openjdk-headless = %{version}-%{release}
Provides:       java-sasl = %{version}
Provides:       jce = %{version}
Provides:       jdbc-stdext = 4.3
Provides:       jndi = %{version}
Provides:       jndi-cos = %{version}
Provides:       jndi-dns = %{version}
Provides:       jndi-ldap = %{version}
Provides:       jndi-rmi = %{version}
Provides:       jsse = %{version}
Obsoletes:      java-10-openjdk-headless < %{version}-%{release}

%description headless
The OpenJDK %{featurever} runtime environment without audio and video support.

%package devel
Summary:        OpenJDK %{featurever} Development Environment
# Require base package.
Group:          Development/Languages/Java
Requires:       %{name} = %{version}-%{release}
# Post requires update-alternatives to install tool update-alternatives.
Requires(post): update-alternatives
# Postun requires update-alternatives to uninstall tool update-alternatives.
Requires(postun): update-alternatives
# Standard JPackage devel provides.
Provides:       java-%{javaver}-devel = %{version}
Provides:       java-10-openjdk-devel = %{version}-%{release}
Provides:       java-devel = %{javaver}
Provides:       java-devel-openjdk = %{version}
Provides:       java-sdk = %{javaver}
Provides:       java-sdk-%{javaver} = %{version}
Provides:       java-sdk-%{javaver}-openjdk = %{version}
Provides:       java-sdk-openjdk = %{version}
Obsoletes:      java-10-openjdk-devel < %{version}-%{release}

%description devel
The OpenJDK %{featurever} development tools.

%package jmods
Summary:        JMods for OpenJDK %{featurever}
Group:          Development/Languages/Java
Requires:       %{name}-devel = %{version}-%{release}
Provides:       java-10-openjdk-jmods = %{version}-%{release}
Obsoletes:      java-10-openjdk-jmods < %{version}-%{release}

%description jmods
The JMods for OpenJDK %{featurever}.

%package demo
Summary:        OpenJDK %{featurever} Demos
Group:          Development/Languages/Java
Requires:       %{name} = %{version}-%{release}
Provides:       java-10-openjdk-demo = %{version}-%{release}
Obsoletes:      java-10-openjdk-demo < %{version}-%{release}

%description demo
The OpenJDK %{featurever} demos.

%package src
Summary:        OpenJDK %{featurever} Source Bundle
Group:          Development/Languages/Java
Requires:       %{name} = %{version}-%{release}
Provides:       java-10-openjdk-src = %{version}-%{release}
Obsoletes:      java-10-openjdk-src < %{version}-%{release}

%description src
The OpenJDK %{featurever} source bundle.

%package javadoc
Summary:        OpenJDK %{featurever} API Documentation
Group:          Development/Languages/Java
Requires:       jpackage-utils
# Post requires update-alternatives to install javadoc alternative.
Requires(post): update-alternatives
# Postun requires update-alternatives to uninstall javadoc alternative.
Requires(postun): update-alternatives
# Standard JPackage javadoc provides.
Provides:       java-%{javaver}-javadoc = %{version}-%{release}
Provides:       java-10-openjdk-javadoc = %{version}-%{release}
Provides:       java-javadoc = %{version}-%{release}
Obsoletes:      java-10-openjdk-javadoc < %{version}-%{release}
BuildArch:      noarch

%description javadoc
The OpenJDK %{featurever} API documentation.

%package accessibility
Summary:        OpenJDK %{featurever} accessibility connector
Group:          Development/Languages/Java
Requires:       %{name} = %{version}-%{release}
Requires:       xprop
Provides:       java-10-openjdk-accessibility = %{version}-%{release}
Obsoletes:      java-10-openjdk-accessibility < %{version}-%{release}

%description accessibility
Enables accessibility support in OpenJDK %{featurever} by using java-atk-wrapper. This allows
compatible at-spi2 based accessibility programs to work for AWT and Swing-based
programs.

Please note, the java-atk-wrapper is still in beta, and OpenJDK itself is still
being tuned to be working with accessibility features. There are known issues
with accessibility on, so please do not install this package unless you really
need to.

%prep
%setup -q -n %{hg_repository}-%{hg_revision}
%setup -q -D -n %{hg_repository}-%{hg_revision} -T -a 8
%setup -q -D -n %{hg_repository}-%{hg_revision} -T -a 9
%setup -q -D -n %{hg_repository}-%{hg_revision} -T -a 20
%setup -q -D -n %{hg_repository}-%{hg_revision} -T -a 21
%setup -q -D -n %{hg_repository}-%{hg_revision} -T -a 22
%setup -q -D -n %{hg_repository}-%{hg_revision} -T -a 23
%setup -q -D -n %{hg_repository}-%{hg_revision} -T -a 24
%setup -q -D -n %{hg_repository}-%{hg_revision} -T -a 25
%setup -q -D -n %{hg_repository}-%{hg_revision} -T -a 26
%setup -q -D -n %{hg_repository}-%{hg_revision} -T -a 27
%setup -q -D -n %{hg_repository}-%{hg_revision} -T -a 28

# Replace config.sub and config.guess with fresh versions
cp %{SOURCE100} make/autoconf/build-aux/
cp %{SOURCE101} make/autoconf/build-aux/

# Remove libraries that are linked
rm -rvf src/java.base/share/native/libzip/zlib-*
find src/java.desktop/share/native/libjavajpeg ! -name imageioJPEG.c ! -name jpegdecoder.c -type f -delete
rm -rvf src/java.desktop/share/native/libsplashscreen/libpng
rm -rvf src/java.desktop/share/native/libsplashscreen/giflib
rm -rvf src/java.desktop/share/native/liblcms/cms*
rm -rvf src/java.desktop/share/native/liblcms/lcms2*

%patch1
%if %{with_pulseaudio}
%patch2 -p1
%endif

%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch8 -p1
%patch10 -p1
%patch12 -p1
%patch13 -p1

%if %{with_system_pcsc}
%patch15 -p1
%endif

%patch16 -p1

%patch20 -p1

%patch30 -p1
%patch31 -p1
%patch32 -p1

# s390 build fixes

%ifarch s390
%patch100 -p1
%patch101 -p1
%endif

%patch200 -p1

%ifarch %{arm6}
%patch201
%endif

%patch302 -p1
%patch303 -p1

%patch400
%patch401
%patch402

%patch500
%patch501

# Extract systemtap tapsets

%if %{with_systemtap}

tar -x -I xz -f %{SOURCE10}

for file in tapset/*.in; do

    OUTPUT_FILE=`echo $file | sed -e s:\.in$::g`
    sed -e s:@ABS_SERVER_LIBJVM_SO@:%{_jvmdir}/%{sdkdir}/lib/server/libjvm.so:g $file > $file.1
# TODO find out which architectures other than ix86 have a client vm

%ifarch %{ix86}
    sed -e s:@ABS_CLIENT_LIBJVM_SO@:%{_jvmdir}/%{sdkdir}/lib/client/libjvm.so:g $file.1 > $OUTPUT_FILE
%else
    sed -e '/@ABS_CLIENT_LIBJVM_SO@/d' $file.1 > $OUTPUT_FILE
%endif
    sed -i -e s:@ABS_JAVA_HOME_DIR@:%{_jvmdir}/%{sdkdir}:g $OUTPUT_FILE

done

%endif

# Prepare desktop files
for file in %{SOURCE11} ; do
    OUTPUT_FILE=`basename $file | sed -e s:\.in$::g`
    sed -e s:@JAVA_HOME@:%{_jvmdir}/%{sdkdir}:g $file > $OUTPUT_FILE
    sed -i -e s:@VERSION@:%{javaver}:g $OUTPUT_FILE
done

%build

%ifarch s390x sparc64 alpha ppc64 ppc64le %{aarch64}
export ARCH_DATA_MODEL=64
%endif

%ifarch alpha
export CFLAGS="$CFLAGS -mieee"
%endif

EXTRA_CFLAGS="-Wno-error"
EXTRA_CPP_FLAGS="-Wno-error"

%ifarch ppc64 ppc64le ppc
EXTRA_CFLAGS="$EXTRA_CFLAGS -fno-strict-aliasing"
%endif

%if 0%{?suse_version} >= 1330
EXTRA_CFLAGS="$EXTRA_CFLAGS -Wno-error -std=gnu++98 -fno-delete-null-pointer-checks -fno-lifetime-dse -fpermissive"
EXTRA_CPP_FLAGS="$EXTRA_CPP_FLAGS -Wno-error -std=gnu++98 -fno-delete-null-pointer-checks -fno-lifetime-dse"
%endif

mkdir -p %{buildoutputdir}

pushd %{buildoutputdir}

bash ../configure \
    --with-version-feature=%{featurever} \
    --with-version-interim=%{interimver} \
    --with-version-update=%{updatever} \
    --with-version-patch=%{patchver} \
    --with-version-date=%{datever} \
    --with-version-build=%{buildver} \
    --with-version-pre="" \
    --with-version-opt="suse-%{release}-%{_arch}" \
    --disable-warnings-as-errors \
%if %{with zero}
    --with-jvm-variants=zero \
%else
%ifarch %{arm6}
    --with-jvm-variants=client \
%endif
%endif
%if %{with aot}
    --enable-aot \
%else
    --disable-aot \
%endif
    --disable-keep-packaged-modules \
    --with-debug-level=%{debugbuild} \
    --with-zlib=system \
    --with-libjpeg=system \
    --with-giflib=system \
    --with-libpng=system \
    --with-lcms=system \
%if %{with_system_pcsc}
    --with-pcsclite=system \
%endif
    --with-stdc++lib=dynamic \
%ifarch s390
    --with-boot-jdk-jvmargs="-Xms256M -Xmx768M" \
%endif
%ifarch x86_64
    --with-jvm-features=zgc \
%endif
    --with-extra-cxxflags="$EXTRA_CPP_FLAGS" \
    --with-extra-cflags="$EXTRA_CFLAGS" \
    --disable-javac-server

# The combination of FULL_DEBUG_SYMBOLS=0 and ALT_OBJCOPY=/does_not_exist
# disables FDS for all build configs and reverts to pre-FDS make %{?_smp_mflags} logic.
# STRIP_POLICY=none says don't do any stripping. DEBUG_BINARIES=true says
# ignore all the other logic about which debug options and just do '-g'.

make \
    JAVAC_FLAGS=-g \
    LOG=trace \
    DEBUG_BINARIES=true \
    STRIP_POLICY=no_strip \
    POST_STRIP_CMD="" \
    WARNINGS_ARE_ERRORS="-Wno-error" \
    CFLAGS_WARNINGS_ARE_ERRORS="-Wno-error" \
    %{imagestarget} docs

# remove redundant *diz and *debuginfo files
find %{imagesdir}/jdk -iname '*.diz' -exec rm {} \;
find %{imagesdir}/jdk -iname '*.debuginfo' -exec rm {} \;

popd >& /dev/null

export JAVA_HOME=$(pwd)/%{buildoutputdir}/%{imagesdir}/jdk

# Copy tz.properties
echo "sun.zoneinfo.dir=%{_datadir}/javazi" >> $JAVA_HOME/conf/tz.properties

%if %{with_pulseaudio}
# Build the pulseaudio plugin
pushd icedtea-sound-%{icedtea_sound_version}
autoreconf --force --install
%configure \
    --with-jdk-home=$JAVA_HOME \
    --disable-docs
make %{?_smp_mflags}
cp icedtea-sound.jar $JAVA_HOME/../jmods/
cp build/native/libicedtea-sound.so $JAVA_HOME/lib/
popd
# Merge the icedtea-sound into the JDK
source $JAVA_HOME/release; export MODULES
$JAVA_HOME/bin/jlink --module-path $JAVA_HOME/../jmods --add-modules "icedtea.sound,${MODULES//\ /,}" --output $JAVA_HOME/../newjdk
cp -rf $JAVA_HOME/../newjdk/* $JAVA_HOME/
rm -rf $JAVA_HOME/../newjdk
%endif

# Build the accessibility plugin
pushd java-atk-wrapper-%{java_atk_wrapper_version}
autoreconf --force --install
rm wrapper/org/GNOME/Accessibility/AtkWrapper.java
%configure \
    --without-jdk-auto-detect \
    JDK_SRC=$JAVA_HOME
rm wrapper/org/GNOME/Accessibility/AtkWrapper.java
make %{?_smp_mflags}
cp wrapper/java-atk-wrapper.jar $JAVA_HOME/../jmods/
cp jni/src/.libs/libatk-wrapper.so $JAVA_HOME/lib/
popd
# Merge the java-atk-wrapper into the JDK
source $JAVA_HOME/release; export MODULES
$JAVA_HOME/bin/jlink --module-path $JAVA_HOME/../jmods --add-modules "atk.wrapper,${MODULES//\ /,}" --output $JAVA_HOME/../newjdk
cp -rf $JAVA_HOME/../newjdk/* $JAVA_HOME/
rm -rf $JAVA_HOME/../newjdk

%if %{add_back_javaee_modules}

# Merge back some Java EE modules removed in OpenJDK 11 by JEP 320

# Build the java.activation framework

pushd %{java_activation_repository}-%{java_activation_tag}
if [ -e build ]; then rm -rf build; fi
mkdir -p build
$JAVA_HOME/bin/javac -d build `find activation -name \*.java | xargs`
$JAVA_HOME/bin/jmod create --do-not-resolve-by-default --class-path=build:activation/src/main/resources $JAVA_HOME/../jmods/java.activation.jmod
popd
# Merge the java activation framework into the JDK
source $JAVA_HOME/release; export MODULES
$JAVA_HOME/bin/jlink --module-path $JAVA_HOME/../jmods --add-modules "java.activation,${MODULES//\ /,}" --output $JAVA_HOME/../newjdk
cp -rf $JAVA_HOME/../newjdk/* $JAVA_HOME/
rm -rf $JAVA_HOME/../newjdk

# Build the java.xml.bind

pushd %{java_xml_bind_repository}-%{java_xml_bind_tag}
if [ -e build ]; then rm -rf build; fi
mkdir -p build
$JAVA_HOME/bin/javac -d build `find jaxb-api/src/main/java/ -name \*.java | xargs`
$JAVA_HOME/bin/jmod create --do-not-resolve-by-default --class-path=build:jaxb-api/src/main/resources $JAVA_HOME/../jmods/java.xml.bind.jmod
popd
# Merge java.xml.bind into the JDK
source $JAVA_HOME/release; export MODULES
$JAVA_HOME/bin/jlink --module-path $JAVA_HOME/../jmods --add-modules "java.xml.bind,${MODULES//\ /,}" --output $JAVA_HOME/../newjdk
cp -rf $JAVA_HOME/../newjdk/* $JAVA_HOME/
rm -rf $JAVA_HOME/../newjdk

# Build the java.xml.soap

pushd %{java_xml_soap_repository}-%{java_xml_soap_tag}
if [ -e build ]; then rm -rf build; fi
mkdir -p build
$JAVA_HOME/bin/javac -d build `find src/main/ -name \*.java | xargs`
$JAVA_HOME/bin/jmod create --do-not-resolve-by-default --class-path=build $JAVA_HOME/../jmods/java.xml.soap.jmod
popd
# Merge java.xml.soap into the JDK
source $JAVA_HOME/release; export MODULES
$JAVA_HOME/bin/jlink --module-path $JAVA_HOME/../jmods --add-modules "java.xml.soap,${MODULES//\ /,}" --output $JAVA_HOME/../newjdk
cp -rf $JAVA_HOME/../newjdk/* $JAVA_HOME/
rm -rf $JAVA_HOME/../newjdk

# Build the java.annotation

pushd %{java_annotation_repository}-%{java_annotation_tag}
if [ -e build ]; then rm -rf build; fi
mkdir -p build
$JAVA_HOME/bin/javac -d build `find src/main/java -name \*.java | xargs`
$JAVA_HOME/bin/jmod create --do-not-resolve-by-default --class-path=build $JAVA_HOME/../jmods/java.annotation.jmod
popd
# Merge java.annotation into the JDK
source $JAVA_HOME/release; export MODULES
$JAVA_HOME/bin/jlink --module-path $JAVA_HOME/../jmods --add-modules "java.annotation,${MODULES//\ /,}" --output $JAVA_HOME/../newjdk
cp -rf $JAVA_HOME/../newjdk/* $JAVA_HOME/
rm -rf $JAVA_HOME/../newjdk

# Build the java.xml.ws

pushd %{java_xml_ws_repository}-%{java_xml_ws_tag}
if [ -e build ]; then rm -rf build; fi
mkdir -p build
$JAVA_HOME/bin/javac -d build `find api/src/main -name \*.java | xargs`
$JAVA_HOME/bin/jmod create --do-not-resolve-by-default --class-path=build:api/src/main/resources $JAVA_HOME/../jmods/java.xml.ws.jmod
popd
# Merge java.xml.ws into the JDK
source $JAVA_HOME/release; export MODULES
$JAVA_HOME/bin/jlink --module-path $JAVA_HOME/../jmods --add-modules "java.xml.ws,${MODULES//\ /,}" --output $JAVA_HOME/../newjdk
cp -rf $JAVA_HOME/../newjdk/* $JAVA_HOME/
rm -rf $JAVA_HOME/../newjdk

# Build the com.sum.xml.fastinfoset

pushd %{com_sun_xml_fastinfoset_repository}-%{com_sun_xml_fastinfoset_tag}
if [ -e build ]; then rm -rf build; fi
mkdir -p build
$JAVA_HOME/bin/javac -d build `find code/fastinfoset/src/main/java -name \*.java | xargs`
$JAVA_HOME/bin/jmod create --do-not-resolve-by-default --class-path=build:code/fastinfoset/src/main/resources $JAVA_HOME/../jmods/com.sun.xml.fastinfoset.jmod
popd
# Merge com.sun.xml.fastinfoset into the JDK
source $JAVA_HOME/release; export MODULES
$JAVA_HOME/bin/jlink --module-path $JAVA_HOME/../jmods --add-modules "com.sun.xml.fastinfoset,${MODULES//\ /,}" --output $JAVA_HOME/../newjdk
cp -rf $JAVA_HOME/../newjdk/* $JAVA_HOME/
rm -rf $JAVA_HOME/../newjdk

# Build the org.jvnet.staxex

pushd %{org_jvnet_staxex_repository}-%{org_jvnet_staxex_tag}
if [ -e build ]; then rm -rf build; fi
mkdir -p build
$JAVA_HOME/bin/javac -d build `find stax-ex/src/java -name \*.java | xargs`
$JAVA_HOME/bin/jmod create --do-not-resolve-by-default --class-path=build $JAVA_HOME/../jmods/org.jvnet.staxex.jmod
popd
# Merge org.jvnet.staxex into the JDK
source $JAVA_HOME/release; export MODULES
$JAVA_HOME/bin/jlink --module-path $JAVA_HOME/../jmods --add-modules "org.jvnet.staxex,${MODULES//\ /,}" --output $JAVA_HOME/../newjdk
cp -rf $JAVA_HOME/../newjdk/* $JAVA_HOME/
rm -rf $JAVA_HOME/../newjdk

# Build the com.sun.istack.runtime

pushd %{com_sun_istack_runtime_repository}-%{com_sun_istack_runtime_tag}
if [ -e build ]; then rm -rf build; fi
mkdir -p build
$JAVA_HOME/bin/javac -d build `find istack-commons/runtime/src/main/java -name \*.java | xargs`
$JAVA_HOME/bin/jmod create --do-not-resolve-by-default --class-path=build $JAVA_HOME/../jmods/com.sun.istack.runtime.jmod
popd
# Merge com.sun.istack into the JDK
source $JAVA_HOME/release; export MODULES
$JAVA_HOME/bin/jlink --module-path $JAVA_HOME/../jmods --add-modules "com.sun.istack.runtime,${MODULES//\ /,}" --output $JAVA_HOME/../newjdk
cp -rf $JAVA_HOME/../newjdk/* $JAVA_HOME/
rm -rf $JAVA_HOME/../newjdk

# Build the com.sun.xml.txw2

pushd %{jaxb_ri_repository}-%{jaxb_ri_tag}
if [ -e build ]; then rm -rf build; fi
mkdir -p build
$JAVA_HOME/bin/javac -d build `find jaxb-ri/txw/runtime/src/main/java -name \*.java | xargs`
$JAVA_HOME/bin/jmod create --do-not-resolve-by-default --class-path=build $JAVA_HOME/../jmods/com.sun.xml.txw2.jmod
popd
# Merge org.jvnet.staxex into the JDK
source $JAVA_HOME/release; export MODULES
$JAVA_HOME/bin/jlink --module-path $JAVA_HOME/../jmods --add-modules "com.sun.xml.txw2,${MODULES//\ /,}" --output $JAVA_HOME/../newjdk
cp -rf $JAVA_HOME/../newjdk/* $JAVA_HOME/
rm -rf $JAVA_HOME/../newjdk

# Build the com.sun.xml.bind

pushd %{jaxb_ri_repository}-%{jaxb_ri_tag}
if [ -e build ]; then rm -rf build; fi
mkdir -p build
$JAVA_HOME/bin/javac -d build `find jaxb-ri/runtime/impl/src/main/java -name \*.java | xargs`
$JAVA_HOME/bin/jmod create --do-not-resolve-by-default --class-path=build:jaxb-ri/runtime/impl/src/main/resources $JAVA_HOME/../jmods/com.sun.xml.bind.jmod
popd
# Merge org.jvnet.staxex into the JDK
source $JAVA_HOME/release; export MODULES
$JAVA_HOME/bin/jlink --module-path $JAVA_HOME/../jmods --add-modules "com.sun.xml.bind,${MODULES//\ /,}" --output $JAVA_HOME/../newjdk
cp -rf $JAVA_HOME/../newjdk/* $JAVA_HOME/
rm -rf $JAVA_HOME/../newjdk

%endif # add_back_javaee_modules

# cacerts are generated in runtime in openSUSE
if [ -f %{buildoutputdir}/%{imagesdir}/jdk/lib/security/cacerts ]; then
        rm %{buildoutputdir}/%{imagesdir}/jdk/lib/security/cacerts
fi

# Check debug symbols are present and can identify code
SERVER_JVM="$JAVA_HOME/lib/server/libjvm.so"
if [ -f "$SERVER_JVM" ] ; then
  nm -aCl "$SERVER_JVM" | grep javaCalls.cpp
fi
CLIENT_JVM="$JAVA_HOME/lib/client/libjvm.so"
if [ -f "$CLIENT_JVM" ] ; then
  nm -aCl "$CLIENT_JVM" | grep javaCalls.cpp
fi
ZERO_JVM="$JAVA_HOME/lib/zero/libjvm.so"
if [ -f "$ZERO_JVM" ] ; then
  nm -aCl "$ZERO_JVM" | grep javaCalls.cpp
fi

# Check unlimited policy has been used
$JAVA_HOME/bin/javac -d . %{SOURCE14}
$JAVA_HOME/bin/java --add-opens java.base/javax.crypto=ALL-UNNAMED TestCryptoLevel

# Check ECC is working
$JAVA_HOME/bin/javac -d . %{SOURCE15}
#FIXME make it run after system NSS support?
$JAVA_HOME/bin/java $(echo $(basename %{SOURCE15})|sed "s|\.java||") || true

%install
export LANG=en_US.UTF-8
#bnc#530046
export STRIP_KEEP_SYMTAB=libjvm*
# skip /usr/lib/rpm/brp-check-bytecode-version:
export NO_BRP_CHECK_BYTECODE_VERSION=true

%if %{with_systemtap}
  # Install systemtap support files.
  install -dm 755 %{buildroot}%{_jvmdir}/%{sdkdir}/tapset
  cp -a tapset/*.stp %{buildroot}%{_jvmdir}/%{sdkdir}/tapset/
  install -d -m 755 %{buildroot}%{tapsetdir}
  pushd %{buildroot}%{tapsetdir}
    RELATIVE=$(%{abs2rel} %{_jvmdir}/%{sdkdir}/tapset %{tapsetdir})
    ln -sf $RELATIVE/*.stp .
  popd
%endif

pushd %{buildoutputdir}/%{imagesdir}/jdk

  # Install main files.
  install -d -m 755 %{buildroot}%{_jvmdir}/%{sdkdir}
  cp -a bin include lib conf release %{buildroot}%{_jvmdir}/%{sdkdir}

  # Install JCE policy symlinks.
  install -d -m 755 %{buildroot}%{_jvmprivdir}/%{archname}/jce/vanilla

  # Install versionless symlinks.
  pushd %{buildroot}%{_jvmdir}
    ln -sf %{sdkdir} %{jrelnk}
    ln -sf %{sdkdir} %{sdklnk}
  popd

  # Remove javaws man page
  rm -f man/man1/javaws*

  # Install man pages.
  install -d -m 755 %{buildroot}%{_mandir}/man1
  rm -f man/man1/javah*.1
  for manpage in man/man1/*
  do
    # Convert man pages to UTF8 encoding.
    iconv -f ISO_8859-1 -t UTF8 $manpage -o $manpage.tmp
    mv -f $manpage.tmp $manpage
    install -m 644 -p $manpage %{buildroot}%{_mandir}/man1/$(basename \
      $manpage .1)-%{sdklnk}.1
  done

  # Install demos and samples.
  cp -a demo %{buildroot}%{_jvmdir}/%{sdkdir}
  # enable short-circuit
  mkdir -p sample/rmi
  [ -f bin/java-rmi.cgi ] && mv bin/java-rmi.cgi sample/rmi
  cp -a sample %{buildroot}%{_jvmdir}/%{sdkdir}

popd

pushd %{buildoutputdir}/%{imagesdir}

  # Install jmods
  cp -a jmods %{buildroot}%{_jvmdir}/%{sdkdir}

popd

# Install nss.cfg
install -m 644 %{SOURCE13} %{buildroot}%{_jvmdir}/%{sdkdir}/lib/security/

# Install Javadoc documentation.
install -d -m 755 %{buildroot}%{_javadocdir}
cp -a %{buildoutputdir}/images/docs %{buildroot}%{_javadocdir}/%{sdklnk}

# Install icons and menu entries.
for s in 16 24 32 48 ; do
  install -D -p -m 644 \
    src/java.desktop/unix/classes/sun/awt/X11/java-icon${s}.png \
    %{buildroot}%{_datadir}/icons/hicolor/${s}x${s}/apps/java-%{javaver}-openjdk.png
done

# Install desktop file.
install -d -m 0755 %{buildroot}%{_datadir}/{applications,pixmaps}
install -d -m 0755 %{buildroot}/%{_jvmdir}/%{sdkdir}/lib/desktop/
install -m 0644 jconsole.desktop %{buildroot}/%{_jvmdir}/%{sdkdir}/lib/desktop/
%suse_update_desktop_file %{buildroot}/%{_jvmdir}/%{sdkdir}/lib/desktop/jconsole.desktop

# Find demo directories.
find %{buildroot}%{_jvmdir}/%{sdkdir}/demo \
  %{buildroot}%{_jvmdir}/%{sdkdir}/sample -type d \
  | sed 's|'%{buildroot}'|%dir |' \
  > %{name}-demo.files

# FIXME: remove SONAME entries from demo DSOs.  See
# https://bugzilla.redhat.com/show_bug.cgi?id=436497

# Find non-documentation demo files.
find %{buildroot}%{_jvmdir}/%{sdkdir}/demo \
  %{buildroot}%{_jvmdir}/%{sdkdir}/sample \
  -type f -o -type l | sort \
  | grep -v README \
  | sed 's|'%{buildroot}'||' \
  >> %{name}-demo.files
# Find documentation demo files.
find %{buildroot}%{_jvmdir}/%{sdkdir}/demo \
  %{buildroot}%{_jvmdir}/%{sdkdir}/sample \
  -type f -o -type l | sort \
  | grep README \
  | sed 's|'%{buildroot}'||' \
  | sed 's|^|%doc |' \
  >> %{name}-demo.files

# Create a config file to  enable java-atk-wrapper
pushd %{buildroot}/%{_jvmdir}/%{sdkdir}/conf/
  echo "#Config file to  enable java-atk-wrapper" > accessibility.properties
  echo "" >> accessibility.properties
  echo "assistive_technologies=org.GNOME.Accessibility.AtkWrapper" >> accessibility.properties
  echo "" >> accessibility.properties
popd

# fdupes links the files from JDK to JRE, so it breaks a JRE
# use it carefully :))
%fdupes -s %{buildroot}/%{_jvmdir}/%{sdkdir}/
%fdupes -s %{buildroot}/%{_jvmdir}/%{sdkdir}/demo
%fdupes -s %{buildroot}%{_javadocdir}/%{sdklnk}

%post headless
ext=.gz
update-alternatives \
  --install %{_bindir}/java java %{jrebindir}/java %{priority} \
  --slave %{_jvmdir}/jre jre %{_jvmdir}/%{jrelnk} \
  --slave %{_bindir}/jjs jjs %{jrebindir}/jjs \
  --slave %{_bindir}/keytool keytool %{jrebindir}/keytool \
  --slave %{_bindir}/pack200 pack200 %{jrebindir}/pack200 \
  --slave %{_bindir}/rmid rmid %{jrebindir}/rmid \
  --slave %{_bindir}/rmiregistry rmiregistry %{jrebindir}/rmiregistry \
  --slave %{_bindir}/unpack200 unpack200 %{jrebindir}/unpack200 \
  --slave %{_mandir}/man1/java.1$ext java.1$ext \
  %{_mandir}/man1/java-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jjs.1$ext jjs.1$ext \
  %{_mandir}/man1/jjs-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/keytool.1$ext keytool.1$ext \
  %{_mandir}/man1/keytool-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/pack200.1$ext pack200.1$ext \
  %{_mandir}/man1/pack200-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/rmid.1$ext rmid.1$ext \
  %{_mandir}/man1/rmid-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/rmiregistry.1$ext rmiregistry.1$ext \
  %{_mandir}/man1/rmiregistry-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/unpack200.1$ext unpack200.1$ext \
  %{_mandir}/man1/unpack200-%{sdklnk}.1$ext \
  || :

update-alternatives \
  --install %{_jvmdir}/jre-openjdk \
  jre_openjdk %{_jvmdir}/%{jrelnk} %{priority}
update-alternatives \
  --install %{_jvmdir}/jre-%{javaver} \
  jre_%{javaver} %{_jvmdir}/%{jrelnk} %{priority}

%postun headless
if [ $1 -eq 0 ]
then
  if test -f /proc/sys/fs/binfmt_misc/jarexec
  then
    echo '-1' > /proc/sys/fs/binfmt_misc/jarexec
  fi
  update-alternatives --remove java %{jrebindir}/java
  update-alternatives --remove jre_openjdk %{_jvmdir}/%{jrelnk}
  update-alternatives --remove jre_%{javaver} %{_jvmdir}/%{jrelnk}
fi

%posttrans headless
# bnc#781690#c11: don't trust user defined JAVA_HOME and use the current VM
# XXX: this might conflict between various versions of openjdk
export JAVA_HOME=%{_jvmdir}/%{jrelnk}

# check if the java-cacerts is a valid keystore (bnc#781690)
if [ X"`%{_bindir}/file --mime-type -b %{javacacerts}`" \
    != "Xapplication/x-java-keystore;" ]; then
%if 0%{?suse_version} <= 1310
    # workaround for bnc#847952 - pre 13.1 keyring.jar attempts to load invalid keystore and fail on it
    rm -f "%{javacacerts}"
%endif
    %{_sbindir}/update-ca-certificates
fi

# remove the default empty cacert file, if it's installed
if [ 0`stat -c "%{s}" %{cacerts} 2>/dev/null` = "032" ] ; then
    rm -f %{cacerts}
fi

# if cacerts does exists, neither does not contain/point to a
# valid keystore (bnc#781690) ...
if [ X"`%{_bindir}/file --mime-type -b -L %{cacerts}`" \
    != "Xapplication/x-java-keystore;" ]; then
    # bnc#727223
    rm -f %{cacerts}
    ln -s %{javacacerts} %{cacerts}
fi

%post devel
ext=.gz
update-alternatives \
  --install %{_bindir}/javac javac %{sdkbindir}/javac %{priority} \
  --slave %{_jvmdir}/java java_sdk %{_jvmdir}/%{sdklnk} \
%if %{with aot}
  --slave %{_bindir}/jaotc jaotc %{sdkbindir}/jaotc \
%endif
  --slave %{_bindir}/jar jar %{sdkbindir}/jar \
  --slave %{_bindir}/jarsigner jarsigner %{sdkbindir}/jarsigner \
  --slave %{_bindir}/javadoc javadoc %{sdkbindir}/javadoc \
  --slave %{_bindir}/javap javap %{sdkbindir}/javap \
  --slave %{_bindir}/jcmd jcmd %{sdkbindir}/jcmd \
  --slave %{_bindir}/jconsole jconsole %{sdkbindir}/jconsole \
  --slave %{_bindir}/jdb jdb %{sdkbindir}/jdb \
  --slave %{_bindir}/jdeprscan jdeprscan %{sdkbindir}/jdeprscan \
  --slave %{_bindir}/jdeps jdeps %{sdkbindir}/jdeps \
%if ! %{with zero}
%ifnarch s390x
  --slave %{_bindir}/jhsdb jhsdb %{sdkbindir}/jhsdb \
%endif
%endif
  --slave %{_bindir}/jimage jimage %{sdkbindir}/jimage \
  --slave %{_bindir}/jinfo jinfo %{sdkbindir}/jinfo \
  --slave %{_bindir}/jlink jlink %{sdkbindir}/jlink \
  --slave %{_bindir}/jmap jmap %{sdkbindir}/jmap \
  --slave %{_bindir}/jmod jmod %{sdkbindir}/jmod \
  --slave %{_bindir}/jps jps %{sdkbindir}/jps \
  --slave %{_bindir}/jrunscript jrunscript %{sdkbindir}/jrunscript \
  --slave %{_bindir}/jshell jshell %{sdkbindir}/jshell \
  --slave %{_bindir}/jstack jstack %{sdkbindir}/jstack \
  --slave %{_bindir}/jstat jstat %{sdkbindir}/jstat \
  --slave %{_bindir}/jstatd jstatd %{sdkbindir}/jstatd \
  --slave %{_bindir}/rmic rmic %{sdkbindir}/rmic \
  --slave %{_bindir}/serialver serialver %{sdkbindir}/serialver \
  --slave %{_mandir}/man1/jar.1$ext jar.1$ext \
  %{_mandir}/man1/jar-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jarsigner.1$ext jarsigner.1$ext \
  %{_mandir}/man1/jarsigner-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/javac.1$ext javac.1$ext \
  %{_mandir}/man1/javac-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/javadoc.1$ext javadoc.1$ext \
  %{_mandir}/man1/javadoc-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/javap.1$ext javap.1$ext \
  %{_mandir}/man1/javap-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jcmd.1$ext jcmd.1$ext \
  %{_mandir}/man1/jcmd-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jconsole.1$ext jconsole.1$ext \
  %{_mandir}/man1/jconsole-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jdb.1$ext jdb.1$ext \
  %{_mandir}/man1/jdb-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jdeps.1$ext jdeps.1$ext \
  %{_mandir}/man1/jdeps-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jinfo.1$ext jinfo.1$ext \
  %{_mandir}/man1/jinfo-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jmap.1$ext jmap.1$ext \
  %{_mandir}/man1/jmap-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jps.1$ext jps.1$ext \
  %{_mandir}/man1/jps-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jrunscript.1$ext jrunscript.1$ext \
  %{_mandir}/man1/jrunscript-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jstack.1$ext jstack.1$ext \
  %{_mandir}/man1/jstack-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jstat.1$ext jstat.1$ext \
  %{_mandir}/man1/jstat-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/jstatd.1$ext jstatd.1$ext \
  %{_mandir}/man1/jstatd-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/rmic.1$ext rmic.1$ext \
  %{_mandir}/man1/rmic-%{sdklnk}.1$ext \
  --slave %{_mandir}/man1/serialver.1$ext serialver.1$ext \
  %{_mandir}/man1/serialver-%{sdklnk}.1$ext \
  --slave %{_datadir}/applications/jconsole.desktop jconsole.desktop \
  %{_jvmdir}/%{sdkdir}/lib/desktop/jconsole.desktop \
  || :

update-alternatives \
  --install %{_jvmdir}/java-openjdk \
  java_sdk_openjdk %{_jvmdir}/%{sdklnk} %{priority}
update-alternatives \
  --install %{_jvmdir}/java-%{javaver} \
  java_sdk_%{javaver} %{_jvmdir}/%{sdklnk} %{priority}

%postun devel
if [ $1 -eq 0 ]
then
  update-alternatives --remove javac %{sdkbindir}/javac
  update-alternatives --remove java_sdk_openjdk %{_jvmdir}/%{sdklnk}
  update-alternatives --remove java_sdk_%{javaver} %{_jvmdir}/%{sdklnk}
fi

%post javadoc
# in some settings, the %{_javadocdir}/%{sdklnk}/api does not exist
# and the update-alternatives call ends up in error. So, filter this
# cases out.
if [ -d %{_javadocdir}/%{sdklnk}/api ]
then
  update-alternatives \
    --install %{_javadocdir}/java javadocdir %{_javadocdir}/%{sdklnk}/api \
    %{priority}
fi

%postun javadoc
if [ $1 -eq 0 ]
then
# in some settings, the %{_javadocdir}/%{sdklnk}/api does not exist
# and the update-alternatives call ends up in error. So, filter this
# cases out.
  if [ -d %{_javadocdir}/%{sdklnk}/api ]
  then
    update-alternatives --remove javadocdir %{_javadocdir}/%{sdklnk}/api
  fi
fi

%files
%dir %{_jvmdir}/%{sdkdir}/lib
%{_jvmdir}/%{sdkdir}/lib/libawt_xawt.so
%if %{with_pulseaudio}
%{_jvmdir}/%{sdkdir}/lib/libicedtea-sound.so
%endif
%{_jvmdir}/%{sdkdir}/lib/libjawt.so
%{_jvmdir}/%{sdkdir}/lib/libsplashscreen.so
%dir %{_datadir}/icons/hicolor
%{_datadir}/icons/hicolor/*x*/apps/java-%{javaver}-openjdk.png

%files headless
%dir %{_jvmdir}
%dir %{_jvmdir}/%{sdkdir}/
%dir %{_jvmdir}/%{sdkdir}/bin
%dir %{_jvmdir}/%{sdkdir}/lib
%dir %{_jvmdir}/%{sdkdir}/lib/jfr
%dir %{_jvmdir}/%{sdkdir}/lib/jli
%ifarch %{arm6}
%dir %{_jvmdir}/%{sdkdir}/lib/client
%else
%dir %{_jvmdir}/%{sdkdir}/lib/server
%endif
%dir %{_jvmdir}/%{sdkdir}/lib/desktop
%dir %{_jvmdir}/%{sdkdir}/lib/security

%dir %{_jvmdir}/%{sdkdir}/conf
%dir %{_jvmdir}/%{sdkdir}/conf/security
%dir %{_jvmdir}/%{sdkdir}/conf/security/policy
%dir %{_jvmdir}/%{sdkdir}/conf/security/policy/unlimited
%dir %{_jvmdir}/%{sdkdir}/conf/security/policy/limited
%dir %{_jvmdir}/%{sdkdir}/conf/management

%dir %{_jvmdir}/%{sdkdir}
%{_jvmdir}/%{jrelnk}
%{_jvmprivdir}/*

%{_jvmdir}/%{sdkdir}/bin/java
%{_jvmdir}/%{sdkdir}/bin/jfr
%{_jvmdir}/%{sdkdir}/bin/jjs
%{_jvmdir}/%{sdkdir}/bin/keytool
%{_jvmdir}/%{sdkdir}/bin/pack200
%{_jvmdir}/%{sdkdir}/bin/rmid
%{_jvmdir}/%{sdkdir}/bin/rmiregistry
%{_jvmdir}/%{sdkdir}/bin/unpack200
%{_jvmdir}/%{sdkdir}/conf/logging.properties
%{_jvmdir}/%{sdkdir}/conf/management/jmxremote.access
%{_jvmdir}/%{sdkdir}/conf/management/jmxremote.password.template
%{_jvmdir}/%{sdkdir}/conf/management/management.properties
%{_jvmdir}/%{sdkdir}/conf/net.properties
%{_jvmdir}/%{sdkdir}/conf/security/java.policy
%{_jvmdir}/%{sdkdir}/conf/security/java.security
%{_jvmdir}/%{sdkdir}/conf/security/policy/limited/default_local.policy
%{_jvmdir}/%{sdkdir}/conf/security/policy/limited/default_US_export.policy
%{_jvmdir}/%{sdkdir}/conf/security/policy/limited/exempt_local.policy
%{_jvmdir}/%{sdkdir}/conf/security/policy/README.txt
%{_jvmdir}/%{sdkdir}/conf/security/policy/unlimited/default_local.policy
%{_jvmdir}/%{sdkdir}/conf/security/policy/unlimited/default_US_export.policy
%{_jvmdir}/%{sdkdir}/conf/sound.properties
%{_jvmdir}/%{sdkdir}/conf/tz.properties
%if ! %{with zero}
%{_jvmdir}/%{sdkdir}/lib/classlist
%endif
%{_jvmdir}/%{sdkdir}/lib/desktop/jconsole.desktop
%{_jvmdir}/%{sdkdir}/lib/jexec
%{_jvmdir}/%{sdkdir}/lib/jfr/default.jfc
%{_jvmdir}/%{sdkdir}/lib/jfr/profile.jfc
%{_jvmdir}/%{sdkdir}/lib/jli/libjli.so
%{_jvmdir}/%{sdkdir}/lib/jrt-fs.jar
%{_jvmdir}/%{sdkdir}/lib/jspawnhelper
%{_jvmdir}/%{sdkdir}/lib/jvm.cfg
%{_jvmdir}/%{sdkdir}/lib/libawt_headless.so
%{_jvmdir}/%{sdkdir}/lib/libawt.so
%{_jvmdir}/%{sdkdir}/lib/libdt_socket.so
%{_jvmdir}/%{sdkdir}/lib/libextnet.so
%{_jvmdir}/%{sdkdir}/lib/libfontmanager.so
%{_jvmdir}/%{sdkdir}/lib/libinstrument.so
%{_jvmdir}/%{sdkdir}/lib/libj2gss.so
%{_jvmdir}/%{sdkdir}/lib/libj2pcsc.so
%{_jvmdir}/%{sdkdir}/lib/libj2pkcs11.so
%{_jvmdir}/%{sdkdir}/lib/libjaas.so
%{_jvmdir}/%{sdkdir}/lib/libjavajpeg.so
%{_jvmdir}/%{sdkdir}/lib/libjava.so
%{_jvmdir}/%{sdkdir}/lib/libjdwp.so
%{_jvmdir}/%{sdkdir}/lib/libjimage.so
%{_jvmdir}/%{sdkdir}/lib/libjsig.so
%{_jvmdir}/%{sdkdir}/lib/libjsound.so
%{_jvmdir}/%{sdkdir}/lib/liblcms.so
%{_jvmdir}/%{sdkdir}/lib/libmanagement_agent.so
%{_jvmdir}/%{sdkdir}/lib/libmanagement_ext.so
%{_jvmdir}/%{sdkdir}/lib/libmanagement.so
%{_jvmdir}/%{sdkdir}/lib/libmlib_image.so
%{_jvmdir}/%{sdkdir}/lib/libnet.so
%{_jvmdir}/%{sdkdir}/lib/libnio.so
%{_jvmdir}/%{sdkdir}/lib/libprefs.so
%{_jvmdir}/%{sdkdir}/lib/librmi.so
%{_jvmdir}/%{sdkdir}/lib/libsctp.so
%{_jvmdir}/%{sdkdir}/lib/libsunec.so
%{_jvmdir}/%{sdkdir}/lib/libunpack.so
%{_jvmdir}/%{sdkdir}/lib/libverify.so
%{_jvmdir}/%{sdkdir}/lib/libzip.so
%{_jvmdir}/%{sdkdir}/lib/modules
%{_jvmdir}/%{sdkdir}/lib/psfontj2d.properties
%{_jvmdir}/%{sdkdir}/lib/psfont.properties.ja
%{_jvmdir}/%{sdkdir}/lib/tzdb.dat
%{_jvmdir}/%{sdkdir}/lib/*/libjsig.so
%{_jvmdir}/%{sdkdir}/lib/*/libjvm.so
%{_jvmdir}/%{sdkdir}/lib/*/Xusage.txt

%config(noreplace) %{_jvmdir}/%{sdkdir}/lib/security/blacklisted.certs
%config(noreplace) %{_jvmdir}/%{sdkdir}/lib/security/nss.cfg
%{_jvmdir}/%{sdkdir}/lib/security/default.policy
%{_jvmdir}/%{sdkdir}/lib/security/public_suffix_list.dat

%{_mandir}/man1/java-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/jjs-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/keytool-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/pack200-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/rmid-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/rmiregistry-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/unpack200-%{sdklnk}.1%{?ext_man}

%files devel
%dir %{_jvmdir}/%{sdkdir}/bin
%dir %{_jvmdir}/%{sdkdir}/include
%dir %{_jvmdir}/%{sdkdir}/include/linux
%dir %{_jvmdir}/%{sdkdir}/lib

%if %{with_systemtap}
%dir %{_jvmdir}/%{sdkdir}/tapset
%endif
%if %{with aot}
%{_jvmdir}/%{sdkdir}/bin/jaotc
%endif
%{_jvmdir}/%{sdkdir}/bin/jar
%{_jvmdir}/%{sdkdir}/bin/jarsigner
%{_jvmdir}/%{sdkdir}/bin/javac
%{_jvmdir}/%{sdkdir}/bin/javadoc
%{_jvmdir}/%{sdkdir}/bin/javap
%{_jvmdir}/%{sdkdir}/bin/jcmd
%{_jvmdir}/%{sdkdir}/bin/jconsole
%{_jvmdir}/%{sdkdir}/bin/jdb
%{_jvmdir}/%{sdkdir}/bin/jdeprscan
%{_jvmdir}/%{sdkdir}/bin/jdeps
%if ! %{with zero}
%ifnarch s390x
%{_jvmdir}/%{sdkdir}/bin/jhsdb
%endif
%endif
%{_jvmdir}/%{sdkdir}/bin/jimage
%{_jvmdir}/%{sdkdir}/bin/jinfo
%{_jvmdir}/%{sdkdir}/bin/jlink
%{_jvmdir}/%{sdkdir}/bin/jmap
%{_jvmdir}/%{sdkdir}/bin/jmod
%{_jvmdir}/%{sdkdir}/bin/jps
%{_jvmdir}/%{sdkdir}/bin/jrunscript
%{_jvmdir}/%{sdkdir}/bin/jshell
%{_jvmdir}/%{sdkdir}/bin/jstack
%{_jvmdir}/%{sdkdir}/bin/jstat
%{_jvmdir}/%{sdkdir}/bin/jstatd
%{_jvmdir}/%{sdkdir}/bin/rmic
%{_jvmdir}/%{sdkdir}/bin/serialver
%{_jvmdir}/%{sdkdir}/include/classfile_constants.h
%{_jvmdir}/%{sdkdir}/include/jawt.h
%{_jvmdir}/%{sdkdir}/include/jdwpTransport.h
%{_jvmdir}/%{sdkdir}/include/jni.h
%{_jvmdir}/%{sdkdir}/include/jvmticmlr.h
%{_jvmdir}/%{sdkdir}/include/jvmti.h
%{_jvmdir}/%{sdkdir}/lib/ct.sym
%{_jvmdir}/%{sdkdir}/lib/libattach.so
%if ! %{with zero}
%ifnarch s390x
%{_jvmdir}/%{sdkdir}/lib/libsaproc.so
%endif
%endif
%{_jvmdir}/%{sdkdir}/include/linux/jawt_md.h
%{_jvmdir}/%{sdkdir}/include/linux/jni_md.h

%if %{with_systemtap}
%{_jvmdir}/%{sdkdir}/tapset/*.stp
%endif
%{_jvmdir}/%{sdklnk}
%{_mandir}/man1/jar-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/jarsigner-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/javac-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/javadoc-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/javap-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/jcmd-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/jconsole-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/jdb-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/jdeps-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/jinfo-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/jmap-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/jps-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/jrunscript-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/jstack-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/jstat-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/jstatd-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/rmic-%{sdklnk}.1%{?ext_man}
%{_mandir}/man1/serialver-%{sdklnk}.1%{?ext_man}

%if %{with_systemtap}
%{tapsetroot}
%endif

%files jmods
%dir %{_jvmdir}/%{sdkdir}/jmods
%{_jvmdir}/%{sdkdir}/release
%{_jvmdir}/%{sdkdir}/jmods/*.jmod
%if %{with_pulseaudio}
%{_jvmdir}/%{sdkdir}/jmods/icedtea-sound.jar
%endif
%{_jvmdir}/%{sdkdir}/jmods/java-atk-wrapper.jar

%files demo -f %{name}-demo.files

%files src
%{_jvmdir}/%{sdkdir}/lib/src.zip

%files javadoc
%dir %{_javadocdir}
%dir %{_javadocdir}/%{sdklnk}
%{_javadocdir}/%{sdklnk}/*

%files accessibility
%config(noreplace) %{_jvmdir}/%{sdkdir}/conf/accessibility.properties
%{_jvmdir}/%{sdkdir}/lib/libatk-wrapper.so

%changelog
* Tue Apr 21 2020 Fridrich Strba <fstrba@suse.com>
- update to upstream tag jdk-11.0.7+10 (April 2020 CPU,
  bsc#1169511)
  * Security fixes:
    + S8223898, CVE-2020-2754: Forward references to Nashorn
    + S8223904, CVE-2020-2755: Improve Nashorn matching
    + S8224541, CVE-2020-2756: Better mapping of serial ENUMs
    + S8224549, CVE-2020-2757: Less Blocking Array Queues
    + S8225603: Enhancement for big integers
    + S8226346: Build better binary builders
    + S8227467: Better class method invocations
    + S8227542: Manifest improved jar headers
    + S8229733: TLS message handling improvements
    + S8231415, CVE-2020-2773: Better signatures in XML
    + S8231785: Improved socket permissions
    + S8232424, CVE-2020-2778: More constrained algorithms
    + S8232581, CVE-2020-2767: Improve TLS verification
    + S8233250: Better X11 rendering
    + S8233410: Better Build Scripting
    + S8234027: Better JCEKS key support
    + S8234408, CVE-2020-2781: Improve TLS session handling
    + S8234825, CVE-2020-2800: Better Headings for HTTP Servers
    + S8234841, CVE-2020-2803: Enhance buffering of byte buffers
    + S8235274, CVE-2020-2805: Enhance typing of methods
    + S8235691, CVE-2020-2816: Enhance TLS connectivity
    + S8236201, CVE-2020-2830: Better Scanner conversions
    + S8238960: linux-i586 builds are inconsistent as the newly
    built jdk is not able to reserve enough space for object heap
  * Other changes:
    + S4919790: Errors in alert ssl message does not reflect the
    actual certificate status
    + S4949105: Access Bridge lacks html tags parsing
    + S7092821: java.security.Provider.getService() is synchronized
    and became scalability bottleneck
    + S7143743: Potential memory leak with zip provider
    + S8005819: Support cross-realm MSSFU
    + S8042383: [TEST_BUG] Test javax/swing/plaf/basic/BasicMenuUI/
    /4983388/bug4983388.java fails with shortcuts on menus do not
    work
    + S8068184: Fix for JDK-8032832 caused a deadlock
    + S8145845: [AOT] NullPointerException in
    compiler/whitebox/GetCodeHeapEntriesTest.java
    + S8152988: [AOT] Update test batch definitions to include
    aot-ed java.base module mode into hs-comp testing
    + S8160926: FLAGS_COMPILER_CHECK_ARGUMENTS doesn't handle
    cross-compilation
    + S8163083: SocketListeningConnector does not allow invocations
    with port 0
    + S8163251: Hard coded loop limit prevents reading of smart
    card data greater than 8k
    + S8167276: jvmci/compilerToVM/MaterializeVirtualObjectTest.java
    fails with -XX:-EliminateAllocations
    + S8169718: nsk/jdb/locals/locals002: ERROR: Cannot find
    boolVar with expected value: false
    + S8176556:
    java/awt/dnd/ImageTransferTest/ImageTransferTest.java fails
    for JFIF
    + S8178798: Two compiler/aot/verification/vmflags tests fail by
    timeout with UseAVX=3
    + S8183107: PKCS11 regression regarding checkKeySize
    + S8185005: Improve performance of
    ThreadMXBean.getThreadInfo(long ids[], int maxDepth)
    + S8189633: Missing -Xcheck:jni checking for DeleteWeakGlobalRef
    + S8189861: Refactor CacheFind
    + S8193042: NativeLookup::lookup_critical_entry() should only
    load shared library once
    + S8193596: java/net/DatagramPacket/ReuseBuf.java failed due to
    timeout
    + S8194944: Regression automated test 'open/test/jdk/javax/
    /swing/JInternalFrame/8145896/TestJInternalFrameMaximize.java'
    fails
    + S8196467: javax/swing/JInternalFrame/Test6325652.java fails
    + S8196969: JTreg Failure: serviceability/sa/ClhsdbJstack.java
    causes NPE
    + S8198321: javax/swing/JEditorPane/5076514/bug5076514.java
    fails
    + S8198398: Test javax/swing/JColorChooser/Test6199676.java
    fails in mach5
    + S8199072: Test javax/swing/GroupLayout/6613904/
    /bug6613904.java is unstable
    + S8200432: javadoc fails with ClassCastException on {@link
    byte[]}
    + S8201349: build broken when configured with
  - -with-zlib=bundled on gcc 7.3
    + S8201355: Avoid native memory allocation in
    sun.security.mscapi.PRNG.generateSeed
    + S8201513: nsk/jvmti/IterateThroughHeap/filter-* are broken
    + S8203364: Some serviceability/sa/ tests intermittently fail
    with java.io.IOException: LingeredApp terminated with non-zero
    exit code 3
    + S8203687: javax/net/ssl/compatibility/Compatibility.java
    supports TLS 1.3
    + S8203904: javax/swing/JSplitPane/4816114/bug4816114.java: The
    divider location is wrong
    + S8203911: Test runtime/modules/getModuleJNI/GetModule fails
    with -Xcheck:jni
    + S8204525: [TESTBUG] runtime/NMT/MallocStressTest.java ran out
    of java heap
    + S8204529: gc/TestAllocateHeapAtMultiple.java fail with Agent
    7 timed out
    + S8204551: Event descriptions are truncated in logs
    + S8206963: [AOT] bug with multiple class loaders
    + S8207367: 10 vmTestbase/nsk/jdi tests timed out when running
    with jtreg
    + S8207832: serviceability/sa/ClhsdbCDSCore.java failed with
    "Couldn't find core file location"
    + S8207938: At step6,Click Add button,case failed automatically.
    + S8208157: requires.VMProps throws NPE for missing properties
    in "release" file
    + S8208379: compiler/jvmci/events/
    /JvmciNotifyInstallEventTest.java failed with "Got unexpected
    event count after 2nd install attempt: expected 9 to equal 2"
    + S8208658: Make CDS archived heap regions usable even if
    compressed oop encoding has changed
    + S8208715: Conversion of milliseconds to nanoseconds in
    UNIXProcess contains bug
    + S8209361: [AOT] Unexpected number of references for
    JVMTI_HEAP_REFERENCE_CONSTANT_POOL [111-->111]: 0 (expected
    at least 1)
    + S8209385: CDS runtime classpath checking is too strict when
    only classes from the system modules are archived
    + S8209389: SIGSEGV in WalkOopAndArchiveClosure::do_oop_work.
    + S8209418: Synchronize test/jdk/sanity/client/lib/jemmy with
    code-tools/jemmy/v2
    + S8209494: Create a test for SwingSet InternalFrameDemo
    + S8209499: Create test for SwingSet EditorPaneDemo
    + S8209574: [AOT] breakpoint events are generated in different
    threads does not meet expected count
    + S8209686: cleanup arguments to PhaseIdealLoop() constructor
    + S8209789: Synchronize test/jdk/sanity/client/lib/jemmy with
    code-tools/jemmy/v2
    + S8209802: Garbage collectors should register JFR types
    themselves to avoid build errors.
    + S8209807: improve handling exception in requires.VMProps
    + S8209817: stack is executable when building with Clang on
    Linux
    + S8209824: Improve the code coverage for ThreadLocal
    + S8209826: Undefined reference to os::write after JDK-8209657
    (filemap.hpp cleanup)
    + S8209850: Allow NamedThreads to use GlobalCounter critical
    sections
    + S8209976: Improve iteration over non-JavaThreads
    + S8209993: Create a test for SwingSet3 ToolTipDemo
    + S8210024: JFR calls virtual is_Java_thread from ~Thread()
    + S8210052: Enable testing for all the available look and feels
    in SwingSet3 demo tests
    + S8210055: Enable different look and feel tests in SwingSet3
    demo tests
    + S8210057: Enable different look and feels in SwingSet3 demo
    test InternalFrameDemoTest
    + S8210058: Algorithmic Italic font leans opposite angle in
    Printing
    + S8210220: [AOT] jdwp test cases are failing with error #
    ERROR: TEST FAILED: Cought IOException while receiving event
    packet
    + S8210289: ArchivedKlassSubGraphInfoRecord is incomplete
    + S8210459: Add support for generating compile_commands.json
    + S8210476: sun/security/mscapi/PrngSlow.java fails with Still
    too slow
    + S8210512: [Testbug] vmTestbase/nsk/jdi/ObjectReference/
    /referringObjects/referringObjects002/referringObjects002.java
    fails with unexpected size of
    ClassLoaderReference.referringObjects
    + S8210523: runtime/appcds/cacheObject/DifferentHeapSizes.java
    crash
    + S8210632: Add key exchange algorithm to
    javax/net/ssl/TLSCommon/CipherSuite.java
    + S8210699: Problem list tests which times out in Xcomp mode
    + S8210793: [JVMCI] AllocateCompileIdTest.java failed to find
    DiagnosticCommand.class
    + S8210910: Create test for FileChooserDemo
    + S8210994: Create test for SwingSet3 FrameDemo
    + S8211139: Increase timeout value in all tests under
    jdk/sanity/client/SwingSet/src
    + S8211160: Handle different look and feels in
    JInternalFrameOperator
    + S8211211: vmTestbase/metaspace/stressDictionary/
    /StressDictionary.java timeout
    + S8211322: Reduce the timeout of tooltip in SwingSet2DemoTest
    + S8211443: Enable different look and feels in SwingSet3 demo
    test SplitPaneDemoTest
    + S8211703: JInternalFrame : java.lang.AssertionError: cannot
    find the internal frame
    + S8211781: re-building fails after changing Graal sources
    + S8212897: Some improvements in the EditorPaneDemotest
    + S8212903: [TestBug] Tests test/jdk/javax/swing/LookAndFeel/
    /8145547/DemandGTK2.sh and DemandGTK3.sh fail on Ubuntu 18.04
    LTS
    + S8213009: Refactoring existing SunMSCAPI classes
    + S8213010: Supporting keys created with certmgr.exe
    + S8213168: Enable different look and feel tests in SwingSet3
    demo test FileChooserDemoTest
    + S8213348: jdk.internal.vm.compiler.management service
    providers missing in module descriptor
    + S8213906: Update arm devkits with libXrandr headers
    + S8213908: AssertionError in DeferredAttr at setOverloadKind
    + S8214124: [TESTBUG] Bugs in runtime/NMT/MallocStressTest.java
    + S8214344: C2: assert(con.basic_type() != T_ILLEGAL) failed:
    elembt=byte; loadbt=void; unsigned=0
    + S8214345: infinite recursion while checking super class
    + S8214471: Enable different look and feel tests in SwingSet3
    demo test ToolTipDemoTest
    + S8214534: Setting of THIS_FILE in the build is broken
    + S8214557: Filter out VM flags which don't affect AOT code
    generation
    + S8214578: [macos] Problem with backslashes on macOS/JIS
    keyboard: Java ignores system settings
    + S8214840: runtime/NMT/MallocStressTest.java timed out
    + S8214850: Rename vm_operations.?pp files to vmOperations.?pp
    files
    + S8214904: Test8004741.java failed due to "Too few ThreadDeath
    hits; expected at least 6 but saw only 5"
    + S8215322: add @file support to jaotc
    + S8215355: Object monitor deadlock with no threads holding the
    monitor (using jemalloc 5.1)
    + S8215396: JTabbedPane preferred size calculation is wrong for
    SCROLL_TAB_LAYOUT
    + S8216180: [AOT] compiler/intrinsics/bigInteger/TestMulAdd.java
    crashed with AOT enabled
    + S8216353: Use utility APIs introduced in org/netbeans/jemmy/
    /util/LookAndFeel class in client sanity test cases
    + S8216354: Syntax error in toolchain_windows.m4
    + S8216472: (se) Stack overflow during selection operation
    leads to crash (win)
    + S8216535: tools/jimage/JImageExtractTest.java timed out
    + S8217235: Create automated test for SwingSet
    ColorChooserDemoTest
    + S8217297: Add support for multiple look and feel for SwingSet
    SliderDemoTest
    + S8217338: [Containers] Improve systemd slice memory limit
    support
    + S8217613: [AOT] TEST_OPTS_AOT_MODULES doesn't work on mac
    + S8217634: RunTest documentation and usability update
    + S8217717: ZGC: Broken oop map in C1 load barrier stub
    + S8217728: Speed up incremental rerun of "make hotspot"
    + S8218268: Javac treats Manifest Class-Path entries as Paths
    instead of URLs
    + S8218662: Allow 204 responses with Content-Length:0
    + S8218882: NET_Writev is declared, NET_WriteV is defined
    + S8218889: Improperly use of the Optional API
    + S8219205: JFR file without license header
    + S8219597: (bf) Heap buffer state changes could provoke
    unexpected exceptions
    + S8219723: javax/net/ssl/compatibility/Compatibility.java
    failed on some SNI cases
    + S8220348: [ntintel] asserts about copying unaligned array
    + S8220451: jdi/EventQueue/remove/remove004 failed due to
    "ERROR: thread2 is not alive"
    + S8220456: jdi/EventQueue/remove_l/remove_l004 failed due to
    "TIMEOUT while waiting for event"
    + S8220479: java/nio/channels/Selector/SelectWithConsumer.java
    failed at testTwoChannels()
    + S8220613: java/util/Arrays/TimSortStackSize2.java times out
    with fastdebug build
    + S8220688: [TESTBUG] runtime/NMT/MallocStressTest.java timed
    out
    + S8220786: Create new switch to redirect error reporting
    output to stdout or stderr
    + S8221270: Duplicated synchronized keywords in SSLSocketImpl
    + S8221312: test/jdk/sanity/client/SwingSet/src/
    /ColorChooserDemoTest.java failed
    + S8221851: Use of THIS_FILE in hotspot invalidates precompiled
    header on Linux/GCC
    + S8221885: Add intermittent test in the JavaSound to the
    ProblemList
    + S8222264: Windows incremental build is broken with JDK-8217728
    + S8222391: javax/net/ssl/compatibility/Compatibility.java
    should be more flexible
    + S8222448: java/lang/reflect/PublicMethods/
    /PublicMethodsTest.java times out
    + S8222519: ButtonDemoScreenshotTest fails randomly with "still
    state to be reached"
    + S8222741: jdi/EventQueue/remove/remove004 fails due to
    VMDisconnectedException
    + S8223003: SunMSCAPI keys are not cleaned up
    + S8223063: Support CNG RSA keys
    + S8223158: Docked MacBook cannot start any Java Swing
    applications
    + S8223260: NamingManager should cache InitialContextFactory
    + S8223464: Improve version string for Oracle CI builds
    + S8223558: Java does not render Myanmar script correctly
    + S8223627: jdk-13+20 bundle name contains null instead of ea
    + S8223638: Replace wildcard address with loopback or local
    host in tests - part 6
    + S8223678: Add Visual Studio Code workspace generation support
    (for native code)
    + S8223727: com/sun/jndi/ldap/privconn/RunTest.java failed due
    to hang in LdapRequest.getReplyBer
    + S8223769: Assert triggers with -XX:+StressReflectiveCode
    + S8224187: Refactor arraycopy_prologue to allow ZGC read
    barriers on arraycopy
    + S8224475: JTextPane does not show images in HTML rendering
    + S8224673: Adjust permission for delayed starting of debugging
    + S8224705: Tests that need to be problem-listed or have
    printer resources
    + S8224778: test/jdk/demo/jfc/J2Ddemo/J2DdemoTest.java cannot
    find J2Ddemo.jar
    + S8224821: java/awt/Focus/NoAutotransferToDisabledCompTest/
    /NoAutotransferToDisabledCompTest.java fails linux-x64
    + S8224830: test/jdk/java/awt/Focus/
    /ModalExcludedWindowClickTest/
    /ModalExcludedWindowClickTest.java fails on linux-x64
    + S8224851: AArch64: fix warnings and errors with Clang and GCC
    8.3
    + S8224905: java/lang/ProcessBuilder/Basic.java#id1 failed with
    stream closed
    + S8225007: java/awt/print/PrinterJob/
    /LandscapeStackOverflow.java may hang
    + S8225105: java/awt/Focus/ShowFrameCheckForegroundTest/
    /ShowFrameCheckForegroundTest.java fails in Windows 10
    + S8225117: java/math/BigInteger/SymmetricRangeTests.java fails
    with ParseException
    + S8225128: Add exception for expiring DocuSign root to
    VerifyCACerts test
    + S8225130: Add exception for expiring Comodo roots to
    VerifyCACerts test
    + S8225144: [macos] In Aqua L&F backspace key does not delete
    when Shift is pressed
    + S8225180: SignedObject with invalid Key not throwing the
    InvalidKeyException in Windows
    + S8225182: JNI exception pending in DestroyXIMCallback of
    awt_InputMethod.c:1327
    + S8225199: [Graal] compiler/jvmci/compilerToVM/
    /IsMatureVsReprofileTest.java fails with
  - XX:CompileThresholdScaling=0.1
    + S8225305: ProblemList java/lang/invoke/VarHandles tests
    + S8225350: compiler/jvmci/compilerToVM/IsCompilableTest.java
    timed out
    + S8225430: Replace wildcard address with loopback or local
    host in tests - part 14
    + S8225435: Upgrade IANA Language Subtag Registry to the latest
    for JDK14
    + S8225487: giflib legal file is missing attribution for
    openbsd-reallocarray.c
    + S8225567: Wrong file headers with 8202414 fix changeset
    + S8225684: [AOT] vmTestbase/vm/oom/production/
    /AlwaysOOMProduction tests fail with AOTed java.base
    + S8225766: Curve in certificate should not affect signature
    scheme when using TLSv1.3
    + S8225797: OldObjectSample event creates unexpected amount of
    checkpoint data
    + S8226381: ProblemList java/lang/reflect/PublicMethods/
    /PublicMethodsTest.java
    + S8226406: JVM fails to detect mismatched or corrupt CDS
    archive
    + S8226608: Hide the onjcmd option from the help output
    + S8226892: ActionListeners on JRadioButtons don't get notified
    when selection is changed with arrow keys
    + S8227112: exclude compiler/intrinsics/sha/sanity tests from
    AOT runs
    + S8227324: Upgrade to freetype 2.10.1
    + S8227528: TestAbortVMOnSafepointTimeout.java failed due to
    "RuntimeException: 'Safepoint sync time longer than' missing
    from stdout/stderr"
    + S8227645: Some tests in serviceability/sa run with fixed -Xmx
    values and risk running out of memory
    + S8227646: [TESTBUG] appcds/SharedArchiveConsistency timed out
    + S8227662: freetype seeks to index at the end of the font data
    + S8228479: Correct the format of ColorChooserDemoTest
    + S8228613: java.security.Provider#getServices order is no
    longer deterministic
    + S8228969: 2019-09-28 public suffix list update
    + S8229236: CriticalJNINatives: dll handling should be done in
    native thread state
    + S8229345: Memory leak due to vtable stubs not being shared on
    SPARC
    + S8229888: (zipfs) Updating an existing zip file does not
    preserve original permissions
    + S8229994: assert(false) failed: Bad graph detected in
    get_early_ctrl_for_expensive
    + S8230004: jdk/internal/jimage/JImageOpenTest.java runs no test
    + S8230235: Rendering HTML with empty img attribute and
    documentBaseKey cause Exception
    + S8230390: Problemlist SA tests with AOT
    + S8230400: Missing constant pool entry for a method in
    stacktrace
    + S8230459: Test failed to resume JVMCI CompilerThread
    + S8230480: check malloc/calloc results in java.desktop
    + S8230597: Update GIFlib library to the 5.2.1
    + S8230611: infinite loop in
    LogOutputList::wait_until_no_readers()
    + S8230624: [TESTBUG] Problemlist JFR
    compiler/TestCodeSweeper.java
    + S8230677: Should disable Escape Analysis if JVMTI capability
    can_get_owned_monitor_info was taken
    + S8230926: [macosx] Two apostrophes are entered instead of one
    with "U.S. International - PC" layout
    + S8231025: Incorrect method tag offset for big endian platform
    + S8231081: TestMetadataRetention fails due to missing symbol id
    + S8231387: java.security.Provider.getService returns random
    result due to race condition with mutating methods in the same
    class
    + S8231430: C2: Memory stomp in max_array_length() for
    T_ILLEGAL type
    + S8231445: check ZALLOC return values in awt coding
    + S8231507: Update Apache Santuario (XML Signature) to version
    2.1.4
    + S8231584: Deadlock with ClassLoader.findLibrary and
    System.loadLibrary call
    + S8231753: use more Posix functionality in aix
    os::print_os_info
    + S8231810: javax/net/ssl/templates/
    /SSLSocketSSLEngineTemplate.java fails intermittently with
    "java.lang.Exception: Unexpected EOF"
    + S8232003: (fs) Files.write can leak file descriptor in the
    exception case
    + S8232056: GetOwnedMonitorInfoWithEATest.java fails with ZGC:
    Heap too small
    + S8232060: add some initializations using sigemptyset in
    os_aix.cpp
    + S8232154: Update Mesa 3-D Headers to version 19.2.1
    + S8232167: Visual Studio install found through
  - -with-tools-dir value is discarded
    + S8232170: FSInfo#getJarClassPath throws an exception not
    declared in its throws clause
    + S8232200: [macos 10.15] Windows in fullscreen tests jumps
    around the screen
    + S8232207: Linux os::available_memory re-reads cgroup
    configuration on every invocation
    + S8232224: [TESTBUG] problemlist JFR TestLargeRootSet.java
    + S8232370: Refactor some com.sun.jdi tests to enable IDE
    integration
    + S8232433: [macos 10.15] java/awt/Window/
    /LocationAtScreenCorner/LocationAtScreenCorner.java may fail
    + S8232571: Add missing SIGINFO signal
    + S8232692: [TESTBUG] compiler/aot/fingerprint/
    /SelfChangedCDS.java fails when cds is disabled
    + S8232713: Update BCEL version to 6.3.1 in license file
    + S8232806: Introduce a system property to disable eager lambda
    initialization
    + S8232834: RunTest sometimes fails to produce valid
    exitcode.txt
    + S8232880: Update test documentation with additional settings
    for client UI tooltip tests
    + S8232950: SUNPKCS11 Provider incorrectly check key length for
    PSS Signatures.
    + S8233018: Add a new test to verify that DatagramSocket is not
    interruptible
    + S8233019: java.lang.Class.isPrimitive() (C1) returns wrong
    result if Klass* is aligned to 32bit
    + S8233032: assert(in_bb(n)) failed: must be
    + S8233078: fix minimal VM build on Linux ppc64(le)
    + S8233328: fix minimal VM build on Linux s390x
    + S8233383: Various minor fixes
    + S8233466: aarch64: remove unnecessary load of mdo when
    profiling return and parameters type
    + S8233491: Crash in AdapterHandlerLibrary::get_adapter with
    CDS due to code cache exhaustion
    + S8233529: loopTransform.cpp:2984: Error: assert(p_f->Opcode()
    == Op_IfFalse) failed
    + S8233548: Update CUP to v0.11b
    + S8233649: Update ProblemList.txt to exclude failing headful
    tests on macos
    + S8233656: assert(d->is_CFG() && n->is_CFG()) failed: must
    have CFG nodes
    + S8233657: Intermittent NPE in Component.validate()
    + S8234288: Turkey Time Zone returns incorrect time zone name
    + S8234323: NULL-check return value of SurfaceData_InitOps on
    macosx
    + S8234339: replace JLI_StrTok in java_md_solinux.c
    + S8234340: Bump update version for OpenJDK: jdk-11.0.7
    + S8234350: assert(mode == ControlAroundStripMined && (use ==
    sfpt || !use->is_reachable_from_root())) failed: missed a node
    + S8234386: [macos] NPE was thrown at expanding Choice from
    maximized frame
    + S8234397: add OS uptime information to os::print_os_info
    output
    + S8234423: Modifying ArrayList.subList().subList() resets
    modCount of subList
    + S8234466: Class loading deadlock involving
    X509Factory#commitEvent()
    + S8234501: remove obsolete NET_ReadV
    + S8234525: enable link-time section-gc for linux s390x to
    remove unused code
    + S8234610: MaxVectorSize set wrongly when UseAVX=3 is
    specified after JDK-8221092
    + S8234617: C1: Incorrect result of field load due to missing
    narrowing conversion
    + S8234723: javax/net/ssl/TLS tests support TLSv1.3
    + S8234724: javax/net/ssl/templates/
    /SSLSocketSSLEngineTemplate.java supports TLSv1.3
    + S8234741: enhance os::get_core_path on macOS
    + S8234769: Duplicate attribution in freetype.md
    + S8234786: Fix for JDK-8214578 breaks OS X 10.12 compatibility
    + S8234809: set relro in linker flags when building with gcc
    + S8234824: java/nio/channels/SocketChannel/AdaptSocket.java
    fails on Windows 10
    + S8235243: handle VS2017 15.9 and VS2019 in abstract_vm_version
    + S8235288: AVX 512 instructions inadvertently used on Xeon for
    small vector width operations
    + S8235325: build failure on Linux after 8235243
    + S8235383: C1 compilation fails with
  - XX:+PrintIRDuringConstruction -XX:+Verbose
    + S8235489: handle return values of sscanf calls in hotspot
    + S8235509: Backport for JDK-8209657 Refactor filemap.hpp to
    simplify integration with Serviceability Agent.
    + S8235510: java.util.zip.CRC32 performance drop after 8200067
    + S8235563: [TESTBUG] appcds/CommandLineFlagComboNegative.java
    does not handle archive mapping failure
    + S8235637: jhsdb jmap from OpenJDK 11.0.5 doesn't work if
    prelink is enabled
    + S8235671: enhance print_rlimit_info in os_posix
    + S8235744: PIT: test/jdk/javax/swing/text/html/
    /TestJLabelWithHTMLText.java times out in linux-x64
    + S8235904: Infinite loop when rendering huge lines
    + S8235998: [c2] Memory leaks during tracing after '8224193:
    stringStream should not use Resource Area'.
    + S8236039: JSSE Client does not accept status_request
    extension in CertificateRequest messages for TLS 1.3
    + S8236140: assert(!VerifyHashTableKeys || _hash_lock == 0)
    failed: remove node from hash table before modifying it
    + S8236179: C1 register allocation error with T_ADDRESS
    + S8236488: Support for configure option
  - -with-native-debug-symbols=internal is impossible on Windows
    + S8236500: Windows ucrt.dll should be looked up in versioned
    WINSDK subdirectory
    + S8236709: struct SwitchRange in HS violates C++ One
    Definition Rule
    + S8236848: [JDK 11u] make run-test-tier1 fails after backport
    of JDK-8232834
    + S8236873: Worker has a deadlock bug
    + S8237217: Incorrect G1StringDedupEntry type used in
    StringDedupTable destructor
    + S8237368: Problem with NullPointerException in RMI
    TCPEndpoint.read
    + S8237375: SimpleThresholdPolicy misses CounterDecay timestamp
    initialization
    + S8237508: Simplify JarFile.isInitializing
    + S8237540: Missing files in backport of JDK-8210910
    + S8237541: Missing files in backport of JDK-8236528
    + S8237600: Test SunJSSEFIPSInit fails on Ubuntu
    + S8237819: s390x - remove unused pd_zero_to_words_large
    + S8237869: exclude jtreg test security/infra/java/security/
    /cert/CertPathValidator/certification/LuxTrustCA.java because
    of instabilities
    + S8237879: make 4.3 breaks build
    + S8237945: CTW: C2 compilation fails with
    assert(just_allocated_object(alloc_ctl) == ptr) failed: most
    recent allo...
    + S8238225: Issues reported after replacing symlink at
    Contents/MacOS/libjli.dylib with binary
    + S8238247: CTW runner should sweep nmethods more aggressively
    + S8238366: CTW runner closes standard output on exit
    + S8238438: SuperWord::co_locate_pack picks memory state of
    first instead of last load
    + S8238502: sunmscapi.dll causing EXCEPTION_ACCESS_VIOLATION
    + S8238534: Deep sign macOS bundles before bundle archive is
    being created
    + S8238591: CTW: Split
    applications/ctw/modules/jdk_localedata.java
    + S8238596: AVX enabled by default for Skylake even when
    unsupported
    + S8238811: C2: assert(i >= req() || i == 0 || is_Region() ||
    is_Phi()) with -XX:+VerifyGraphEdges
    + S8239005: [TESTBUG] test/hotspot/jtreg/runtime/
    /StackGuardPages/TestStackGuardPages.java: exeinvoke.c: must
    initialize static state before calling do_overflow()
    + S8239466: Loss of precision in counter decay calculation in
    11u backport of JDK-8237375
    + S8239856: [ntintel] asserts about copying unaligned array
    element
    + S8240724: [test] jdk11 downport of 8224475 misses binary file
    test/jdk/javax/swing/JTextPane/arrow.png
    + S8241296: Segfault in JNIHandleBlock::oops_do()
- Removed patch:
  * DependOnVariableHelper.patch
    + fixed upstream
- Added patch:
  * JDK-8228407.patch
    + fix crashes due to shared archive file mismatch
* Wed Apr 15 2020 Fridrich Strba <fstrba@suse.com>
- The pack200 and unpack200 alternatives should be slaves of java
  and not of javac, since they are part of JRE.
* Wed Mar 25 2020 Martin Liška <mliska@suse.cz>
- Add gcc-fno-common-fix.patch in order to fix
  boo#1167462.
* Thu Feb 13 2020 Andreas Schwab <schwab@suse.de>
- DependOnVariableHelper.patch: Fix DependOnVariableHelper for make 4.3
* Sun Feb  2 2020 Fridrich Strba <fstrba@suse.com>
- Install java icons not only versioned, but also postfixed by the
  "openjdk", in order to prevent install conflicts with other
  jdk 11 flavours.
* Wed Jan 15 2020 Fridrich Strba <fstrba@suse.com>
- Update to upstream tag jdk-11.0.6+10 (January 2020 CPU,
  bsc#1160968)
  * Security fixes
    + S8224909, CVE-2020-2583: Unlink Set of LinkedHashSets
    + S8225261: Better method resolutions
    + S8225279: Better XRender interpolation
    + S8226352, CVE-2020-2590: Improve Kerberos interop capabilities
    + S8227758: More valid PKIX processing
    + S8227816: More Colorful ICC profiles
    + S8228548, CVE-2020-2593: Normalize normalization for all
    + S8229728: Implement negotiation parameters
    + S8229951, CVE-2020-2601: Better Ticket Granting Services
    + S8230279: Improve Pack200 file reading
    + S8230318: Better trust store usage
    + S8230967: Improve Registry support of clients
    + S8231139: Improved keystore support
    + S8231422, CVE-2020-2604: Better serial filter handling
    + S8231780, CVE-2020-2655: Better TLS messaging support
    + S8231790: Provide better FileSystemProviders
    + S8232419: Improve Registry registration
    + S8234037, CVE-2020-2654: Improve Object Identifier Processing
  * Other changes
    + S8016914: CoreDocumentImpl.setXmlVersion NPE
    + S8048556: Unnecessary GCLocker-initiated young GCs
    + S8080462: Update SunPKCS11 provider with PKCS11 v2.40 support
    + S8134672: [TEST_BUG] Some tests should check
    isDisplayChangeSupported
    + S8144125: [macOS] java/awt/event/ComponentEvent/
    /MovedResizedTwiceTest/MovedResizedTwiceTest.java failed
    automatically
    + S8146238: [macosx] Java2D Queue Flusher crash on OSX after
    switching between user accounts
    + S8176837: SunPKCS11 provider needs to check more details on
    PKCS11 Mechanism
    + S8185898: setRequestProperty(key, null) results in HTTP header
    without colon in request
    + S8190737: use unicode version of the canonicalize() function
    to handle long path on windows
    + S8191521: handle long relative path specified in
  - Xbootclasspath/a on windows
    + S8193255: Root Certificates should be stored in text format
    and assembled at build time
    + S8193325: StackFrameInfo::getByteCodeIndex returns wrong value
    if bci > 32767
    + S8198882: Add 10 JNDI tests to com/sun/jndi/dns/AttributeTests
    + S8200381: Typos in javadoc - missing verb "be" and alike
    + S8202359: [GRAAL] compiler/uncommontrap/TestDeoptOOM.java
    failed with OutOfMemoryError
    + S8205516: JFR tool
    + S8206115: Use shared macros for JavaClasses::compute_offsets
    and MetaspaceShared::serialize_well_known_classes
    + S8207263: Store the Configuration for system modules into CDS
    archive.
    + S8207922: ctw of jdk.security.auth failed with "Unexpected
    zero exit codebefore finishing all compilations"
    + S8208179: Devanagari not shown with logical fonts on Windows
    after removal of Lucida Sans from JDK
    + S8208236: [TESTBUG] vmTestbase/nsk/stress/stack tests fail by
    timeout
    + S8208364: java/lang/reflect/callerCache/
    /ReflectionCallerCacheTest.java missing module dependencies
    declaration
    + S8208582: Introduce native oop barriers in C1 for OopHandle
    + S8208601: Introduce native oop barriers in C2 for OopHandle
    + S8209003: Consolidate use of empty collections in
    java.lang.module
    + S8209120: Archive the Integer.IntegerCache
    + S8209178: Proxied HttpsURLConnection doesn't send BODY when
    retrying POST request
    + S8209545: Simplify HeapShared::archive_module_graph_objects
    + S8209647: constantPoolHandle::constantPoolHandle(ConstantPool*)
    when precompiled header is disabled
    + S8209691: Allow MemBar on single memory slice
    + S8209771: jdk.test.lib.Utils::runAndCheckException error
    + S8209790: SA tools not providing option to connect to debug
    server
    + S8209833: C2 compilation fails with
    "assert(ex_map->jvms()->same_calls_as(_exceptions->jvms()))
    failed: all collected exceptions must come from the same
    place"
    + S8209835: Aarch64: elide barriers on all volatile operations
    + S8209972: [GRAAL] Don't run RTM tests with Graal
    + S8210158: Accessorize JFR getEventWriter() intrinsics
    + S8210384: SunLayoutEngine.isAAT() font is expensive on MacOS
    + S8210387: C2 compilation fails with
    "assert(node->_last_del == _last) failed: must have deleted
    the edge just produced"
    + S8210403: Refactor java.util.Locale:i18n shell tests to plain
    java tests
    + S8210559: ClassLoaderData Symbols can leak
    + S8210776: Upgrade X Window System 6.8.2 to the latest
    XWD 1.0.7
    + S8210789: langtools/tools/javac/T8152616.java missing @modules
    + S8211037: Load jib jars dynamically from JibArtifactManager
    + S8211147: Incorrect comparator
    com.sun.beans.introspect.MethodInfo.MethodOrder
    + S8211385: (zipfs) ZipDirectoryStream yields a stream of
    absolute paths when directory is relative
    + S8211740: [AOT] -XX:AOTLibrary doesn't accept windows path
    + S8211866: TLS 1.3 CertificateRequest message sometimes offers
    disallowed signature algorithms
    + S8211919: ZipDirectoryStream should provide a stream of paths
    that are relative to the directory
    + S8211992: GraphicsConfiguration.getDevice().getDisplayMode()
    causes JVM crash on Mac
    + S8212028: Use run-test makefile framework for testing in
    Oracle's Mach5
    + S8212071: Need to set the FreeType LCD Filter to reduce
    fringing.
    + S8212627: [TESTBUG] runtime/CreateMirror/
    /ArraysNewInstanceBug.java timed out
    + S8212673: jtreg/applications/runthese/RunThese30M.java fails
    in C2 with "assert(!had_error) failed: bad dominance"
    + S8212738: Incorrectly named signature scheme
    ecdsa_secp512r1_sha512
    + S8212752: Typo in SSL log message related to inactive/disabled
    signature scheme
    + S8213005: Missing symbols in hs_err files on Windows after
    JDK-8212028
    + S8213008: Cipher with UNWRAP_MODE should support the
    generation of an AES key type
    + S8213014: Crash in CompileBroker::make_thread due to OOM
    + S8213119: [macos] java/awt/GraphicsDevice/
    /CheckDisplayModes.java fails
    + S8213381: Hook to allow GC to inject Node::Ideal() calls
    + S8213448: [TESTBUG] enhance jfr/jvm/TestDumpOnCrash
    + S8213568: Typo in java/awt/GraphicsEnvironment/LoadLock/
    /GE_init5.java
    + S8213604: Fix missing includes after JDK-8212673
    + S8214046: [macosx] Undecorated Frame does not Iconify when
    set to
    + S8214052: [testbug] vmTestbase/vm/compiler/
    /CodeCacheInfoOnCompilation - wrong shell used
    + S8214098: sun.security.ssl.HandshakeHash.T12HandshakeHash
    constructor check backwards.
    + S8214311: dtrace gensrc has missing dependencies
    + S8214315: G1: fatal error: acquiring lock SATB_Q_FL_lock/1 out
    of order with lock tty_lock/0
    + S8214321: Misleading code in SSLCipher
    + S8214542: JFR: Old Object Sample event slow on a deep heap in
    debug builds
    + S8214750: Unnecessary <p> tags in jfr classes
    + S8214773: Replace use of thread unsafe strtok
    + S8214896: JFR Tool left files behind
    + S8214925: JFR tool fails to execute
    + S8214975: No hs-err file if fatal error is raised during
    dynamic initialization
    + S8215032: Support Kerberos cross-realm referrals (RFC 6806)
    + S8215105: java/awt/Robot/HiDPIScreenCapture/
    /ScreenCaptureTest.java: Wrong Pixel Color
    + S8215200: IllegalArgumentException in
    sun.lwawt.macosx.CPlatformWindow
    + S8215411: some GetByteArrayElements calls miss corresponding
    Release
    + S8215449: Several tests failing when jtreg run with
  - vmoption:--illegal-access=deny
    + S8215524: Finished message validation failure should be
    decrypt_error alert
    + S8215699: -Xlog::file cannot be used with named pipe
    + S8215708: ZGC: Add missing LoadBarrierNode::size_of()
    + S8215755: ZGC: split_barrier_thru_phi: check number of inputs
    of phi
    + S8215771: The jfr tool should pretty print reference chains
    + S8215913: [Test_bug]java/util/Locale/LocaleProvidersRun.java
    failed on de_DE and ja_JP locale.
    + S8216064: -XX:StartFlightRecording:settings= doesn't work
    properly
    + S8216135: C2 assert(!had_error) failed: bad dominance
    + S8216283: Allow shorter method sampling interval than 10 ms
    + S8216363: NullPointerException in
    java.util.logging.Handler#isLoggable
    + S8216426: Usage of array placement new may lead to memory
    corruption
    + S8216561: HttpClient: The logic of retry on connect exception
    is inverted
    + S8216977: ShowHiddenFrames use in
    java_lang_StackTraceElement::fill_in appears broken
    + S8217362: Emergency dump does not work when disk=false is set
    + S8217610: TLSv1.3 fail with ClassException when EC keys are
    stored in PKCS11
    + S8217731: Font rendering and glyph spacing changed from jdk-8
    to jdk-11
    + S8218468: Load barrier slow path node should be MachTypeNode
    + S8218580: endpoint identification algorithm should be
    case-insensitive
    + S8218935: Make jfr strncpy uses GCC 8.x friendly
    + S8219504: Test for JDK-8211435 can be run on all platforms
    + S8219914: Change the environment variable for Java Access
    Bridge logging to have a directory.
    + S8220175: serviceability/dcmd/framework/VMVersionTest.java
    fails with a timeout
    + S8220231: Cache HarfBuzz face object for same font's text
    layout calls
    + S8220352: Crash with assert(external_guard || result != __null)
    failed: Invalid JNI handle
    + S8220394: bufferedStream does not honor size limit
    + S8220474: Incorrect GPL header in src/java.instrument/share/
    /classes/java/lang/instrument/package-info.java
    + S8220476: Incorrect GPL header in src/jdk.internal.jvmstat/
    /share/classes/sun/jvmstat/perfdata/monitor/protocol/local/
    /PerfDataFile.java
    + S8220528: [AIX] Fix basic Xinerama and Xrender functionality
    + S8220555: JFR tool shows potentially misleading message when
    it cannot access a file
    + S8220598: Malformed copyright year range in a few files in
    java.base
    + S8221092: UseAVX=3 has performance degredation on Skylake (X7)
    processors
    + S8221172: SunEC specific test is not limited to SunEC
    + S8221246: NullPointerException within Win32ShellFolder2
    + S8221395: HttpClient leaving connections in CLOSE_WAIT state
    until Java process ends
    + S8221406: Windows 32bit build error in
    NetworkInterface_winXP.c
    + S8221456: nmethod::make_unloaded() clears _method member too
    early
    + S8221532: Incorrect copyright header in FileSystemSupport_md.c
    + S8221539: [metaspace] Improve MetaspaceObj::is_metaspace_obj()
    and friends
    + S8221569: JFR tool produces incorrect output when both
  - -categories and --events are specified
    + S8221711: [TESTBUG] create more tests for JFR in container
    environment
    + S8221913: Add GC.selected() jtreg-ext function
    + S8222015: Small VM.metaspace improvements
    + S8222440: (zipfs) JarFileSystem does not correctly handle
    versioned entries if no root entry is present
    + S8222529: sun.jdwp.listenerAddress agent property uses wrong
    encoding
    + S8222807: Address iteration with invalid ZIP header entries
    + S8222888: [TESTBUG] docker/TestJFREvents.java fails due to
    "RuntimeException: JAVA_MAIN_CLASS_ is not defined"
    + S8223438: add VirtualizationInformation JFR event
    + S8223490: Optimize search algorithm for determining default
    time zone
    + S8223697: jfr tool can't format duration values greater than
    minute
    + S8223869: Problem list java/awt/FontMetrics/
    /MaxAdvanceIsMax.java on more platforms
    + S8224152: [macOS] ProblemList tests that leave rubbish on the
    screen
    + S8224157: BCEL: update to version 6.3.1
    + S8224172: assert(jfr_is_event_enabled(id)) failed: invariant
    + S8224193: stringStream should not use Resouce Area
    + S8224217: RecordingInfo should use textual representation of
    path
    + S8224502: [TESTBUG] JDK docker test TestSystemMetrics.java
    fails with access issues and OOM
    + S8224505: TestQuotedLogOutput failure after ProcessBuilder
    changes
    + S8224538: LoadBarrierNode::common_barrier must check address
    + S8224958: add os::dll_load calls to event log
    + S8225101: Crash at sun.awt.X11.XlibWrapper.XkbGetUpdatedMap
    when change keybord map
    + S8225225: stringStream internal buffer should always be zero
    terminated
    + S8225392: Comparison builds are failing due to cacerts file
    + S8225505: ctrl-F1 does not show the tooltip of a menu item
    (JMenuItems)
    + S8225694: Destination option missing in
    FlightRecorderMXBeanImpl
    + S8225695: 32-bitbuild failures after JDK-8080462 (Update
    SunPKCS11 provider with PKCS11 v2.40 support)
    + S8225745: NoSuchAlgorithmException exception for
    SHA256withECDSA with RSASSA-PSS support
    + S8226513: JEditorPane is shown with incorrect size
    + S8226651: Setting the mgfHash in CK_RSA_PKCS_PSS_PARAMS has no
    effect
    + S8226719: Kerberos login to Windows 2000 failed with
    "Inappropriate type of checksum in message"
    + S8226779: [TESTBUG] Test JFR API from Java agent
    + S8226869: Testjava/util/Locale/LocaleProvidersRun.java should
    enable assertions
    + S8226899: Problemlist compiler/rtm tests
    + S8227031: Print NMT statistics on fatal errors
    + S8227032: MetaspaceUtils::print_report crashes when called
    before initialization
    + S8227035: JVM::printFlags fails in native OOM situations
    + S8227061: KDC.java test behaves incorrectly when AS-REQ
    contains a PAData not PA-ENC-TS-ENC
    + S8227086: Use AS_NO_KEEPALIVE loads in HeapDumper
    + S8227127: Era designator not displayed correctly using the
    COMPAT provider
    + S8227338: templateInterpreter.cpp: copy_table() needs to be
    safer
    + S8227368: EnumSet.class serialization broken in JDK 9+
    + S8227381: GSS login fails with PREAUTH_FAILED
    + S8227391: Update double-conversion to version 3.1.5
    + S8227397: Add --with-extra-asflags configure option
    + S8227411: TestTimeMultiple.java failed "assert(!lease())
    failed: invariant"
    + S8227435: Perf::attach() should not throw a java.lang.Exception
    + S8227437: S4U2proxy cannot continue because server's TGT
    cannot be found
    + S8227439: Turn off AOT by default
    + S8227605: Kitchensink fails "assert((((klass)->trace_id() &
    (JfrTraceIdEpoch::leakp_in_use_this_epoch_bit())) != 0))
    failed: invariant"
    + S8227642: [TESTBUG] Make docker tests podman compatible
    + S8228368: avoid incompatible pointer to integer conversion
    initializing gint in gtk2_interface
    + S8228434: jdk/net/Sockets/Test.java fails after JDK-8227642
    + S8228465: HOST locale provider holds wrong era name for
    GregorianCalendar in US locale
    + S8228625: [TESTBUG] sun/tools/jhsdb/JShellHeapDumpTest.java
    fails with RuntimeException 'JShellToolProvider' missing from
    stdout/stderr
    + S8228645: Don't run sun/security/pkcs11/Cipher/
    /TestKATForGCM.java on buggy NSS solaris versions
    + S8228687: [TESTBUG] exclude Container tests from hotspot_misc
    group
    + S8228772: C2 compilation fails due to unschedulable graph if
    DominatorSearchLimit is reached
    + S8228834: Regression caused by JDK-8214542 not installing
    complete checkpoint data to candidates
    + S8228835: Memory leak in PKCS11 provider when using AES GCM
    + S8228888: C2 compilation fails with assert "m has strange
    control"
    + S8228902: add os::dll_load to the unified logging os category
    + S8229016: C2 scalarization crashes with assert(node->Opcode()
    == Op_CastP2X) failed: ConvP2XNode required
    + S8229020: Failure on CPUs allowing loads reordering:
    assert(_tasks[t] == 1) failed: What else?
    + S8229022: BufferedReader performance can be improved by using
    StringBuilder
    + S8229156: ProblemList gc/stress/gclocker/
    /TestExcessGCLockerCollections.java
    + S8229169: False failure of GenericTaskQueue::pop_local on
    architectures with weak memory model
    + S8229182: runtime/containers/docker/TestMemoryAwareness.java
    test fails on SLES12
    + S8229243: SunPKCS11-Solaris provider tests failing on
    Solaris 11.4
    + S8229284: jdk/internal/platform/cgroup/TestCgroupMetrics.java
    fails for - memory:getMemoryUsage
    + S8229408: Bump update version for OpenJDK: jdk-11.0.6
    + S8229420: [Redo] jstat reports incorrect values for OU for
    CMS GC
    + S8229437: assert(is_aligned(ref, HeapWordSize)) failed:
    invariant
    + S8229450: C2 compilation fails with assert(found_sfpt) failed
    + S8229483: Sinking load out of loop may trigger:
    assert(found_sfpt) failed: no node in loop that's not input to
    safepoint
    + S8229496: SIGFPE (division by zero) in C2 OSR compiled method
    + S8229515: [macos] access to window property of NSView on wrong
    thread
    + S8229701: aarch64: C2 OSR compilation fails with "shouldn't
    process one node several times" in final graph reshaping
    + S8229800: WindowsServerCore 1809 does not provide d2d1.dll
    library required by awt.dll
    + S8229810: [macos] NullPointerException getting bounds of
    GraphicsConfiguration
    + S8229872: (fs) Increase buffer size used with getmntent
    + S8229899: Make java.io.File.isInvalid() less racy
    + S8230061: # assert(mode == ControlAroundStripMined
    && use == sfpt) failed: missed a node
    + S8230062: assert(i == p->size()-1) failed: must be last
    element of the pack
    + S8230110: TestLinkageErrorInGenerateOopMap times out
    + S8230115: Problemlist JFR TestNetworkUtilization test
    + S8230238: Add another regression test for JDK-8134739
    + S8230303: JDB hangs when running monitor command
    + S8230363:C2: Let ConnectionGraph::not_global_escape(Node* n)
    return false if n is not in the CG
    + S8230376: [TESTBUG] runtime/StackTrace/HiddenFrameTest.java
    fails with release VM
    + S8230388: Problemlist additional compiler/rtm tests
    + S8230466: check malloc/calloc results in jdk.hotspot.agent
    + S8230646: Epsilon does not extend TLABs to max size
    + S8230669: [s390] C1: assert(is_bound() || is_unused()) failed:
    Label was never bound to a location, but it was used as a jmp
    target
    + S8230671: x86_32 build failures after JDK-8229496
    + S8230711: ConnectionGraph::unique_java_object(Node* N) return
    NULL if n is not in the CG
    + S8230728: Thin stroked shapes are not rendered if affine
    transform has flip bit
    + S8230769: BufImg_SetupICM add ReleasePrimitiveArrayCritical
    call in early return
    + S8230782: Robot.createScreenCapture() fails if "awt.robot.gtk"
    is set to false
    + S8230813: Add JDK-8010500 to compiler/loopopts/superword/
    /TestFuzzPreLoop.java bug list
    + S8230856: Java_java_net_NetworkInterface_getByName0 on unix
    misses ReleaseStringUTFChars in early return
    + S8230861: missing ReleaseStringUTFChars in
    Java_sun_security_pkcs11_wrapper_PKCS11_connect
    + S8230873: [AIX] GUI app does not work with UTF-8 locale on
    minimum software requirements
    + S8230881: serviceability/sa/TestJmapCore tests fail with
    java.lang.RuntimeException: Could not find dump file
    + S8230900: missing ReleaseStringUTFChars in java.desktop native
    code
    + S8230901: missing ReleaseStringUTFChars in serviceability
    native code
    + S8230923: SunJSSE is not properly initialized in FIPS mode
    from a configuration file
    + S8230943: False deadlock detection with
  - XX:+CIPrintCompileQueue after JDK-8163511
    + S8231055: C2: arraycopy with same non escaping src and dest
    but different positions causes wrong execution
    + S8231084: Large performance regression in SwingMark TextArea
    in 14-b13
    + S8231085: C2/GC: Better GC-interface for expanding clone
    + S8231098: (tz) Upgrade time-zone data to tzdata2019c
    + S8231124: Missing closedir call with JDK-8223490
    + S8231201: hs_err should print coalesced safepoint operations
    in Events section
    + S8231222: fix pkcs11 P11_DEBUG guarded native traces
    + S8231223: C2's conditional move optimization fails with
    assert(bol->Opcode() == Op_Bool) failed
    + S8231247: (zipfs) Test failure in jdk/nio/zipfs/
    /InvalidZipHeaderTests.java after backport of JDK-8222807
    + S8231254: (fs) Add test for macOS Catalina changes to protect
    system software
    + S8231294: ZGC: vmTestbase/nsk/jvmti/ResourceExhausted/
    /resexhausted002 fails
    + S8231296: ZGC: vmTestbase/nsk/jvmti/Allocate/alloc001/ fails
    + S8231318: Several compiler/aot tests fail for JDK11 on Windows
    when only MSVC 2017 is installed
    + S8231336: Corrupted option dialog in JTHarness with JDK14b13
    + S8231403: [ppc]: Align ReservedCodeCacheSize default value
    with other platforms
    + S8231457: Asserts on AIX because os::elapsed_counter() is not
    monotonic
    + S8231503: [TESTBUG] compiler/{jvmci,aot} tests should not run
    with GCs that do not support JVMCI/AOT
    + S8231620: assert(bol->is_Bool()) crash during split if due to
    FastLockNode
    + S8231665: 8231055 broke escapeAnalysis/TestSelfArrayCopy.java
    + S8231693: Backout "8230728: Thin stroked shapes are not
    rendered if affine transform has flip bit" from jdk11u
    + S8231751: on aix handle Power 9 in os::get_summary_cpu_info
    + S8231770: Test java/util/zip/FlaterTest.java fails with
  - Xcheck:jni
    + S8231885: Fix/remove malformed assert in os_windows.cpp
    + S8231887: ComodoCA.java fails because certificate was revoked
    + S8231930: Windows build fails after JDK-8191521
    + S8231949: [PPC64, s390]: Make async profiling more reliable
    + S8231988: Unexpected test result caused by C2
    IdealLoopTree::do_remove_empty_loop
    + S8231991: Mouse wheel change focus on awt/swing windows
    + S8232005: [s390, PPC64] More exception checks missing in
    interpreter
    + S8232019: Add LuxTrust certificate updates to the existing
    root program
    + S8232051: Epsilon should warn about Xms/Xmx/AlwaysPreTouch
    configuration
    + S8232052: use string literal for format string when handling
    PauseAtStartupFile
    + S8232178: MacVolumesTest failed after upgrade to MacOS
    Catalina
    + S8232381: add result NULL-checking to freetypeScaler.c
    + S8232539: SIGSEGV in C2 Node::unique_ctrl_out
    + S8232592: <Unknown compiled code> is shown in jstack mixed
    mode
    + S8232874: Add missing test for 8230062
    + S8232879: Writing out data with the Zip File System leads to
    a CRC failure
    + S8232984: Upgrading Joni License version to 2.1.16
    + S8233075: JFR - nmetods - misspelled in several places
    + S8233081: C1: PatchingStub for field access copies too much
    + S8233097: Fontmetrics for large Fonts has zero width
    + S8233202: exclude javax/swing/plaf/basic/BasicGraphicsUtils/
    /8132119/bug8132119.java
    + S8233203: fix non-product build on AIX when compiling with
    xlc16/legacy-xlc
    + S8233223: Add Amazon Root CA certificates
    + S8233404: System property to set the number of PBE iterations
    in JCEKS keystores
    + S8233820: Test crashed with assert(phi->operand_count() != 1
    || phi->subst() != phi) failed: missed trivial simplification
    + S8233839: aarch64: missing memory barrier in
    NewObjectArrayStub and NewTypeArrayStub
    + S8233886: TEST_BUG jdk/java/net/CookieHandler/B6791927.java
    hit hardcoded expiration date
    + S8233944: Make KerberosPrincipal.KRB_NT_ENTERPRISE field
    package private
    + S8233954: UnsatisfiedLinkError or NoSuchAlgorithmException
    after removing sunec.dll
    + S8234080: jdk/nio/zipfs/CRCWriteTest.java fails
    + S8234107: Several AWT modal dialog tests failing on Linux
    after JDK-8231991
    + S8234245: sun/security/lib/cacerts/VerifyCACerts.java fails
    due to wrong checksum
    + S8234321: Call cache flush after generating trampoline.
    + S8234591: [11u] Build with old C compiler broken by 8223490
    + S8234625: hs test serviceability/sa/ClhsdbCDSCore.java fails
    on macOS 10.15
    + S8234645: ARM32: C1: PatchingStub for field access: not enough
    bytes
    + S8234906: [TESTBUG] TestDivZeroCheckControl fails for client
    VMs due to Unrecognized VM option LoopUnrollLimit
    + S8235142: JDK-8193255 backport broke bootstrap with JDK 10
    + S8235403: Further cleanup to test
    serviceability/sa/ClhsdbCDSCore.java
    + S8235585: Enable macOS codesigning for all libraries and
    executables
    + S8235687: Contents/MacOS/libjli.dylib cannot be a symlink
* Tue Dec 17 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Switch back armv6 from zero platform to client JVM
* Wed Oct 23 2019 Fridrich Strba <fstrba@suse.com>
- Update to upstream tag jdk-11.0.5-10 (October 2019 CPU,
  bsc#1154212)
  * Security fixes:
    + S8209901: Canonical file handling
    + S8213429, CVE-2019-2933: Windows file handling redux
    + S8218573, CVE-2019-2945: Better socket support
    + S8218877: Help transform transformers
    + S8219914: Change the environment variable for Java Access
    Bridge logging to have a directory.
    + S8220186: Improve use of font temporary files
    + S8220302, CVE-2019-2949: Better Kerberos ccache handling
    + S8221497: Optional Panes in Swing
    + S8221858, CVE-2019-2958: Build Better Processes
    + S8222684, CVE-2019-2964: Better support for patterns
    + S8222690, CVE-2019-2962: Better Glyph Images
    + S8223163: Better pattern recognition
    + S8223505, CVE-2019-2973: Better pattern compilation
    + S8223518, CVE-2019-2975: Unexpected exception in jjs
    + S8223886: Add in font table referene
    + S8223892, CVE-2019-2978: Improved handling of jar files
    + S8224025: Fix for JDK-8220302 is not complete
    + S8224062, CVE-2019-2977: Improve String index handling
    + S8224532, CVE-2019-2981: Better Path supports
    + S8224915, CVE-2019-2983: Better serial attributes
    + S8225286, CVE-2019-2987: Better rendering of native glyphs
    + S8225292, CVE-2019-2988: Better Graphics2D drawing
    + S8225298, CVE-2019-2989: Improve TLS connection support
    + S8225597, CVE-2019-2992: Enhance font glyph mapping
    + S8226765, CVE-2019-2999: Commentary on Javadoc comments
    + S8227601: Better collection of references
    + S8228825, CVE-2019-2894, bsc#1152856: Enhance ECDSA operations
  * Other fixes:
    + S6996807: FieldReflectorKey hash code computation can be
    improved
    + S8076988: reevaluate trivial method policy
    + S8087128: C2: Disallow definition split on MachCopySpill nodes
    + S8133489: Better messaging for PKIX path validation matching
    + S8139965: Hang seen when using
    com.sun.jndi.ldap.search.replyQueueSize
    + S8147502: Digest is incorrectly truncated for ECDSA
    signatures when the bit length of n is less than the field
    size
    + S8148188: Enhance the security libraries to record events of
    interest
    + S8163363: AArch64: Stack size in tools/launcher/Settings.java
    needs to be adjusted
    + S8163511: Allocation of compile task fails with assert:
    "Leaking compilation tasks?"
    + S8170639: [Linux] jsig is limited to a maximum of 64 signals
    + S8177899: Tests fail due to code cache exhaustion on machines
    with many cores
    + S8180901: Transformer.reset() resets the state only once
    + S8193234: When using -Xcheck:jni an internally allocated
    buffer can leak
    + S8194231: java/net/DatagramSocket/ReuseAddressTest.java
    failed with java.net.BindException: Address already in use:
    Cannot bind
    + S8196681: Java Access Bridge logging and debug flags
    dynamically controlled
    + S8198411: [TEST_BUG] Two java2d tests are unstable in mach5
    + S8200365: TestOptionsWithRanges.java of
    '-XX:TLABWasteTargetPercent=100' fails intermittently
    + S8200400: Restrict Sasl mechanisms
    + S8202035: Archive the set of ModuleDescriptor and
    ModuleReference objects for observable system modules with
    unnamed initial module.
    + S8202252: (aio) Closed AsynchronousSocketChannel keeps
    completion handler alive
    + S8202952: C2: Unexpected dead nodes after matching
    + S8203629: Produce events in the JDK without a dependency on
    jdk.jfr
    + S8204203: Many pkcs11 tests failed in Provider
    initialization, after compiler on Windows changed
    + S8204521: compiler/jsr292/
    /RedefineMethodUsedByMultipleMethodHandles.java fails trying
    to delete temp file
    + S8205421: AARCH64: StubCodeMark should be placed after
    alignment
    + S8205654: serviceability/dcmd/framework/HelpTest.java timed
    out
    + S8206074: nsk/jdi/EventRequestManager/createStepRequest/
    /crstepreq001/TestDescription.java is timing out
    + S8206879: Currency decimal marker incorrect for Peru
    + S8207965: C2-only debug build fails
    + S8208269: Javadoc does not support module-info in a
    multi-release jar
    + S8208499: NMT: Missing memory tag for Safepoint polling page
    + S8208655: use JTreg skipped status in hotspot tests
    + S8208701: Fix for JDK-8208655 causes test failures in CI tier1
    + S8208706: compiler/tiered/ConstantGettersTransitionsTest.java
    fails to compile
    + S8208780: (se) test
    SelectWithConsumer.testReadableAndWriteable(): failure
    + S8209186: Rename SimpleThresholdPolicy to
    TieredThresholdPolicy
    + S8209413: AArch64: NPE in clhsdb jstack command
    + S8209420: Track membars for volatile accesses so they can be
    properly optimized
    + S8209684: Intrinsics that assume some input non null should
    use GraphKit::must_be_not_null()
    + S8209939: [testbug][ppc] Test SafepointPollingPages fails
    after 8208499 with UseSIGTRAP on.
    + S8210063: ZGC: Enable load barriers for IN_NATIVE runtime
    barriers
    + S8210130: java/net/httpclient/UnknownBodyLengthTest.java
    failed
    + S8210314: [aix] NMT does not show "Safepoint" memory type
    + S8210389: C2: assert(n->outcnt() != 0 || C->top() == n ||
    n->is_Proj()) failed: No dead instructions after post-alloc
    + S8210390: C2 still crashes with "assert(mode ==
    ControlAroundStripMined && use == sfpt) failed: missed a node"
    + S8210408: Refactor java.util.ResourceBundle:i18n shell tests
    to plain java tests
    + S8210729: Clean up macosx static library handling
    + S8210919: Remove statically linked libjli on Windows
    + S8210926: vmTestbase/nsk/jvmti/scenarios/allocation/AP11/
    /ap11t001/TestDescription.java failed with
    JVMTI_ERROR_INVALID_CLASS in CDS mode
    + S8210985: Update the default SSL session cache size to 20480
    + S8211097: aix: fix build after JDK-8210919
    + S8211232: GraphKit::make_runtime_call() sometimes attaches
    wrong memory state to call
    + S8211233: MemBarNode::trailing_membar() and
    MemBarNode::leading_membar() need to handle dying subgraphs
    better
    + S8211727: Adjust default concurrency settings for running
    tests on Sparc
    + S8212528: Wrong cgroup subsystem being used for some CPU
    Container Metrics
    + S8212970: TZ database in "vanguard" format support
    + S8212992: Change mirror accessor in Klass::verify_on() to use
    AS_NO_KEEPALIVE
    + S8213017: jspawnhelper: need to handle pipe write failure
    when sending return code
    + S8213117: adoptNode corrupts attribute values
    + S8213134: AArch64: vector shift failed with MaxVectorSize=8
    + S8213172: CDS and JFR tests fail with
    assert(JdkJfrEvent::is(klass)) failed: invariant
    + S8213325: (props) Properties.loadFromXML does not fully
    comply with the spec
    + S8213406: (fs) More than one instance of built-in FileSystem
    observed in heap
    + S8213561: ZipFile/MultiThreadedReadTest.java timed out in
    tier1
    + S8213734: SAXParser.parse(File, ..) does not close resources
    when Exception occurs.
    + S8214003: Limit default test jobs based on memory size
    + S8214096: sun.security.util.SignatureUtil passes null
    parameter, so JCE validation fails
    + S8214161: java.lang.IllegalAccessError: class
    jdk.internal.event.X509CertificateEvent (in module java.base)
    cannot access class jdk.jfr.internal.handlers.EventHandler
    (in module jdk.jfr) because module java.base does not read
    module jdk.jfr
    + S8214287: SpecJbb2005StressModule got uncaught exception
    + S8214579: JFrame does not paint content in XVFB / X11vnc
    environment
    + S8214687: Optimize Collections.nCopies().hashCode() and
    equals()
    + S8214702: Wrong text position for whitespaced string in
    printing Swing text
    + S8214770: java/time/test/java/time/format/
    /TestNonIsoFormatter.java failed in non-english locales.
    + S8214777: Avoid some GCC 8.X strncpy() errors in HotSpot
    + S8214857: "bad trailing membar" assert failure at
    memnode.cpp:3220
    + S8215044: C2 crash in loopTransform.cpp with
    assert(cl->trip_count() > 0) failed: peeling a fully unrolled
    loop
    + S8215130: Fix errors in LittleCMS 2.9 reported by GCC 8
    + S8215265: C2: range check elimination may allow illegal out
    of bound access
    + S8215281: Use String.isEmpty() when applicable in java.base
    + S8215380: Backout accidental change to String::length
    + S8215451: JNI IsSameObject should not keep objects alive
    + S8215483: Off heap memory accesses should be vectorized
    + S8215505: Cleanup jvm.cpp obsolete code after JDK-8210094:
    Better loading of classloader classes
    + S8215534: [testbug] some jfr test don't check @requires
    vm.hasJFR
    + S8215694: keytool cannot generate RSASSA-PSS certificates
    + S8215756: Memory leaks in the AWT on macOS
    + S8215792: AArch64: String.indexOf generates incorrect result
    + S8215879: AArch64: ReservedStackAccess may leave stack guard
    in inconsistent state
    + S8215901: [TESTBUG] TestCheckedEnsureLocalCapacity.java fails
    intermittently
    + S8215961: jdk/jfr/event/os/TestCPUInformation.java fails on
    AArch64
    + S8215982: (tz) Upgrade time-zone data to tzdata2018i
    + S8216039: TLS with BC and RSASSA-PSS breaks
    ECDHServerKeyExchange
    + S8216046: test/jdk/java/beans/PropertyEditor/Test6397609.java
    failing
    + S8216155: C4819 warning at libfreetype sources on Windows
    + S8216199: Local variable arg defined but never used in
    BCEscapeAnalyzer::compute_escape_for_intrinsic()
    + S8216205: Java API documentation formatting error in
    System.getEnv
    + S8216261: Javap ignores default modifier on interfaces
    + S8216326: SSLSocket stream close() does not close the
    associated socket
    + S8216375: Revert JDK-8145579 after JDK-8076988 is resolved
    + S8216401: Allow "file:" URLs in Class-Path of local JARs
    + S8216427: ciMethodData::load_extra_data() does not always
    unpack the last entry
    + S8216528: test/jdk/java/rmi/transport/
    /runtimeThreadInheritanceLeak/
    /RuntimeThreadInheritanceLeak.java failing with Xcomp
    + S8216549: Mismatched unsafe access to non escaping object
    fails
    + S8216562: UnknownBodyLength sometimes fails due to
    "Connection reset by peer"
    + S8216987: ciMethodData::load_data() unpacks MDOs with
    non-atomic copy
    + S8216989: CardTableBarrierSetAssembler::gen_write_ref_array_post_barrier()
    does not check for zero length on AARCH64
    + S8217093: Support extended-length paths in parse_manifest.c
    on windows
    + S8217344: Make comparison overflow-aware in
    ECDHKeyAgreement.engineGenerateSecret()
    + S8217359: C2 compiler triggers SIGSEGV after transformation
    in ConvI2LNode::Ideal
    + S8217364: Custom URLStreamHandler for jrt or file protocol
    can override default handler
    + S8217366: ZoneStrings are not populated for all the Locales
    + S8217368: AArch64: C2 recursive stack locking optimisation
    not triggered
    + S8217371: Incorrect LP64 guard in x86.ad after JDK-8210764
    (Update avx512 implementation)
    + S8217576: C1 atomic access handlers use incorrect decorators
    + S8217676: Upgrade libpng to 1.6.37
    + S8217760: C2: Missing symbolic info on a call from intrinsics
    when invoked through MethodHandle
    + S8217766: Container Support doesn't work for some Join
    Controllers combinations
    + S8217785: Padding
    ParallelTaskTerminator::_offered_termination variable
    + S8217896: Make better use of LCPUs when building on AIX
    + S8217990: C2 UseOptoBiasInlining: load of markword optimized
    to 0 if running with -XX:-EliminateLocks
    + S8218163: C2: Continuous deoptimization w/
    Reason_speculate_class_check and Action_none
    + S8218185: aarch64: missing LoadStore barrier in
    TemplateTable::putfield_or_static
    + S8218201: Failures when vmIntrinsics::_getClass is not inlined
    + S8218280: LineNumberReader throws "Mark invalid" exception if
    CRLF straddles buffer.
    + S8218553: Enhance keystore load debug output
    + S8218558: NMT stack traces in output should show mt component
    for virtual memory allocations
    + S8218566: NMT: missing memory tag for assert poison page
    + S8218581: Incorrect exception message generation
    + S8218682: [TEST_BUG] DashOffset fails in mach5
    + S8218705: Test sun/tools/jcmd/TestJcmdDefaults.java fails on
    Linux
    + S8218715: [TESTBUG]
    TestUseOptoBiasInliningWithoutEliminateLocks needs to unlock
    WhiteBoxAPI
    + S8218721: C1's CEE optimization produces safepoint poll with
    invalid debug information
    + S8218723: Use SunJCE Mac in SecretKeyFactory PBKDF2
    implementation
    + S8218780: Update MUSCLE PCSC-Lite header files
    + S8218879: Keep track of memory accesses originated from Unsafe
    + S8218966: AArch64: String.compareTo() can read memory after
    string
    + S8219013: Update Apache Santuario (XML Signature) to version
    2.1.3
    + S8219241: Provide basic virtualization related info in the
    hs_error file on linux/windows x86_64
    + S8219244: NMT: Change ThreadSafepointState's allocation type
    from mtInternal to mtThread
    + S8219370: NMT: Move synchronization primitives from
    mtInternal to mtSynchronizer
    + S8219513: compiler/codegen/aes/
    /TestCipherBlockChainingEncrypt.java timeout on Solaris-sparc
    + S8219517: assert(false) failed: infinite loop in
    PhaseIterGVN::optimize
    + S8219562: Line of code in osContainer_linux.cpp L102 appears
    unreachable
    + S8219583: Windows build failure after JDK-8214777 (Avoid some
    GCC 8.X strncpy() errors in HotSpot)
    + S8219635: aarch64: missing LoadStore barrier in
    TemplateTable::fast_storefield
    + S8219807: C2 crash in IfNode::up_one_dom(Node*, bool)
    + S8219919: RuntimeStub name lost with
    PrintFrameConverterAssembly
    + S8219993: AArch64: Compiled CI stubs are unsafely modified
    + S8219997: [TESTBUG] Create test for JFR events in Docker
    container: CPU, Memory and Process Info
    + S8220037: Inconsistencies of generated timezone files between
    Windows and Linux
    + S8220072: GCC 8.3 reports errors in java.base
    + S8220173: assert(_handle_mark_nesting > 1) failed: memory
    leak: allocating handle outside HandleMark
    + S8220227: Host Locale Provider getDisplayCountry returns
    error message under non-English Win10
    + S8220313: [TESTBUG] Update base image for Docker testing to
    OL 7.6
    + S8220341: Class redefinition fails with
    assert(!is_unloaded()) failed: unloaded method on the stack
    + S8220355: Improve assertion texts and exception messages in
    eventHandlerVMInit
    + S8220570: Additonal trace when native thread creation fails
    + S8220579: [Containers] SubSystem.java out of sync with
    osContainer_linux.cpp
    + S8220657: JFR.dump does not work when filename is set
    + S8220672: [TESTBUG] TestCPUSets should check that cpuset does
    not exceed available cores
    + S8220674: [TESTBUG] MetricsMemoryTester failcount test in
    docker container only works with debug JVMs
    + S8220682: Heap dumping and inspection fails with JDK-8214712
    + S8220690: ATTRIBUTE_ALIGNED requires GNU extensions enabled
    + S8221120: CopyOnWriteArrayList.set should always have
    volatile write semantics
    + S8221220: AArch64: Add StoreStore membar explicitly for
    Volatile Writes in TemplateTable
    + S8221253: TLSv1.3 may generate TLSInnerPlainText longer than
    2^14+1 bytes
    + S8221325: Add information about swap space to
    print_memory_info() on MacOS
    + S8221340: [TESTBUG] TestCgroupMetrics.java fails after fix
    for JDK-8219562
    + S8221342: [TESTBUG] Generate Dockerfile for docker testing
    + S8221407: Windows 32bit build error in
    libsunmscapi/security.cpp
    + S8221408: Windows 32bit build build errors/warnings in hotspot
    + S8221411: NullPointerException in RasterPrinterJob without
    PrinterResolution
    + S8221434: Fix typo in lib-x11 autoconf error message about
    missing headers
    + S8221480: jcmd VM.metaspace shall print limits in basic mode
    + S8221497: Optional Panes in Swing
    + S8221527: [TESTBUG] DockerBasicTest.java contains hard-coded
    reference to JDK 10
    + S8221529: [TESTBUG] Docker tests use old/deprecated image on
    AArch64
    + S8221710: [TESTBUG] more configurable parameters for docker
    testing
    + S8221725: AArch64 build failures after JDK-8221408 (Windows
    32bit build build errors/warnings in hotspot)
    + S8221730: jcmd process name matching broken
    + S8221801: Update src/java.base/share/legal/public_suffix.md
    + S8221892: ThreadPoolExecutor: Thread.isAlive() is not
    equivalent to not being startable
    + S8221894: Add comments for docker tests in the test doc
    + S8222108: Reduce minRefreshTime for updating remote printer
    list on Windows
    + S8222154: upgrade gtest to 1.8.1
    + S8222280: Provide virtualization related info in the hs_error
    file on AIX
    + S8222299: [TESTBUG] move hotspot container tests to
    hotspot/containers
    + S8222362: Upgrade to Freetype 2.10.0
    + S8222387: Out-of-bounds access to CPU _family_id_xxx array
    + S8222415: Xerces 2.12.0: Parsing Configuration
    + S8222670: pathological case of JIT recompilation and code
    cache bloat
    + S8222720: Provide extended VMWare/vSphere virtualization
    related info in the hs_error file on linux/windows x86_64
    + S8222743: Xerces 2.12.0: DOM Implementation
    + S8222914: Partial backport of JDK-8218266
    + S8222968: ByteArrayPublisher is not thread-safe resulting in
    broken re-use of HttpRequests
    + S8222980: Upgrade IANA Language Subtag Registry to Version
    2019-04-03
    + S8222987: sun/security/tools/keytool/PSS.java times out on
    Solaris-SPARC
    + S8222991: Xerces 2.12.0: Validation
    + S8223177: Data race on JvmtiEnvBase::_tag_map in
    double-checked locking
    + S8223227: Rename acquire_tag_map() to tag_map_acquire() in
    jvmtiEnvBase
    + S8223244: Fix usage of ARRAYCOPY_DISJOINT decorator
    + S8223336: Assert in
    VirtualMemoryTracker::remove_released_region when running the
    SharedArchiveConsistency.java test with
  - XX:NativeMemoryTracking=detail
    + S8223482: Unsupported ciphersuites may be offered by a TLS
    client
    + S8223518: Unexpected exception in jjs
    + S8223537: testlibrary_tests/ctw/ClassesListTest.java fails
    with Agent timeout frequently
    + S8223553: Fix code constructs that do not compile with the
    Eclipse Java Compiler
    + S8223572: ~ThreadInVMForHandshake() should call
    handle_special_runtime_exit_condition()
    + S8223574: add more thread-related system settings info to
    hs_error file on AIX
    + S8223660: jtreg: Decouple Unsafe from RTM tests
    + S8223814: SA: jhsdb common help needs to be more detailed
    + S8223886: Add in font table referene
    + S8224033: os::snprintf should be used in
    virtualizationSupport.cpp
    + S8224034: [TESTBUG] runtime/ErrorHandlerTest/ErrorHandler
    fails intermittently for case 13 on Windows
    + S8224090: [PPC64] Fix SLP patterns for filling an array with
    double float literals
    + S8224165: [TESTBUG] Docker tests produce excessive output
    + S8224181: On child process spawn, child may write to random
    file descriptor instead of the fail pipe
    + S8224202: Speed up Properties.load
    + S8224221: add memprotect calls to event log
    + S8224230: [PPC64, s390] Support AsyncGetCallTrace
    + S8224252: [TESTBUG]
    hotspot/test/serviceability/sa/sadebugd/SADebugDTest.java is
    timing out again after fix for JDK-8163805
    + S8224487: outputStream should not be copyable
    + S8224531: SEGV while collecting Klass statistics
    + S8224558: Fix replicateB encoding
    + S8224560: (tz) Upgrade time-zone data to tzdata2019a
    + S8224580: Matcher can cause oop field/array element to be
    reloaded
    + S8224589: Improve startup behavior of SecurityProperties
    + S8224658: Unsafe access C2 compile fails with assert(flat !=
    TypePtr::BOTTOM) failed: cannot alias-analyze an untyped ptr:
    adr_type = NULL
    + S8224698: ConcurrentSkipListMap.java does not compile with
    the Eclipse Java Compiler
    + S8224825: java/awt/Color/AlphaColorTest.java fails in
    linux-x64 system
    + S8224838: Bump update version for OpenJDK: jdk-11.0.5
    + S8224991: Problemlist
    javax/net/ssl/ServerName/SSLEngineExplorerMatchedSNI.java
    + S8225005: Xerces 2.12.0: License file
    + S8225141: Better handling of classes in error state in fast
    class initialization checks
    + S8225178: [Solaris] os::signal() should call sigaction() with
    SA_SIGINFO
    + S8225189: Multiple JNI calls within critical region in ZIP
    Library
    + S8225257: sun/security/tools/keytool/PSS.java timed out
    + S8225286: Better rendering of native glyphs
    + S8225298: Improve TLS connection support
    + S8225347: [s390] Unexpected exit from stack overflow test
    + S8225386: test for JDK-8216261 fails in Windows
    + S8225388: Running jcmd Compiler.CodeHeap_Analytics all 0
    cause crash.
    + S8225390: ProblemList sun/security/pkcs11/sslecc/
    /ClientJSSEServerJSSE.java due to JDK-8161536
    + S8225423: GTK L&F: JSplitPane: There is no divider shown
    + S8225425: java.lang.UnsatisfiedLinkError: net.dll: Can't find
    dependent libraries
    + S8225543: Jcmd fails to attach to the Java process on Linux
    using the main class name if whitespace options were used to
    launch the process
    + S8225580: tzdata2018i integration causes test failures on
    jdk-13
    + S8225636: SA can't handle prelinked libraries
    + S8225644: C1 dumps incorrect class name in ClassCastException
    message
    + S8225663: [testbug] Missing JNIEXPORT in XAbortProvoker
    native function
    + S8225715: jhsdb jmap fails to write binary heap dump of a
    jshell process
    + S8226409: Enable argument profiling for
    sun.misc.Unsafe.put*/get*
    + S8226468: [aix] loadquery failed error message displayed
    + S8226530: ZipFile reads wrong entry size from ZIP64 entries
    + S8226543: Reduce GC pressure during message digest
    calculations in password-based encryption
    + S8226607: Inconsistent info between pcsclite.md and MUSCLE
    headers
    + S8226798: JVM crash in
    klassItable::initialize_itable_for_interface(int,
    InstanceKlass*, bool, Thread*)
    + S8226964: [Yaru] GTK L&F: There is no difference between menu
    selected and de-selected
    + S8227011: Starting a JFR recording in response to JVMTI
    VMInit and / or Java agent premain corrupts memory
    + S8227041: runtime/memory/RunUnitTestsConcurrently.java has a
    memory leak
    + S8227117: normal interpreter table is not restored after
    single stepping with TLH
    + S8227247: tools/sjavac/IdleShutdown.java fails with
    AssertionError: Error too big on windows
    + S8227277: HeapInspection::find_instances_at_safepoint walks
    dead objects
    + S8227392: Colors with alpha are painted incorrectly on Linux,
    after JDK-8214579
    + S8227594: sadebugd/DebugdConnectTest.java fails due to
    "java.rmi.NotBoundException: SARemoteDebugger"
    + S8227630: adjust format specifiers in loadlib_aix.cpp
    + S8227834: build.log output from failing commands : include
    the hs_error file path in case of crashes in build
    + S8227869: fix wrong format specifiers in os_aix.cpp
    + S8227919: 8213232 causes crashes on solaris sparc64
    + S8228337: problemList failing/ignored manual tests in
    security-libs
    + S8228400: Remove built-in AArch64 simulator
    + S8228469: (tz) Upgrade time-zone data to tzdata2019b
    + S8228485: JVM crashes when bootstrap method for condy
    triggers loading of class whose static initializer throws
    ve thread creation fails
    + S8220579: [Containers] SubSystem.ja  exception
    + S8228501: java_props_macosx.c - provide missing CFRelease for
    CFLocaleCopyCurrent
    + S8228578: fix CFData object leak in macosx KeystoreImpl.m
    + S8228585: jdk/internal/platform/cgroup/TestCgroupMetrics.java
  - NumberFormatException because of large long values (memory
    limit_in_bytes)
    + S8228596: Class redefinition fails when condy instructions
    are removed
    + S8228601: AArch64: Fix interpreter code at JVMCI
    deoptimization entry
    + S8228618: s390: c1/c2 fail to add a metadata relocation in
    the static call stub.
    + S8228649: [PPC64] SA reads wrong slots from interpreter frames
    + S8228658: test GetTotalSafepointTime.java fails on fast Linux
    machines with Total safepoint time 0 ms
    + S8228711: Path rendered incorrectly when it goes outside the
    clipping region
    + S8228725: AArch64: Purge method call format support
    + S8228764: New library dependencies due to JDK-8222720
    + S8229118: [TESTBUG] serviceability/sa/ClhsdbFindPC fails on
    AArch64
    + S8229352: Use of an uninitialized register in 32-bit ARM
    template interpreter
    + S8229406: ZGC: Fix incorrect statistics
    + S8229767: Typo in java.security: Sasl.createClient and
    Sasl.createServer
    + S8229773: Resolve permissions for code source URLs lazily
    + S8229887: (zipfs) zip file corruption when replacing an
    existing STORED entry
    + S8229925: [s390, PPC64] Exception check missing in interpreter
    + S8230085: (fs) FileStore::isReadOnly is always true on macOS
    Catalina
    + S8230099: Prepare for backport of JDK-8217368
    + S8230728: Thin stroked shapes are not rendered if affine
    transform has flip bit
    + S8230850: Test sun/tools/jcmd/TestProcessHelper.java fails
    intermittently
    + S8231693: Backout "8230728: Thin stroked shapes are not
    rendered if affine transform has flip bit" from jdk11u
- Modified patch:
  * system-pcsclite.patch
    + adapt to changed context
* Wed Jul 17 2019 Fridrich Strba <fstrba@suse.com>
- Update to upstream tag jdk-11.0.4+11 (July 2019 CPU)
  * Security fixes
    + S8208698, CVE-2019-2745, bsc#1141784: Improved ECC
    Implementation
    + S8212328, CVE-2019-2762, bsc#1141782: Exceptional throw cases
    + S8213431, CVE-2019-2766, bsc#1141789: Improve file protocol
    handling
    + S8213432, CVE-2019-2769, bsc#1141783: Better copies of
    CopiesList
    + S8216381, CVE-2019-2786, bsc#1141787: More limited privilege
    usage
    + S8217563: Improve realm maintenance
    + S8218863: Better endpoint checks
    + S8218873: Improve JSSE endpoint checking
    + S8218876, CVE-2019-7317, bsc#1141780: Improve PNG support
    options
    + S8219775: Certificate validation improvements
    + S8220517: Enhanced GIF support
    + S8221345, CVE-2019-2818, bsc#1141788: Better Poly1305 support
    + S8221518, CVE-2019-2816, bsc#1141785: Normalize normalization
    + S8222678, CVE-2019-2821, bsc#1141781: Improve TLS negotiation
  * Other fixes
    + S6913047: Long term memory leak when using PKCS11 and JCE
    exceeds 32 bit process address space
    + S8139178: Wrong fontMetrics when printing in Landscape
    (OpenJDK)
    + S8163805: hotspot/test/serviceability/sa/sadebugd/
    /SADebugDTest.java failed with timed out
    + S8170494: JNI exception pending in PlainDatagramSocketImpl.c
    + S8174691: [TESTBUG] A number of native hotspot unit tests
    fail when executed in stand-alone mode
    + S8179098: Crypto AES/ECB encryption/decryption performance
    regression (introduced in jdk9b73)
    + S8181143: Introduce diagnostic flag to abort VM on too long
    VM operations
    + S8188133: C2: Static field accesses in clinit can trigger
    deoptimizations
    + S8190361: Incorrect version info in jaccessinspector.exe and
    jaccesswalker.exe
    + S8195793: Remove GTE CyberTrust Global Root
    + S8200286: (testbug) MOptionTest test fails with
    java.lang.AssertionError: Classfiles too old!
    + S8200613: SA: jstack throws UnmappedAddressException with a
    CDS core file
    + S8201317: X25519/X448 code improvements
    + S8201633: Problems with AES-GCM native acceleration
    + S8202353: os::readdir should use readdir instead of readdir_r
    + S8202414: Unsafe write after primitive array creation may
    result in array length change
    + S8202651: Test ComodoCA.java fails
    + S8202794: Native Unix code should use readdir rather than
    readdir_r
    + S8202884: SA: Attach/detach might fail on Linux if debugee
    application create/destroy threads during attaching
    + S8203627: Swing applications with JRadioButton and JCheckbox
    fail to render correctly when using GTK3 and the GTK L&F
    + S8204308: SA: serviceability/sa/TestInstanceKlassSize*.java
    fails when running in CDS mode
    + S8205574: Loop predication "assert(f <= 1 && f >= 0) failed
    Incorrect frequency"
    + S8205611: Improve the wording of LinkageErrors to include
    module and class loader information
    + S8206955: MethodHandleProxies.asInterfaceInstance does not
    support default methods
    + S8207340: (fs) UnixNativeDispatcher close and readdir usages
    should be fixed
    + S8207748: Fix for 8202794 breaks tier1 builds
    + S8207760: SAXException: Invalid UTF-16 surrogate detected:
    d83c ?
    + S8208634: Add x-IBM-1129 charset
    + S8208648: ECC Field Arithmetic Enhancements
    + S8208702: javax/swing/reliability/
    /HangDuringStaticInitialization.java may hang on macos
    + S8208996: X11 icon window color handing bug
    + S8209055: c.s.t.javac.code.DeferredCompletionFailureHandler
    seems to use WeakHashMap incorrectly
    + S8209414: AArch64: method handle invocation does not respect
    JVMTI interp_only mode
    + S8209415: Fix JVMTI test failure HS202
    + S8209573: [TESTBUG] gc/epsilon/TestMemoryMXBeans should retry
    on failure
    + S8209914: javadoc search sometimes generates bad URIs
    + S8209951: Problematic sparc intrinsic:
    com.sun.crypto.provider.CipherBlockChaining
    + S8210008: custom extension for make/SourceRevision.gmk
    + S8210197: javac can't tell during speculative attribution if
    a diamond expression is creating an anonymous inner class or
    not
    + S8210283: Support git as an SCM alternative in the build
    + S8210320: PPC64: Fix uninitialized variable in C1 LIR
    assembler code
    + S8210457: JVM crash in ResolvedMethodTable::add_method(Handle)
    + S8210483: AssertionError in DeferredAttr at setOverloadKind
    caused by JDK-8203679
    + S8210519: build/releaseFile/CheckSource.java failed additional
    sources found
    + S8210739: Calling JSpinner's setFont with null throws
    NullPointerException
    + S8210782: Upgrade HarfBuzz to the latest 2.3.1
    + S8210803: Compilation failure in codeBlob.cpp for Windows
    32-bit
    + S8210837: Add libXrandr-devel to the Linux devkits
    + S8210863: Remove Xrandr include files from JDK sources
    + S8210880: Remove HPKeysym.h from JDK sources
    + S8210886: Remove references in xwindows.md to non-existent
    files.
    + S8210899: (zipfs) ZipFileSystem.EntryOutputStreamCRC32
    mistakenly set the crc32 value into size field
    + S8211266: [TESTBUG] ZipFSTester.java failed intermittently in
    ZipFSTester.checkRead(): bound must be positive
    + S8211350: Remove jprt support
    + S8211393: Memory leak issue on awt_InputMethod.c
    + S8211435: Exception in thread "AWT-EventQueue-1"
    java.lang.IllegalArgumentException: null source
    + S8211698: Crash in C2 compiled code during execution of
    double array heavy processing code
    + S8211810: X11 Time stamp data should be unsigned
    + S8211826: StringIndexOutOfBoundsException happens via
    GetStringUTFRegion()
    + S8211841: [testbug] sun/nio/cs/OLD/TestIBMDB.java does not
    compile (aix)
    + S8211969: test/jdk/lib/security/CheckBlacklistedCerts.java
    searching for wrong paths
    + S8211971: Move security/cacerts/VerifyCACerts.java and
    security/CheckBlacklistedCerts.java
    + S8212202: [Windows] Exception if no printers are installed.
    + S8212205: VM asserts after CDS archive has been unmapped
    + S8212562: To remove lib/security from test/jdk/TEST.groups
    + S8212676: AWT SystemColor setting on CDE
    + S8212677: X11 default visual support for IM status window on
    VNC
    + S8212678: Windows IME related patch
    + S8212794: IBM-964 is required for AIX default charset
    + S8212828: (process) Provide a way for Runtime.exec to use
    posix_spawn on linux
    + S8213015: Inconsistent settings between JFR.configure and
  - XX:FlightRecorderOptions
    + S8213213: Remove src/java.desktop/unix/classes/sun/awt/
    /X11/keysym2ucs.h
    + S8213232: Unix/X11 setCompositionEnableNative issue
    + S8213292: Input freezes after MacOS key-selector (press&hold)
    usage on macOS Mojave
    + S8213294: Upgrade IANA LSR data
    + S8213515: Improve freetype detection on linux/ppc64/ppc64le/
    /s390x
    + S8213614: DnD operation change feature does not work with
    64bit big endian CPU
    + S8213617: JFR should record the PID of the recorded process
    + S8213618: IBM970 charset has missing entry and remove
    unexpected entries
    + S8213825: assert(false) failed: Non-balanced monitor
    enter/exit! Likely JNI locking
    + S8213944: Fix AIX build after the removal of Xrandr.h and add
    a configure check for it
    + S8214002: Cannot use italic font style if the font has
    embedded bitmap
    + S8214109: XToolkit is not correctly displayed color on 16-bit
    high color setting
    + S8214111: There is no icon in all JOptionPane target image
    + S8214112: The whole text in target JPasswordField image are
    not selected
    + S8214252: Expanded & Collapsed nodes of a JTree look the same
    on GTK3
    + S8214253: Tooltip is transparent rather than having a black
    background
    + S8214468: jQuery UI upgrade from 1.11.4 to 1.12.1
    + S8214533: IBM-29626C is required for AIX default charset
    + S8214765: All TrayIcon MessageType icons does not show up
    with gtk3 option set
    + S8214935: Upgrade IANA LSR data
    + S8215026: Incorrect amount of memory unmapped with
    ImageFileReader::close()
    + S8215123: Crash in runtime image built with jlink --compress=2
    + S8215284: Reduce noise induced by periodic task getFileSize()
    + S8215296: do not disable c99 on Solaris
    + S8215342: [Zero] Build fails after JDK-8200613
    + S8215364: JavaFX crashes on Ubuntu 18.04 with Wayland while
    using Swing-FX interop
    + S8215374: 32-bit build failures after JDK-8181143 (Introduce
    diagnostic flag to abort VM on too long VM operations)
    + S8215398: -Xlog option usage => Invalid decorator
    '\temp\app_cds.log'.
    + S8215443: The use of TransportContext.fatal() leads to bad
    coding style
    + S8215472: (zipfs) Cleanups in implementation classes of
    jdk.zipfs and tests
    + S8215707: [macosx] fix pthread_getschedparam and
    pthread_setschedparam calls
    + S8215757: C2: PhaseIdealLoop::create_new_if_for_predicate()
    computes wrong IDOM
    + S8215790: Delegated task created by SSLEngine throws
    java.nio.BufferUnderflowException
    + S8216045: The size of key_exchange may be wrong on FFDHE
    + S8216355: missing NULL checks in libnet in interface iteration
    and potential resource leak in getMacAddress
    + S8216556: Unnecessary liveness computation with JVMTI
    + S8216577: Add GlobalSign's R6 Root certificate
    + S8216597: SIGBUS in
    Java_sun_security_pkcs11_wrapper_PKCS11_getNativeKeyInfo
    after JDK-6913047
    + S8216970: condy causes JVM crash
    + S8217088: Disable JDK-6913047 fix (SunPKCS11 memory leak)
    after JDK-8216597 (SIGBUS error in getNativeKeyInfo)
    + S8217094: HttpClient SSL race if a socket IOException is
    raised before ALPN is available
    + S8217263: Automate DashOffset test
    + S8217311: Improve Exception thrown when
    MulticastSocket.setInterface fails on AIX(Unix)
    + S8217564: idempotent protection missing in crc32c.h
    + S8217647: JFR: recordings on 32-bit systems unreadable
    + S8217690: Update public suffix version
    + S8217707: JNICALL declaration breaks Splash screen functions
    + S8217765: Internal Error (javaCalls.cpp:61)
    guarantee(thread->can_call_java()) failed
    + S8217786: Provide virtualization related info in the hs_error
    file on linux s390x
    + S8217878: ENVELOPING XML signature no longer works in JDK 11
    + S8217879: hs_err should print more instructions in hex dump
    + S8217880: AIX build issue after JDK-8214533
    + S8218020: Fix version number in mesa.md 3rd party legal file
    + S8218060: JDK-8217786 breaks build due to remaining unused
    function
    + S8218063: JDK-8218060 breaks build for S390
    + S8218152: [javac] fails and exits with no error if a bad
    annotation processor provided
    + S8218469: JSlider display issue with slider for GTKLookAndFeel
    + S8218470: JScrollBar display issue with GTKLookAndFeel
    + S8218472: JProgressBar display issue with GTKLookAndFeel
    + S8218473: JOptionPane display issue with GTKLookAndFeel
    + S8218479: JTextPane display issue with GTKLookAndFeel
    + S8218618: Program fails when using JDK addressed by UNC path
    and using Security Manager
    + S8218629: XML Digital Signature throws NAMESPACE_ERR exception
    on OpenJDK 11, works 8/9/10
    + S8218674: HTML Tooltip with "img=src" on component doesn't
    show
    + S8218733: SA: CollectedHeap provides broken implementation for
    used() and capacity()
    + S8218781: Localized names for Japanese era Reiwa in COMPAT
    provider
    + S8218811: replace open by os::open in hotspot coding
    + S8218854: FontMetrics.getMaxAdvance may be less than the
    maximum FontMetrics.charWidth
    + S8218960: CONFIG level logging statements printed in
    CLDRCalendarDataProviderImpl.java even when default log Level
    is INFO
    + S8218991: s390: Add intrinsic for GHASH algorithm
    + S8219006: AArch64: Register corruption in slow subtype check
    + S8219011: Implement MacroAssembler::warn method on AArch64
    + S8219112: name_and_sig_as_C_string usages in frame_s390 miss
    ResourceMark
    + S8219335: "failed: unexpected type" assert failure in
    ConnectionGraph::split_unique_types() with unsafe accesses
    + S8219389: Delegated task created by SSLEngine throws
    BufferUnderflowException
    + S8219414: SA: jhsdb jsnap throws UnmappedAddressException with
    core generated by gcore
    + S8219448: split-if update_uses accesses stale idom data
    + S8219460: ppc: adjust NativeGeneralJump::insert_unconditional
    to stack allocated MacroAssembler
    + S8219566: JFR did not collect call stacks when
    MaxJavaStackTraceDepth is set to zero
    + S8219574: Minimal VM build failure after JDK-8219414
    + S8219582: PPC: Crash after C1 checkcast patched and GC
    + S8219584: Try to dump error file by thread which causes
    safepoint timeout
    + S8219698: aarch64: SIGILL triggered when specifying
    unsupported hardware features
    + S8219710: Bump update version for OpenJDK: jdk11.0.4
    + S8219746: Provide virtualization related info in the hs_error
    file on linux ppc64 / ppc64le
    + S8219915: [TESTBUG] Fix test langtools/tools/javac/processing/
    /model/completionfailure/SymbolsDontCumulate.java in
    Standalone mode
    + S8219918: ProblemList hotspot tests failing in SAP testing.
    + S8220165: Encryption using GCM results in RuntimeException-
    input length out of bound
    + S8220166: Performance regression in deserialization (4-6%% in
    SPECjbb)
    + S8220198: Lots of com/sun/crypto/provider/Cipher tests fail
    on x86_32 due to missing SHA512 stubs
    + S8220281: IBM-858 alias name is missing on IBM00858 charset
    + S8220293: Deadlock in JFR string pool
    + S8220349: The fix done for JDK-8214253 have caused issues in
    JTree behaviour
    + S8220353: [TESTBUG] TestRegisterRestoring uses SafepointALot
    without UnlockDiagnosticVMOptions
    + S8220374: C2: LoopStripMining doesn't strip as expected
    + S8220441: [PPC64] Clobber memory effect missing for memory
    barriers in atomics
    + S8220495: Update GIFlib library to the 5.1.8
    + S8220513: Wrapper Key may get deleted when closing sessions in
    SunPKCS11 crypto provider
    + S8220625: tools/javac/classreader/8171132/
    /BadConstantValue.java failed with "did not see expected
    error"
    + S8220707: [TESTBUG] serviceability/sa/
    /TestHeapDumpForLargeArray.java fails with jtreg
  - vmoption:-Xmx < 8g
    + S8220714: C2 Compilation failure when accessing off-heap
    memory using Unsafe
    + S8220718: Missing ResourceMark in nmethod::metadata_do
    + S8220781: linux-s390 : os::get_summary_cpu_info gives bad
    output
    + S8220794: PPC64: Fix signal handler for SIGSEGV on branch to
    illegal address
    + S8221083: [ppc64] Wrong oop compare in C1-generated code
    + S8221175: Fix bad function case for controlled JVM crash on
    PPC64 big-endian
    + S8221244: Unexpected behavior of
    PropertyDescription.getReadMethod for boolean properties
    + S8221263: [TEST_BUG] RemotePrinterStatusRefresh test is hard
    to use
    + S8221304: Problem list java/awt/FontMetrics/
    /MaxAdvanceIsMax.java
    + S8221400: java/lang/String/StringRepeat.java test requests
    too much heap
    + S8221401: java/math/BigInteger/LargeValueExceptions.java test
    should be disabled on 32-bit platforms
    + S8221412: lookupPrintServices() does not always update the
    list of Windows remote printers
    + S8221437:
    assert(java_lang_invoke_ResolvedMethodName::vmtarget(resolved_method())
    == m()) failed: Should not change after link resolution
    + S8221470: Print methods in exception messages in java-like
    Syntax.
    + S8221479: Fix JFR profiling on s390
    + S8221483: TestOopCmp.java fails due to "Multiple garbage
    collectors selected"
    + S8221535: add steal tick related information to hs_error file
    [linux]
    + S8221610: Resurrect (legacy) JRE bundle target
    + S8221639: [i386] expand_exec_shield_cs_limit workaround is
    undefined code after JDK-8199717
    + S8221833: Readability check in Symbol::is_valid not performed
    for some addresses
    + S8221870: use driver to run CtwRunner in applications/ctw
    tests
    + S8221880: Better customization for Windows RC properties
    FileDescription and ProductName
    + S8221915: cleanup ticks related coding in os_perf_aix.cpp
    [aix]
    + S8221917: serviceability/sa/TestPrintMdo.java fails on 32-bit
    platforms
    + S8221924: get(null) on single-entry unmodifiable Map returns
    null instead of throwing NPE
    + S8222027: java/util/logging/LogManager/TestLoggerNames.java
    generates intermittent ClassCastException
    + S8222032: x86_32 fails with "wrong size of mach node" on
    AVX-512 machine
    + S8222089: [TESTBUG] sun/security/lib/cacerts/
    /VerifyCACerts.java fails due to cert within 90-day expiry
    window
    + S8222133: Add temporary exceptions for root certs that are
    due to expire soon
    + S8222136: Remove two Comodo root CA certificates that are
    expiring
    + S8222137: Remove T-Systems root CA certificate
    + S8222397: x86_32 tests with UseSHA1Intrinsics SEGV due to
    garbled registers
    + S8222410: java/nio/file/attribute/BasicFileAttributeView/
    /UnixSocketFile hangs when "nc" does not accept "-U"
    + S8222522: Add configure options for Mac Bundle creation
    + S8222532: (zipfs) Performance regression when writing
    ZipFileSystem entries in parallel
    + S8222913: Add Jib support for VERSION_EXTRA*
    + S8222930: ConcurrentSkipListMap.clone() shares size variable
    between original and clone
    + S8223266: PPC64: Check for branch to illegal address before
    checking for mem serialization
    + S8223395: PPC64: Improve comments in the JVM signal handler
    to match ISA text
    + S8223499: Remove two DocuSign root certificates that are
    expiring
    + S8223555: Cleanups in cacerts tests
    + S8223597: jdk/nio/zipfs/ZipFSTester.java RuntimeException:
    CHECK_FAILED! (getAttribute.crc <entries20> failed 6af4413c
    vs 0 ...)
    + S8223665: SA: debugd options should follow jhsdb style
    + S8224474: harfbuzz 2.3.1 code fails to compile with gcc
    4.4.7
    + S8224671: AArch64: mauve System.arraycopy test failure
    + S8224727: Problem list test security/infra/java/security/cert/
    /CertPathValidator/certification/ActalisCA.java
    + S8224828: aarch64: rflags is not correct after safepoint poll
    + S8224880: AArch64: java/javac error with
    AllocatePrefetchDistance
    + S8225402: events logging in deoptimization.cpp should go to
    deopt-log
    + S8225716: G1 GC: Undefined behaviour in
    G1BlockOffsetTablePart::block_at_or_preceding
    + S8226876: Assertion in sun/util/locale/provider/
    /CalendarDataUtility on Windows after JDK-8218960
    + S8226880: Backport of JDK-8208698 (Improved ECC
    Implementation) should not bring parts of JDK-8205476
    (KeyAgreement#generateSecret is not reset for ECDH based
    algorithm)
* Fri Jul  5 2019 Fridrich Strba <fstrba@suse.com>
- Do not fail installation when the manpages are not present
  (bsc#1115375)
* Fri Jul  5 2019 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * JDK-8208602.patch
    + Backport upstream fix for JDK-8208602: Cannot read PEM X.509
    cert if there is whitespace after the header or footer
    (bsc#1140461)
* Tue Jun  4 2019 Fridrich Strba <fstrba@suse.com>
- Provide and Obsolete the corresponding java-10-openjdk-<sub>
  packages to assure smooth upgrade (fate#326347, bsc#1137264)
* Tue Apr 23 2019 Fridrich Strba <fstrba@suse.com>
- Require update-ca-certificates by the headless subpackage
  (bsc#1131378)
- Removed patch:
  * java11-improved-fonts.patch
    + broken with the recent changes in font rendering
* Wed Apr 17 2019 Fridrich Strba <fstrba@suse.com>
- Update to upstream tag jdk-11.0.3+7 (April 2019 CPU)
  * Security fixes
    + S8211936, CVE-2019-2602, bsc#1132728: Better String parsing
    + S8214809: CDS storage improvements
    + S8218453, CVE-2019-2684, bsc#1132732: More dynamic RMI
    interactions
  * Other changes
    + S8034802: (zipfs) newFileSystem throws UOE when the zip file
    is located in a custom file system
    + S8165675: Trace event for thread park has incorrect unit for
    timeout
    + S8172695: (scanner) java/util/Scanner/ScanTest.java fails
    + S8187364: Unable to enter zero width non-joiner (ZWNJ) symbol
    in Swing text component
    + S8197398: (zipfs) Files.walkFileTree walk indefinitelly while
    processing JAR file with "/" as a directory inside.
    + S8200109: NMT: diff_malloc_site assert(early->flags() ==
    current->flags(), "Must be the same memory type")
    + S8201818: [macosx] Printing attributes break page size set via
    "java.awt.print.Book" object
    + S8204142: AWT hang occurs when sequenced events arrive out of
    sequence in multiple AppContexts
    + S8205432: Replace the placeholder Japanese era name
    + S8206120: Add test cases for lenient Japanese era parsing
    + S8207070: Webstart app popup on wrong screen in a one-screen
    setup changing to multi-monitor
    + S8207258: Distrust TLS server certificates anchored by
    Symantec Root CAs
    + S8207760: SAXException: Invalid UTF-16 surrogate detected:
    d83c ?
    + S8207829: FlightRecorderMXBeanImpl is leaking the first
    classloader which calls it
    + S8207849: Allow the addition of more number to the Java
    version string
    + S8208275: C2 crash in Node::add_req(Node*)
    + S8208656: Move java/util/Calendar/CalendarTestScripts tests
    into OpenJDK
    + S8209615: ParseError in XMLEventReader on a valid input
    + S8209758: 2 classes with same name G1PrintCollectionSetClosure
    cause crash when logging is enabled
    + S8209960: -Xlog:jfr* doesn't work with the JFR
    + S8210192: Hsperf counter ParNew::CMS should be ParNew:CMS
    + S8210394: (zipfs) jdk/nio/zipfs/ZFSTests.java rootdir.zip: The
    process cannot access the file because it is being used by
    another process
    + S8210633: Cannot parse JapaneseDate string with
    DateTimeFormatterBuilder Mapped-values
    + S8210874: Test for JDK-8209615
    + S8210974: No extensions debug log for ClientHello
    + S8210989: RSASSA-PSS certificate cannot be selected for client
    auth on TLSv1.2
    + S8211049: Second parameter of "initialize" method is not used
    + S8211064: [AArch64] Interpreter and c1 don't correctly handle
    jboolean results in native calls
    + S8211100: hotspot C1 issue with comparing long numbers on x86
    32-bit
    + S8211163: UNIX version of Java_java_io_Console_echo does not
    return a clean boolean
    + S8211267: StackOverflowError happened by
    TextField.setFont(...)
    + S8211295: DriverManager.getConnection fails when called from
    com.sun.rowset.JdbcRowSetImpl
    + S8211320: Aarch64: unsafe.compareAndSetByte() and
    unsafe.compareAndSetShort() c2 intrinsics broken with negative
    expected value
    + S8211382: ISO2022JP and GB18030 NIO converter issues
    + S8211398: Square character support for the Japanese new era
    + S8211698: Crash in C2 compiled code during execution of double
    array heavy processing code
    + S8211765: JarFile constructor throws undocumented exception
    + S8211787: javax/net/ssl/TLSCommon/TLSTest.java throws
    java.net.SocketTimeoutException: Read timed out
    + S8211821: PrintStringTableStatistics crashes JVM
    + S8212173: Thread._stack_base/_stack_size initialized too late
    for new threads
    + S8212232: Wrong metadata for the configuration of the cutoff
    for old object sample events
    + S8212233: javadoc fails on jdk12 with "The code being
    documented uses modules but the packages defined in $URL are
    in the unnamed module."
    + S8212885: TLS 1.3 resumed session does not retain peer
    certificate chain
    + S8212941: Support new Japanese era in
    java.time.chrono.JapaneseEra
    + S8213183: InputMethod cannot be used after its restarting
    + S8213202: Possible race condition in TLS 1.3 session resumption
    + S8213419: C2 may hang in MulLNode::Ideal()/MulINode::Ideal()
    with gcc 8.2.1
    + S8213421: Line number information for execution samples
    always 0
    + S8213583: Error while opening the JFileChooser when desktop
    contains shortcuts pointing to deleted files
    + S8213754: PPC64: Add Intrinsics for
    isDigit/isLowerCase/isUpperCase/isWhitespace
    + S8213782: NullPointerException in
    sun.security.ssl.OutputRecord.changeWriteCiphers
    + S8213829: Remove circular dependency between g1CollectedHeap
    and g1ConcurrentMark
    + S8213952: Relax DNSName restriction as per RFC 1123
    + S8213966: The ZGC JFR events should be marked as experimental
    + S8213983: [macosx] Keyboard shortcut ?cmd +`? stops working
    properly if popup window is displayed
    + S8214063: OpenJDK will not build on AIX while using the xlc
    13.1 compiler
    + S8214100: use of keystore probing results in unnecessary
    exception thrown
    + S8214118: HeapRegions marked as archive even if CDS mapping
    fails
    + S8214122: JDWP is broken on 32 bit Windows: transport library
    missing onLoad entry
    + S8214129: SSL session resumption/SNI with TLS1.2 causes
    StackOverflowError
    + S8214189: test/hotspot/jtreg/compiler/intrinsics/mathexact/
    /MulExactLConstantTest.java fails on Windows x64 when run with
  - XX:-TieredCompilation
    + S8214206: Fix for JDK-8213419 is broken on 32-bit
    + S8214339: SSLSocketImpl erroneously wraps SocketException
    + S8214352: C1: Unnecessary "compilation bailout: block join
    failed" with JVMTI
    + S8214451: PPC64/s390: Clean up unused CRC32 prototype and
    function
    + S8214513: A PKCS12 keystore from Java 8 using custom PBE
    parameters cannot be read in Java 11
    + S8214688: TLS 1.3 session resumption with hello retry request
    failed with "illegal_parameter"
    + S8214827: Incorrect call
    ClassLoaders.toFileURL("jrt:/java.compiler")
    + S8215100: AArch64: fix compareTo intrinsic with four-character
    Latin/Unicode
    + S8215175: Inconsistencies in JFR event metadata
    + S8215202: AArch64: jtreg test
    test/jdk/sun/nio/cs/FindEncoderBugs.java fails
    + S8215317: [GRAAL] unit test CheckGraalIntrinsics failed after
    8213754
    + S8215330: javax.xml.catalog.CatalogResolverImpl:
    GroupEntry.matchURI fails to match
    + S8215362: JFR GTest JfrTestNetworkUtilization fails
    + S8215397: jsig.c missing classpath exception
    + S8215727: Restore JFR thread sampler loop to old / previous
    behavior
    + S8215947: JVM crash with -XX:+DumpSharedSpaces
    + S8215951: AArch64: jtreg test
    vmTestbase/nsk/jvmti/PopFrame/popframe005 segfaults
    + S8215962: Support ThreadPriorityPolicy mode 1 for non-root
    users on linux/bsd
    + S8216049: stringTable::intern creates redundant String when
    looking up existing one
    + S8216060: [PPC64] Vector CRC implementation should be used by
    interpreter and be faster for short arrays
    + S8216280: Allow later Symantec Policy distrust date for two
    Apple SubCAs
    + S8216302: StackTraceElement::fill_in can use cached Class.name
    + S8216308: StackTraceElement::fill_in can use injected Class
    source-file
    + S8216350: AArch64: monitor unlock fast path not called
    + S8216546: Support new Japanese era in java.lang.Character for
    Java SE 11
    + S8216578: Remove unused/obsolete method in JFR code
    + S8216965: crash in freetypeScaler.c CopyBW2Grey8
    + S8217014: Epsilon should not ignore Metadata GC causes
    + S8217315: Proper units should print more significant digits
    + S8217321: [TESTBUG] utilities/test_globalDefinitions.cpp
    should use _LP64, not LP64
    + S8217342: Build failed with excluding JFR
    + S8217378: UseCriticalCMSThreadPriority is broken
    + S8217427: (dc) nio/channels/DatagramChannel/UseDGWithIPv6.java
    fails without IPv6
    + S8217432: MetaspaceGC::_capacity_until_GC exceeds
    MaxMetaspaceSize
    + S8217459: [PPC64] Cleanup non-vector version of CRC32
    + S8217471: [TESTBUG] gc/epsilon/TestClasses.java fails on some
    platforms - OOME Metaspace
    + S8217520: Remove vm.opt.MaxGCPauseMillis == "null" from
    TestOldGenCollectionUsage.java
    + S8217579: TLS_EMPTY_RENEGOTIATION_INFO_SCSV is disabled after
    8211883
    + S8217597: [TESTBUG] old version docker does not support --cpus
    + S8217609: New era placeholder not recognized by
    java.text.SimpleDateFormat
    + S8217628: Verbose ArrayIndexOutOfBoundsException message also
    in JNI calls.
    + S8217657: Move the test for default value of
    jdk.includeInExceptions into own test
    + S8217994: os::print_hex_dump should be more resilient against
    unreadable memory
    + S8218156: "jcmd VM.metaspace basic" misreports free chunk
    space
    + S8218192: Remove copy constructor for MemRegion
    + S8218915: Change isJavaIdentifierStart and
    isJavaIdentifierPart to handle new code points
    + S8219251: Langtools tests default memory size needs to be 768m
    + S8219260: Default number of test jobs needs to be consistently
    calculated
    + S8219461: Bump update version for OpenJDK jdk11.0.3
    + S8219650: [Testbug] Fix potential crashes in new test hotspot
    gtest "test_print_hex_dump"
    + S8219651: compiler/ciReplay/TestServerVM.java is failing on
    windows
    + S8219714: [testbug] com/sun/jdi/RedefineNestmateAttr/
    /TestNestmateAttr.java must pass classpath to subprocess
    + S8219789: [TESTBUG] TestOptionsWithRanges.java produces
    hs_err_pidXXXXX.log file for
    VMThreadStackSize=9007199254740991
    + S8219890: Calendar.getDisplayName() returns empty string for
    new Japanese Era on some locales
    + S8220283: ZGC fails to build on GCC 4.4.7: ATTRIBUTE_ALIGNED
    compatibility issue
    + S8220294: ZGC fails to build on GCC 4.4.7: Type parameter
    issue
    + S8221769: Revert JDK-8221767 mistakenly pushed to jdk11u
    11.0.3
- Modified patch:
  * java11-improved-fonts.patch
    + Adapted to changed context
* Wed Jan 16 2019 Fridrich Strba <fstrba@suse.com>
- Update to upstream tag jdk-11.0.2+7 (Oracle January 2019 CPU)
  * Security fixes:
    + S8206290, CVE-2019-2422, bsc#1122293: Better FileChannel
    transfer performance
    + S8209094, CVE-2019-2426: Improve web server connections
    + S8210866, CVE-2018-11212, bsc#1122299: Improve JPEG
    processing
  * Security-In-Depth fixes:
    + S8199156: Better route routing
    + S8199161: Better interface enumeration
    + S8199166: Better interface lists
    + S8199552: Update to build scripts
    + S8200659: Improve BigDecimal support
    + S8203955: Improve robot support
    + S8204895: Better icon support
    + S8205356: Choose printer defaults
    + S8205709: Proper allocation handling
    + S8205714: Initial class initialization
    + S8206295: More reliable p11 transactions
    + S8206301: Improve NIO stability
    + S8210094: Better loading of classloader classes
    + S8210598: Strengthen Windows Access Bridge Support
    + S8210606: Improved data set handling
    + S8210610: Improved LSA authentication
    + S8210870: Libsunmscapi improved interactions
  * Fixes
    + S8021335: Missing synchronization when reading counters for
    live threads and peak thread count
    + S8027434: "-XX:OnOutOfMemoryError" uses fork instead of vfork
    + S8029661: Support TLS v1.2 algorithm in SunPKCS11 provider
    + S8170937: Swing apps are slow if displaying from a remote
    source to many local displays
    + S8196902: Better HTTP Redirection
    + S8203688: [testbug] Nashorn test
    test/nashorn/script/nosecurity/treeapi/diagnostic.js fails
    + S8203850: java.net.http HTTP client should allow specifying
    Origin and Referer headers
    + S8205330: InitialDirContext ctor sometimes throws NPE if the
    server has sent a disconnection
    + S8205507: jdk/javax/xml/crypto/dsig/GenerationTests.java
    timed out
    + S8205633: TestOptionsWithRanges.java of
    '-XX:TLABSize=2147483648' fails intermittently
    + S8206075: On x86, assert on unbound assembler Labels used as
    branch targets
    + S8206107: [x86_32] jck tests for ldc2_w bytecode fail
    + S8207059: Update test certificates in QuoVadisCA.java test
    + S8207150: Clip.isRunning() may return true after Clip.stop()
    was called
    + S8207343: Automate vtable/itable stub size calculation
    + S8207395: jar has issues with UNC-path arguments for the jar
  - C parameter [windows]
    + S8207810: Remove jdk-11.0.1+2 tag from source repository
    + S8207924: serviceability/sa/TestUniverse.java#id0
    intermittently fails with
    assert(get_instanceKlass()->is_loaded()) failed: must be at
    least loaded
    + S8208209: Improve TLS connection stability again
    + S8208350: Disable all DES cipher suites
    + S8208480: Test failure: assert(is_bound() || is_unused())
    after JDK-8206075 in C1
    + S8208638: Instead of circle rendered in appl window, but
    ellipse is produced JEditor Pane
    + S8208647: switch jtreg to 4.2b13
    + S8208661: JDK 11.0.1 l10n resource file update
    + S8208754: The fix for JDK-8194534 needs updates
    + S8209357: [PPC64] Fix build which was broken by 8208672
    (Enable -Wreorder)
    + S8209433: [s390] Fix build, broken by 8208672 (Enable
  - Wreorder)
    + S8209511: C2 asserts with UseSSE < 4 and AVX enabled: "Label
    was never bound to a location, but it was used as a jmp target'
    + S8209544: AES encrypt performance regression in jdk11b11
    + S8209576: java.nio.file.Files.writeString writes garbled
    UTF-16 instead of UTF-8
    + S8209588: SIGSEGV in MethodArityHistogram() with
  - XX:+CountCompiledCalls
    + S8209916: NPE in SupportedGroupsExtension
    + S8209950: SIGBUS in CodeHeapState::print_names()
    + S8209965: The "supported_groups" extension in ServerHellos
    + S8210040: TestOptionsWithRanges.java is very slow
    + S8210043: Invalid assert(HeapBaseMinAddress > 0) in
    ReservedHeapSpace::initialize_compressed_heap
    + S8210319: [s390]: Use of shift operators not covered by cpp
    standard
    + S8210334: TLS 1.3 server fails if ClientHello doesn't have
    pre_shared_key and psk_key_exchange_modes
    + S8210345: The Japanese message of FileNotFoundException
    garbled
    + S8210355: Minimal and Zero non-PCH builds fail after
    JDK-8207343 (Automate vtable/itable stub size calculation)
    + S8210357: Zero builds fail after JDK-8207343 (Automate
    vtable/itable stub size calculation)
    + S8210416: [linux] Poor StrictMath performance due to
    non-optimized compilation
    + S8210425: [x86] sharedRuntimeTrig/sharedRuntimeTrans compiled
    without optimization
    + S8210432: Add additional TeliaSonera root certificate
    + S8210490: TimeZone.getDisplayName given Locale.US doesn't
    always honor the Locale.
    + S8210695: Create test to cover JDK-8205330 InitialDirContext
    ctor sometimes throws NPE if the server has sent a disconnection
    + S8210754: print_location is not reliable enough (printing
    register info)
    + S8210764: Update avx512 implementation
    + S8210846: TLSv.1.3 interop problems with OpenSSL 1.1.1 when
    used on the client side with mutual auth
    + S8210912: Build error in src/jdk.crypto.cryptoki/share/native/
    /libj2pkcs11/p11_convert.c after JDK-8029661
    + S8210918: Add test to exercise server-side client hello
    processing
    + S8210964: add more ld preloading related info to hs_error
    file on Linux
    + S8211061: Tests fail with
    assert(VM_Version::supports_sse4_1()) on ThreadRipper CPU
    + S8211106: [windows] Update OS detection code to recognize
    Windows Server 2019
    + S8211107: LDAPS communication failure with jdk 1.8.0_181
    + S8211124: HotSpot update for vm_version.cpp to recognise
    updated VS2017
    + S8211231: BarrierSetC1::generate_referent_check() confuses
    register allocator
    + S8211251: Default mask register for avx512 instructions
    + S8211268: Disable unsupported GCs for Zero
    + S8211272: x86_32 build failures after JDK-8210764 (Update
    avx512 implementation)
    + S8211375: Minimal VM build failures after JDK-8211251
    (Default mask register for avx512 instructions)
    + S8211420: com.sun.net.httpserver.HttpServer returns
    Content-length header for 204 response code
    + S8211437: 8211437 java.net.http.HttpClient hangs on 204 reply
    without Content-length 0
    + S8211451: ~2.5%% regression on compression benchmark starting
    with 12-b11
    + S8211714: Need to update vm_version.cpp to recognise VS2017
    minor versions
    + S8211731: Reconsider default option for ClassPathURLCheck
    change done in JDK-8195874
    + S8211806: TLS 1.3 handshake server name indication is missing
    on a session resume
    + S8211844: [aix] ProcessBuilder: Piping between created
    processes does not work.
    + S8211852: inspect stack during error reporting
    + S8211883: Disable anon and NULL cipher suites
    + S8211909: JDWP Transport Listener: dt_socket thread crash
    + S8211926: Catastrophic size_t underflow in BitMap::*_large
    methods
    + S8211931: [ppc][testbug] runtime/jni/terminatedThread/
    /TestTerminatedThread.java fails as threads don't terminate
    immediately
    + S8212005: Epsilon elastic TLAB sizing may cause misalignment
    + S8212070: Introduce diagnostic flag to abort VM on failed JIT
    compilation
    + S8212100: AppCDS crashes for some uses with JRuby
    + S8212116: IIOException "tEXt chunk length is not proper" on
    opening png file
    + S8212177: Epsilon alignment adjustments can overflow max TLAB
    size
    + S8212178: Soft reference reclamation race in
    com.sun.xml.internal.stream.util.ThreadLocalBufferAllocator
    + S8212197: OpenDataException thrown when constructing
    CompositeData for StackTraceElement
    + S8212481: PPC64: Enable POWER9 CPU detection
    + S8212613: Bump update version for jdk11.0.2 cpu forest
    + S8212645: Need change jdk 11.0.2 milestone to ea
    + S8212754: Build failure: undefined
    JvmtiSampledObjectAllocEventCollector::object_alloc_is_safe_to_sample
    + S8212795: ThreadInfoCompositeData.toCompositeData fails to
    map ThreadInfo to CompositeData
    + S8212926: HttpClient does not retrieve files with large sizes
    over HTTP/1.1
    + S8212937: Parent class loader may not have a referred
    ClassLoaderData instance when obtained in
    Klass::class_in_module_of_loader
    + S8213085: (tz) Upgrade time-zone data to tzdata2018g
    + S8213086: Compiler thread creation should be bounded by
    available space in memory and Code Cache
    + S8213151: [AIX] Some class library files are missing the
    Classpath exception
    + S8213154: Update copyright headers of files in src tree that
    are missing Classpath exception
    + S8213367: JDK 11.0.2 l10n resource file update
    + S8213410: UseCompressedOops requirement check fails fails on
    32-bit system
    + S8213527: [testbug] Fix PrintMetaspaceDcmd test using
    UseCompressedOops for 32-bit.
    + S8213763: Need change jdk 11.0.2 milestone to fcs
    + S8213834: JVMTI ResourceExhausted should not be posted in
    CompilerThread
    + S8213942: URLStreamHandler initialization race
    + S8213992: Rename and make DieOnSafepointTimeout the
    diagnostic option
    + S8214059: Undefined behaviour in ADLC
    + S8214061: Buffer written into itself
    + S8214105: [TESTBUG] Bit test is always false in
    serviceability/jvmti/StartPhase/AllowedFunctions
    + S8214108: [TESTBUG] Incorrect Function parameter lists in
    vmTestbase/nsk/jvmti/scenarios/extension/EX03/ex03t001
    + S8214295: Populate handlers while holding streamHandlerLock
    + S8214476: ZGC: Build ZGC by default
    + S8214892: Delayed starting of debugging via jcmd
    + S8215128: Test library OSInfo.getSolarisVersion cannot
    determine Solaris version
    + S8215637: client VM variant build error: zgc (enabled)
    depends on opto (disabled)
    + S8215975: [testbug] Adapt nsk tests to the PPC, S390 and AIX
    platforms.
    + S8216290: Register to register spill may use AVX 512 move
    instruction on unsupported platform.
* Thu Jan 10 2019 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * loadAssistiveTechnologies.patch
    + Do not crash the whole JVM if assistive technologies crash
* Thu Jan 10 2019 Fridrich Strba <fstrba@suse.com>
- Do not resolve by default the added JavaEE modules (fixes
  bsc#1120431)
* Thu Oct 25 2018 Antoine Belvire <antoine.belvire@opensuse.org>
- Remove hardcoded Java version in jconsole desktop file.
* Tue Oct 23 2018 Fridrich Strba <fstrba@suse.com>
- Merge into the JDK following modules from github.com/javaee:
  * com.sum.xml.fastinfoset
  * org.jvnet.staxex
  * com.sun.istack.runtime
  * com.sun.xml.txw2
  * com.sun.xml.bind
    + This provides a default implementation of JAXB-API that
    existed in JDK before Java 11 and that some applications
    depend on.
* Wed Oct 17 2018 Fridrich Strba <fstrba@suse.com>
- Update to upstream tag jdk-11.0.1+13 (Oracle October 2018 CPU)
  * Security fixes:
    + S8202936, CVE-2018-3183, bsc#1112148: Improve script engine
    support
    + S8199226, CVE-2018-3169, bsc#1112146: Improve field accesses
    + S8199177, CVE-2018-3149, bsc#1112144: Enhance JNDI lookups
    + S8202613, CVE-2018-3180, bsc#1112147: Improve TLS connections
    stability
    + S8208209, CVE-2018-3180, bsc#1112147: Improve TLS connection
    stability again
    + S8199172, CVE-2018-3150, bsc#1112145: Improve jar attribute
    checks
    + S8200648, CVE-2018-3157, bsc#1112149: Make midi code more
    sound
    + S8194534, CVE-2018-3136, bsc#1112142: Manifest better support
    + S8208754, CVE-2018-3136, bsc#1112142: The fix for JDK-8194534
    needs updates
    + S8196902, CVE-2018-3139, bsc#1112143: Better HTTP Redirection
  * Security-In-Depth fixes:
    + S8194546: Choosier FileManagers
    + S8195874: Improve jar specification adherence
    + S8196897: Improve PRNG support
    + S8197881: Better StringBuilder support
    + S8201756: Improve cipher inputs
    + S8203654: Improve cypher state updates
    + S8204497: Better formatting of decimals
    + S8200666: Improve LDAP support
    + S8199110: Address Internet Addresses
  * Fixes
    + S7017058: Malayalam glyph substitution is failing for
    Malayalam with Windows Kartika font.
    + S8130655: OS X: keyboard input in textfield is not possible
    if the window contained textfield is owned by EmbeddedFrame
    + S8160104: CORBA communication improvements
    + S8163237: Restrict the use of EXPORT cipher suites
    + S8172525: Improve key keying case
    + S8174756: Extra validation for public keys
    + S8174962: Better interface invocations
    + S8175075: Add 3DES to the default disabled algorithm security
    property
    + S8175932: Improve host instance supports
    + S8176450: Revise default document styling
    + S8178449: Improve LDAP logins
    + S8178458: Better use of certificates in LDAP
    + S8178466: Better RSA parameters
    + S8179533: Cleaner print job handling
    + S8179990: Cleaner palette entry handling
    + S8180011: Cleaner native graphics device handling
    + S8180015: Cleaner AWT robot handling
    + S8180020: Improve SymbolHashMap entry handling
    + S8180869: Cleaner image file reading handling
    + S8180877: More deeply colored ICC spaces
    + S8181664: Improve JVM UTF String handling
    + S8181670: Improve implementation of keystores
    + S8182125: Improve reliability of DNS lookups
    + S8182362: Update CipherOutputStream Usage
    + S8182387: Improve PKCS usage
    + S8182601: Improve usage messages
    + S8183032: Upgrade to LittleCMS 2.9
    + S8185292: Stricter key generation
    + S8185325: Improve GTK initialization
    + S8186032: Disable XML Signatures signed with EC keys less
    than 224 bits
    + S8186080: Transform XML interfaces
    + S8186212: Improve GSS handling
    + S8186600: Improve property negotiations
    + S8186606: Improve LDAP lookup robustness
    + S8186998: Improve JMX supportive features
    + S8187496: Possible memory leak in
    java.apple.security.KeychainStore.addItemToKeychain
    + S8189123: More consistent classloading
    + S8189284: More refactoring for deserialization cases
    + S8189969: Manifest better manifest entries
    + S8189977: Improve permission portability
    + S8189981: Improve queuing portability
    + S8189985: Improve tabular data portability
    + S8189989: Improve container portability
    + S8189993: Improve document portability
    + S8189997: Enhance keystore mechanisms
    + S8190227: Forward port 8188880 to JDK10CPU
    + S8190289: More refactoring for client deserialization cases
    + S8190478: Improved interface method selection
    + S8190789: sun/security/provider/certpath/LDAPCertStore/
    /TestURICertStoreParameters.java fails after JDK-8186606
    + S8190877: Better handling of abstract classes
    + S8191130: Sinhala text rendering problem with
    C+VIRAMA+ZWJ+RA/YA+V
    + S8191142: More refactoring for naming deserialization cases
    + S8191178: [macos] Problem with input of yen symbol
    + S8191239: Improve desktop file usage
    + S8191358: Restore TSA certificate expiration check
    + S8191696: Better mouse positioning
    + S8191907: PPC64 and s390 parts of JDK-8174962: Better
    interface invocations
    + S8192025: Less referential references
    + S8192030: Better MTSchema support
    + S8192757: Improve stub classes implementation
    + S8192789: Avoid using AtomicReference in
    sun.security.provider.PolicyFile
    + S8193409: Improve AES supporting classes
    + S8193414: Improvements in MethodType lookups
    + S8193419: Better Internet address support
    + S8194233: Improve support for array handles
    + S8194238: Trying exceptions in MethodHandles
    + S8194259: keytool error: java.io.IOException: Invalid secret
    key format
    + S8195662: Add T6587786.java to problem list before
    JDK-8195589 is resolved
    + S8195836: opentype:Bengali: "Khanda Ta" shaping issue with
    U+09A4 TA, U+09CD virama, U+200D ZWJ
    + S8196224: Even better Internet address support
    + S8196289: Update src/java.desktop/share/legal/lcms.md for
    LCMS 2.9
    + S8197443: ArrayIndexOutOfBoundsException in
    UcryptoException.getError
    + S8197925: Better stack walking
    + S8199547: Exception to Pattern Syntax
    + S8200332: Improve GCM counting
    + S8204667: Resources not freed on exception
    + S8205479: OS X: requestFocus() does not work properly for
    embedded frame
    + S8205491: adjust reflective access checks
    + S8206389: JarEntry.setCreation/LastAccessTime without
    setLastModifiedTime causes Invalid CEN header
    + S8206392: [macosx] Cycling through windows (JFrames) does not
    work with keyboard shortcut
    + S8206473: Revert changes of JDK-8202613 in jdk-cpu and
    jdk11u-cpu
    + S8206884: Bump update version for jdk11.0.1 cpu forest
    + S8207057: No debug info for assembler files
    + S8207153: Some intrinsic tests take long time to run
    + S8207745: serviceability/sa/TestJmapCore.java times out
    parsing a 4GB hprof file
    + S8207775: Better management of CipherCore buffers
    + S8207941: javax/swing/plaf/basic/BasicGraphicsUtils/8132119/
    /bug8132119.java fails on machines without Arial font
    [testbug]
    + S8207948: JDK 11 L10n resource file update msg drop 10
    + S8208091: SA: jhsdb jstack --mixed throws
    UnmappedAddressException on i686
    + S8208268: 11.0.1 b03 java.net bundles - Release Date is wrong
    + S8208350: Disable all DES cipher suites
    + S8208583: Better management of internal KeyStore buffers
    + S8208595: [parfait] Better X11 font support
    + S8208654: Please change jdk 11.0.1 milestone to FCS
    + S8208661: JDK 11.0.1 l10n resource file update
    + S8208746: ISO 4217 Amendment #168 update
    + S8209129: Further improvements to cipher buffer management
    + S8209639: assert failure in coalesce.cpp: attempted to spill
    a non-spillable item
    + S8209775: ISO 4217 Amendment #169 update
    + S8209786: JDK12 fails to build on s390x with gcc 7.3
    + S8209862: CipherCore performance improvement
    + S8209889: RedefineStress tests crash
    + S8209916: NPE in SupportedGroupsExtension
    + S8209942: [epsilon] range function for EpsilonTLABElasticity
    causes compiler warning
    + S8209996: [PPC64] Fix JFR profiling
    + S8210153: localized currency symbol of VES
    + S8210259: [testbug] IncompatibleOptions.java fails if VM
    configured without ZGC
    + S8210335: Clipping problems with complex affine transforms:
    negative scaling factors or small scaling factors
    + S8210345: The Japanese message of FileNotFoundException
    garbled
    + S8210432: Add additional TeliaSonera root certificate
    + S8210497: [PPC64] Vector registers not saved across safepoint
    + S8210502: jdeps does not handle properly on analyzing a
    mixture of MR JARs and non-MR JARs
    + S8210647: libsaproc is being compiled without optimization.
    + S8210703: vmStructs.cpp compiled with -O0
    + S8210736: jdk/javax/xml/crypto/dsig/GenerationTests.java slow
    on linux
    + S8210761: libjsig is being compiled without optimization
    + S8210775: JVM TI Spec missing copyright
    + S8210810: Escaped character at specific position in argument
    file is not handled properly
    + S8210836: Build fails with warn_unused_result in
    openjdk/src/jdk.hotspot.agent/linux/native/libsaproc/ps_core.c
    + S8210846: TLSv.1.3 interop problems with OpenSSL 1.1.1 when
    used on the client side with mutual auth
    + S8211065: Private method check in linkResolver is incorrect
    + S8211105: AArch64: Disable cos/sin and log intrinsics in
    jdk11u pending fix
    + S8211107: LDAPS communication failure with jdk 1.8.0_181
    + S8211165: License header is absent in a few J2Ddemo source
    code files
    + S8211208: make AllocateHeapAt an unsupported option on AIX
    + S8211387: [Zero] atomic_copy64: Use ldrexd for atomic reads
    on ARMv7
    + S8211731: Reconsider default option for ClassPathURLCheck
    change done in JDK-8195874
    + S8211768: [s390] Implement JFR profiling
    + S8211856: [ppc, s390] ProblemList some failing tests.
    + S8211916: Javadoc -link makes broken links if module name
    matches package name
    + S8212110: Build of saproc.dll broken on Windows 32 bit after
    JDK-8210647
    + S8212204: [TESTBUG] test/hotspot/jtreg/compiler/intrinsics/
    /base64/TestBase64.java fails
- Removed patches:
  * RHBZ-1628612-JDK-8210461-workaround-disable-aarch64-intrinsic.patch
  * RHBZ-1630996-JDK-8210858-workaround-disable-aarch64-intrinsic-log.patch
    + Integrated upstream
* Wed Oct  3 2018 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add patches to workaround aarch64 critical bugs:
  * RHBZ-1628612-JDK-8210461-workaround-disable-aarch64-intrinsic.patch
  * RHBZ-1630996-JDK-8210858-workaround-disable-aarch64-intrinsic-log.patch
* Tue Sep 25 2018 Fridrich Strba <fstrba@suse.com>
- Official OpenJDK 11 release (fate#324453, fate#323970, bsc#1111162)
  * Pull the sources from the jdk-updates/jdk11u repository from
    now on.
  * Remove the buildver from the rpm version string
* Tue Sep 11 2018 Fridrich Strba <fstrba@suse.com>
- Update jax-ws-spec and jaxb-spec tarball to the latest versions
- Modified patch:
  * annotation-module.patch
    + module name change from java.xml.ws.annotation to
    java.annotation
* Mon Sep 10 2018 Mark Hammons <markehammons@gmail.com>
- Update configuration flags to enable ZGC on x86_64 platforms
* Thu Aug 23 2018 fstrba@suse.com
- Update to upstream tag jdk-11+28 (OpenJDK 11 rc1)
  * Fixes:
    + S8207317: SSLEngine negotiation fail exception behavior
    changed from fail-fast to fail-lazy
    + S8207838: AArch64: Float registers incorrectly restored in
    JNI call
    + S8209637: [s390x] Interpreter doesn't call result handler
    after native calls
    + S8209670: CompilerThread releasing code buffer in destructor
    is unsafe
    + S8209735: Disable avx512 by default
    + S8209806: API docs should be updated to refer to javase11
- Report version without the "-internal" postfix
* Tue Aug 21 2018 fstrba@suse.com
- Added patch:
  * jaw-nogtk.patch
    + Don't build against gdk making the accessibility depend on a
    particular version of gtk.
* Mon Aug 20 2018 fstrba@suse.com
- Update to upstream tag jdk-11+27
  * Fixes:
    + S8031761: [TESTBUG] Add a regression test for JDK-8026328
    + S8151259: [TESTBUG] nsk/jvmti/RedefineClasses/redefclass030
    fails with "unexpected values of outer fields of the class"
    when running with -Xcomp
    + S8164639: Configure PKCS11 tests to use user-supplied NSS
    libraries
    + S8189667: Desktop#moveToTrash expects incorrect "<<ALL
    FILES>>" FilePermission
    + S8194949: [Graal] gc/TestNUMAPageSize.java fail with OOM in
  - Xcomp
    + S8195156: [Graal] serviceability/jvmti/GetModulesInfo/
    /JvmtiGetAllModulesTest.java fails with Graal in Xcomp mode
    + S8199081: [Testbug] compiler/linkage/LinkageErrors.java fails
    if run twice
    + S8201394: Update java.se module summary to reflect removal of
    java.se.ee module
    + S8204931: Colors with alpha are painted incorrectly on Linux
    + S8204966: [TESTBUG] hotspot/test/compiler/whitebox/
    /IsMethodCompilableTest.java test fails with
  - XX:CompileThreshold=1
    + S8205608: Fix 'frames()' in ThreadReferenceImpl.c to prevent
    quadratic runtime behavior
    + S8205687: TimeoutHandler generates huge core files
    + S8206176: Remove the temporary tls13VN field
    + S8206258: [Test Error] sun/security/pkcs11 tests fail if NSS
    libs not found
    + S8206965: java/util/TimeZone/Bug8149452.java failed on de_DE
    and ja_JP locale.
    + S8207009: TLS 1.3 half-close and synchronization issues
    + S8207046: arm32 vm crash: C1 arm32 platform functions
    parameters type mismatch
    + S8207139: NMT is not enabled on Windows 2016/10
    + S8207237: SSLSocket#setEnabledCipherSuites is accepting empty
    string
    + S8207355: C1 compilation hangs in
    ComputeLinearScanOrder::compute_dominator
    + S8207746: C2: Lucene crashes on AVX512 instruction
    + S8207765: HeapMonitorTest.java intermittent failure
    + S8207944: java.lang.ClassFormatError: Extra bytes at the end
    of class file test" possibly violation of JVMS 4.7.1
    + S8207948: JDK 11 L10n resource file update msg drop 10
    + S8207966: HttpClient response without content-length does not
    return body
    + S8208125: Cannot input text into JOptionPane Text Input Dialog
    + S8208164: (str) improve specification of String::lines
    + S8208166: Still unable to use custom SSLEngine with default
    TrustManagerFactory after JDK-8207029
    + S8208189: ProblemList compiler/graalunit/JttThreadsTest.java
    + S8208205: ProblemList tests that fail due to 'Error attaching
    to process: Can't create thread_db agent!'
    + S8208226: ProblemList com/sun/jdi/BasicJDWPConnectionTest.java
    + S8208251: serviceability/jvmti/HeapMonitor/MyPackage/
    /HeapMonitorGCCMSTest.java fails intermittently on Linux-X64
    + S8208305: ProblemList
    compiler/jvmci/compilerToVM/GetFlagValueTest.java
    + S8208347: ProblemList
    compiler/cpuflags/TestAESIntrinsicsOnSupportedConfig.java
    + S8208353: Upgrade JDK 11 to libpng 1.6.35
    + S8208358: update bug ids mentioned in tests
    + S8208370: fix typo in ReservedStack tests' @requires
    + S8208391: Differentiate response and connect timeouts in HTTP
    Client API
    + S8208466: Fix potential memory leak in harfbuzz shaping.
    + S8208496: New Test to verify concurrent behavior of TLS.
    + S8208521: ProblemList more tests that fail due to 'Error
    attaching to process: Can't create thread_db agent!'
    + S8208640: [a11y] [macos] Unable to navigate between
    Radiobuttons in Radio group using keyboard.
    + S8208663: JDK 11 L10n resource file update msg drop 20
    + S8208676: Missing NULL check and resource leak in
    NetworkPerformanceInterface::NetworkPerformance::network_utilization
    + S8208691: Tighten up jdk.includeInExceptions security property
    + S8209011: [TESTBUG] AArch64: sun/security/pkcs11/Secmod/
    /TestNssDbSqlite.java fails in aarch64 platforms
    + S8209029: ProblemList tests that fail due to 'Error attaching
    to process: Can't create thread_db agent!' in jdk-11+25
    testing
    + S8209149: [TESTBUG] runtime/RedefineTests/
    /RedefineRunningMethods.java needs a longer timeout
    + S8209451: Please change jdk 11 milestone to FCS
    + S8209452: VerifyCACerts.java failed with "At least one cacert
    test failed"
    + S8209506: Add Google Trust Services GlobalSign root
    certificates
    + S8209537: Two security tests failed after JDK-8164639 due to
    dependency was missed
* Thu Jul 26 2018 fstrba@suse.com
- Update to upstream tag jdk-11+24 (Oracle July 2018 CPU)
  * Security fixes:
    + S8197925: Better stack walking (CVE-2018-2940, bsc#1101645)
    + S8199547: Exception to Pattern Syntax (CVE-2018-2952,
    bsc#1101651)
    + S8200332: Improve GCM counting (CVE-2018-2972, bsc#1101655)
    + S8200666: Improve LDAP support (CVE-2018-2973, bsc#1101656)
  * Security-In-Depth fixes:
    + S8191239: Improve desktop file usage
    + S8193419: Better Internet address support
  * Fixes:
    + S8189922: UseNUMA memory interleaving vs membind
    + S8196224: Even better Internet address support
    + S8202837: PBES2 AlgorithmId encoding error in PKCS12 KeyStore
    + S8203230: update VerifyCACerts test
    + S8203504: [Graal]
    org.graalvm.compiler.debug.test.DebugContextTest fails with
    java.util.ServiceConfigurationError
    + S8203820: [TESTBUG]
    vmTestbase/metaspace/staticReferences/StaticReferences.java
    timed out
    + S8204196: integer cleanup
    + S8205390: jtreg: Fix failing TestRTMSpinLoopCount on PPC64
    + S8205491: adjust reflective access checks
    + S8205578: jtreg: Fix failing TestRTMAbortRatio on PPC64
    + S8205580: PPC64: RTM: Don't retry lock on abort if abort was
    intentional
    + S8205581: PPC64: RTM: Fix abort on native calls
    + S8205582: PPC64: RTM: Fix counter for aborts on nested
    transactions
    + S8206171: Signature#getParameters for RSASSA-PSS throws
    ProviderException when not initialized
    + S8206241: compiler/graalunit/PhasesCommonTest.java fails with
    java.lang.Error: TESTBUG: no tests found for prefix
    org.graalvm.compiler.phases.common.test
    + S8206445: JImageListTest.java failed in Windows
    + S8206456: [TESTBUG] docker jtreg tests fail on systems
    without cpuset.effective_cpus / cpuset.effective_mem
    + S8206865: RMI activation tests fail with InvalidClassException
    + S8206886: Java does not set the default format locale
    correctly on mac10.13
    + S8206931: Misleading "COMPILE SKIPPED: invalid non-klass
    dependency" compile log
    + S8207056: Epsilon GC to support object pinning
    + S8207069: [AOT] we should check that VM uses the same GC as
    one used for AOT library generation.
    + S8207223: SSL Handshake failures are reported with more
    generic SSLException
    + S8207243: Fix translation filtering to also support zh_HK and
    zh_TW
    + S8207244: java/nio/channels/Selector/SelectWithConsumer.java
    testInterruptDuringSelect() fails intermittently
    + S8207250: setUseClientMode post handshake with the same value
    as before does not throw IAE
    + S8207252: C1 still does eden allocations when TLAB is enabled
    + S8207365: Make man pages optional
    + S8207380: compiler/graalunit/JttLangMTest.java timeout
    + S8207383: [Graal] SelfChangedCDS.java fails with
    "guarantee(disp == (intptr_t)(jint)disp) failed: must be
    32-bit offset"
    + S8207392: [PPC64] Implement JFR profiling.
    + S8207584: ARM32: ShouldNotReachHere assertion on Test8168712
    jtreg test
    + S8207761: Split compiler/graalunit/JttReflectFTest.java
    + S8207765: HeapMonitorStatIntervalTest.java fails with ZGC
    + S8207766: [testbug] Adapt tests for Aix.
    + S8207818: Problem list several rmi tests
    + S8207819: Problem list serviceability/jvmti/HeapMonitor/
    /MyPackage/HeapMonitorStatRateTest.java
    + S8207830: [aix] disable jfr in build and tests
    + S8207833: java/nio/channels/Selector/SelectWithConsumer.java
    testCancel() fails intermittently
    + S8207846: Generalize the jdk.net.includeInExceptions security
    property
    + S8207915: [AOT] jaotc w/ '--ignore-errors' should ignore
    illegal class files
    + S8207952: Problem-list 3 sctp tests
    + S8207959: The initial value of
    SETTINGS_MAX_CONCURRENT_STREAMS should have no limit
    + S8207960: Non-negative WINDOW_UPDATE increments may leave the
    stream window size negative
    + S8208075: Quarantine vmTestbase/nsk/jvmti/RedefineClasses/
    /StressRedefineWithoutBytecodeCorruption/TestDescription.java
    + S8208092: ProblemList serviceability/sa/ClhsdbCDSCore.java
    + S8208096: Update build documentation to reflect compiler
    upgrades at Oracle
    + S8208111: Problem list
    java/nio/channels/Selector/RacyDeregister.java
* Fri Jul 20 2018 fstrba@suse.com
- Update to upstream tag jdk-11+23
  * Fixes
    + S8181855: [Graal]
    runtime/ReservedStack/ReservedStackTest.java triggers:
    assert(thread->deopt_mark() == __null) failed: no stack
    overflow from deopt blob/uncommon trap
    + S8189747: JDK9 javax.lang.model.util.Elements#getTypeElement
    regressed 1000x in performance.
    + S8191948: db error: InvalidTypeException: Can't assign
    double[][][] to double[][][]
    + S8199779: Add T-Systems, GlobalSign and Starfield services
    root certificates
    + S8200282: Serializing non-zero byte as zero to ByteBuffer
    + S8202481: RegisterDuringSelect.java fails with
    java.util.concurrent.ExecutionException:
    java.nio.channels.ClosedSelectorException
    + S8204860: The frame could be resized by dragging a corner of
    the frame with the mouse
    + S8205541: serviceability/jvmti/HeapMonitor/MyPackage/
    /HeapMonitorStatArrayCorrectnessTest.java fails with Should
    not have any events stored yet.
    + S8205576: forkjoin/FJExceptionTableLeak.java fails
    "AssertionError: failed to satisfy condition"
    + S8205643: HeapMonitorGCCMSTest fails with Graal
    + S8205652: serviceability/jvmti/HeapMonitor/MyPackage/
    /HeapMonitorStatRateTest.java fails
    + S8205725: Update the JVMTI Spec for Heap Sampling
    + S8205967: Remove sun/security/krb5/auto/UnboundSSL.java from
    ProblemList.txt
    + S8206189: sun/security/pkcs12/EmptyPassword.java fails with
    Sequence tag error
    + S8206238: Aspect ratio is not maintained when Image is scaled
    in JEditorPane
    + S8206265: aarch64 jtreg: assert in TestOptionsWithRanges.jtr
    + S8206271: CodeHeap State Analytics must digest new method
    state
    + S8206448: (fs) Extended attributes assumed to be enabled on
    ext3 (lnx)
    + S8206471: Race with ConcurrentHashTable deleting items on
    insert with cleanup thread
    + S8206873: 2 Null pointer dereference defect groups in
    LIRGenerator
    + S8206903: Unable to build Client VM with JVMCI
    + S8206915: XDH TCK issues
    + S8206929: Check session context for TLS 1.3 session resumption
    + S8206953: compiler/profiling/TestTypeProfiling.java fails
    when JVMCI build disabled
    + S8206960: HeapMonitor tests fail with Graal
    + S8206975: AArch64: Fix CompareAndSwapOp when useLSE is
    enabled in Graal
    + S8206977: Minor improvements of runtime code.
    + S8206980: ZonedDateTime could not parse timezone name with
    zh_CN locale correctly.
    + S8206998: [test] runtime/ElfDecoder/TestElfDirectRead.java
    requires longer timeout on ppc64
    + S8207001: *.obj.log files get truncated causing unreliable
    incremental builds on Windows
    + S8207006: serviceability/sa/TestUniverse.java#id0 crashes
    with EpsilonGC and AOT
    + S8207023: Add trace info to
    java/nio/channels/Selector/RegisterDuringSelect.java
    + S8207027: Lookup.accessClass fails for an array type in the
    same package when assertions are enabled
    + S8207029: Unable to use custom SSLEngine with default
    TrustManagerFactory after updating to JDK 11 b21
    + S8207032: Compilation succeeds without checking readability
    when --add-exports used
    + S8207044: minimal vm build fail: missing #include
    + S8207047: Multiple VM variants build fail
    + S8207049: Minor improvements of compiler code.
    + S8207065: Cleanup compiler tests for Client VM
    + S8207067: [test] prevent timeouts in
    serviceability/tmtools/jstat/{GcTest02,GcCauseTest02}.java
    + S8207068: Add Entrust root certificates
    + S8207152: Placeholder for Japanese new era should be two
    characters
    + S8207190: JDK 11 javadoc generates bad code example
    + S8207210: Problem list
    javax/sound/sampled/Clip/AutoCloseTimeCheck.java
    + S8207213: The help-doc.html generated by the doclet is
    incomplete
    + S8207217: Problem list
    java/lang/management/ThreadMXBean/AllThreadIds.java
    + S8207233: Minor improvements of jdk C-coding
    + S8207235:
    ManagementFactory.getPlatformMXBeans(BufferPoolMXBean.class)
    throws NPE
    + S8207240: AARCH64: C2-only VM does not build
    + S8207261: [Graal] JDI and JDWP tests that consume all memory
    should be filtered out to not run with Graal
    + S8207265: Bad HTML in {@link} in
    HttpResponse.BodySubscribers.ofPublisher
    + S8207318: KeyStore#getInstance(File, LoadStoreParameter) does
    not load the keystore
    + S8207342: error occurred during error reporting (printing
    register info)
    + S8207345: AArch64: Trampoline generation code reads from
    unitialized memory
    + S8207763: serviceability/jvmti/HeapMonitor/MyPackage/
    /HeapMonitorStatRateTest.java failed with Error. Parse
    Exception: Can't find source file:
    HeapMonitorStatIntervalTest.java
* Sat Jul 14 2018 fstrba@suse.com
- Merge standalone modules java.activation, java.xml.bind,
  java.xml.soap, java.xml.ws.annotation and java.xml.ws into the
  OpenJDK
- Added patches:
  * activation-module.patch
    + add module-info.java file for java.activation module
  * annotation-module.patch
    + add module-info.java file for java.xml.ws.annotation
* Thu Jul 12 2018 fstrba@suse.com
- Update to upstream tag jdk-11+22
  * Fixes
    + S8185740: The help-doc.html generated by the doclet is
    outdated
    + S8187069: The case auto failed with the
    java.lang.ClassNotFoundException:
    IPv6NameserverPlatformParsingTest exception
    + S8189604: possible hang in
    sun.awt.shell.Win32ShellFolder2$KnownFolderDefinition::<clinit>
    + S8193126: Incorrect setting of MetaspaceSize and
    NewSizeThreadIncrease when using JVMCI compiler
    + S8194740: UseSubwordForMaxVector causes performance regression
    + S8198346: assert(!_cld->claimed()) failed in
    TestObjectDescription.java
    + S8198352: java.util.MissingResourceException:
    sun.security.util.AuthResources when trying to use
    com.sun.security.auth.module.UnixLoginModule
    + S8198405: JImageExtractTest.java & JImageListTest.java failed
    in Windows.
    + S8198819: tools/jimage/JImageExtractTest.java, fails
    intermittently at testExtract (macos)
    + S8199645: javax/net/ssl/SSLSession/TestEnabledProtocols.java
    failed with Connection reset
    + S8201611: Broken links in java.desktop javadoc
    + S8202123: C2 Crash in Node::in(unsigned int) const+0x14
    + S8202264: Race condition in AudioClip.loop()
    + S8202329: [AIX] Fix codepage mappings for IBM-943 and Big5
    + S8202561: clean up TEST.groups file
    + S8202769: jck test fails with C2:
    vm/jvmti/FollowReferences/fref001/fref00113/fref00113.html
    + S8203007: Address missing block coverage for ChaCha20 and
    Poly1305 algorithms
    + S8203943: eventThreadGroup was null in
    TestJavaBlockedEvent.java
    + S8204603: Short week days, NaN value and timezone name are
    inconsistent between CLDR and Java in zh_CN, zh_TW locales.
    + S8204630: Generating an anonymous class with
    Filer#createClassFile causes an NPE in
    JavacProcessingEnvironment
    + S8204691: HeapRegion.apply_to_marked_objects_other_vm_test
    fails with assert(!hr->is_free() || hr->is_empty()) failed:
    Free region 0 is not empty for set Free list #
    + S8205426: Humongous continues remembered set does not match
    humongous start region one after Remark
    + S8205454: &amp; is displayed in some Swing docs
    + S8205472: Deadlock in Kitchensink when trying to print
    compile queues causing timeout
    + S8205588: Deprecate for removal com.sun.awt.SecurityWarning
    + S8205646: Broken link in jdk.jsobject
    + S8205878: pthread_getcpuclockid is expected to return 0 code
    + S8205924: ZGC: Premature OOME due to failure to expand
    backing file
    + S8205928: [TESTBUG]
    jdk/internal/platform/docker/TestDockerMemoryMetrics
    + S8205966: [testbug] New Nestmates JDI test times out with
    Xcomp on sparc
    + S8205973: Client jtreg ProblemList cleanup
    + S8205999: C2 compilation fails with
    "assert(store->find_edge(load) != -1) failed: missing
    precedence edge"
    + S8206001: Enable TLS1.3 by default in Http Client
    + S8206106: [solaris sparc] jck tests
    api/javax_print/PrintService failing
    + S8206135: Building jvm with AOT but without JVMCI should fail
    at configure time
    + S8206145: dbgsysSocketClose - do not restart close if errno
    is EINTR [linux]
    + S8206163: AArch64: incorrect code generation for StoreCM
    + S8206173: MallocSiteTable::initialize() doesn't take function
    descriptors into account
    + S8206184: docs-reference build fails due to
    extlink.spec.version property not set
    + S8206243: java -XshowSettings fails if memory.limit_in_bytes
    overflows LONG.max
    + S8206254: Unable to complete emergency dump during safepoint
    + S8206255: fix compiler/intrinsics/sha/cli/
    /TestUseSHAOptionOnSupportedCPU.java jtreg test on linux s390x
    + S8206287: fix legal notice in hotspot tests
    + S8206316: ZGC: Preferred tmpfs mount point not found on Debian
    + S8206322: ZGC: Incorrect license header in gtests
    + S8206323: Missing some legal notices in docs bundle
    + S8206324: compiler/whitebox/DeoptimizeFramesTest.java to
    ProblemList-graal.txt
    + S8206355: SSLSessionImpl.getLocalPrincipal() throws NPE
    + S8206375: ProblemList update of bug ID for
    SwingFontMetricsTest
    + S8206378: Backout JDK-8202561
    + S8206394: missing ResourceMark in
    AOTCompiledMethod::metadata_do,
    AOTCompiledMethod::clear_inline_caches,
    CompiledMethod::clear_ic_stubs,
    CompiledMethod::cleanup_inline_caches_impl
    + S8206408: Add missing CPU/system info to vm_version_ext on
    PPC64
    + S8206428: Upgrade JDK11 to harfbuzz 1.8.2
    + S8206429: [REDO] 8202561 clean up TEST.groups
    + S8206433: Several jib profiles missing autoconf dependency
    + S8206436: sun/nio/cs/TestIBMBugs.java no longer compiles
    + S8206450: Add JImageListTest.java to ProblemList.txt
    + S8206459: [s390] Prevent restoring incorrect bcp and locals
    in interpreter and avoid incorrect size of
    partialSubtypeCheckNode in C2
    + S8206476: Wrong assert in phase_enum_2_phase_string() in
    referenceProcessorPhaseTimes.cpp
    + S8206919: s390: add missing info to vm_version_ext_s390
    + S8206951: [Graal]
    org.graalvm.compiler.hotspot.test.GraalOSRTest to
    ProblemList-graal.txt
    + S8206952: java/lang/Class/GetPackageBootLoaderChildLayer.java
    fails with Graal
    + S8206954: Test runtime/Thread/ThreadPriorities.java crashes
    with SEGV in pthread_getcpuclockid
    + S8207007: Add missing license header to zHash.inline.hpp
* Thu Jul 12 2018 guillaume.gardet@opensuse.org
- Switch armv6 to zero JVM variant (without JIT) since client and
  server JVM do not build for armv6 ATM
* Thu Jul  5 2018 fstrba@suse.com
- Update to upstream tag jdk-11+21
  * Fixes:
    + S8201552: Ellipsis in "Classical" label in SwingSet2 demo
    with Windows L&F at Hidpi
    + S8203848: Missing remembered set entry in j.l.ref.references
    after JDK-8203028
    + S8204355: [Graal] org.graalvm.compiler.debug.test.CSVUtilTest
    fails on Windows due to improper line separator used
    + S8204517: [Graal]
    org.graalvm.compiler.debug.test.VersionsTest fails with
    InvalidPathException on windows
    + S8205515: assert(opcode == Op_RangeCheck) failed: no other if
    variant here
    + S8205563: modules/AnnotationProcessing.java failed
    testGenerateSingleModule
    + S8205720: KeyFactory#getKeySpec and translateKey throws
    NullPointerException with Invalid key
    + S8205965: SIGSEGV on write to NativeCallStack::EMPTY_STACK
    + S8205984: javax/net/ssl/compatibility/Compatibility.java
    failed to access port log file
    + S8206003: SafepointSynchronize with TLH: StoreStore barriers
    should be moved out of the loop
    + S8206093: compiler/graalunit/HotspotTest.java fails in
    CheckGraalIntrinsics
    + S8206117: failed to get JDK properties for JVM w/o JVMCI
* Mon Jul  2 2018 fstrba@suse.com
- Update to upstream tag jdk-11+20 (rampdown phase 1)
  * Fixes:
    + S4475138: getBestCursorSize and XFree86 4.1.0
    + S7007966: Add Brainpool ECC support (RFC 5639)
    + S8003209: JFR events for network utilization
    + S8010319: Implementation of JEP 181: Nest-Based Access Control
    + S8060192: Add default method <A> A[]
    Collection.toArray(IntFunction<A[]> generator)
    + S8066709: Make some JDK system properties read only
    + S8137164: Include PID in the JFR jcmd hint
    + S8144992: Remove OopIterateClosure::idempotent
    + S8149729: [jittester] Replace all 'path1 +"/" + path2' with
    Paths::get
    + S8153732: Windows remote printer changes do not reflect in
    lookupPrintServices()
    + S8155192: [TESTBUG] SHA tests assumes that x86 does not have
    SHA intrinsics
    + S8160673: Jittester: investigate bytecode generation hangs
    during bytecode tests generation
    + S8169559: Add class loader names to relevant VM messages
    + S8172854: [TESTBUG] Exclude
    runtime/ReservedStack/ReservedStackTest.java from being run
    with DeoptimizeALot option
    + S8185927: create regression test for 8062950
    + S8187100: Support Unicode Variation Selectors
    + S8187218: GSSCredential.getRemainingLifetime() returns
    negative value for TTL > 24 days.
    + S8187288: bad (no) wrapping for modifier and type column
    + S8189103: AARCH64: optimize String indexOf intrinsic
    + S8189105: AARCH64: create intrinsic for sin and cos
    + S8189112: AARCH64: optimize StringUTF16 compress intrinsic
    + S8189113: AARCH64: StringLatin1 inflate intrinsic doesn't use
    prefetch instruction
    + S8189429: SA: MacOSX: Replace the deprecated PT_ATTACH with
    PT_ATTACHEXC
    + S8190876: javadoc search on "java.se" shows "java.se" the
    last one among other modules
    + S8192953: sun/management/jmxremote/bootstrap/*.sh tests fail
    with error : revokeall.exe: Permission denied
    + S8194152: sun/security/tools/jarsigner/AltProvider.java
    failed on de-DE locale
    + S8194873: right ALT key hotkeys no longer work in Swing
    components
    + S8194937: Inconsistent behavior of --validate-modules when
    combined with -m and other options
    + S8195077: [Testbug] tools/javac/processing/model/
    /completionfailure/NoAbortForBadClassFile.java -
    AccessDeniedException
    + S8195607: sun/security/pkcs11/Secmod/TestNssDbSqlite.java
    failed with "NSS initialization failed" on NSS 3.34.1
    + S8195630: [Graal] vmTestbase/nsk/jvmti/AttachOnDemand/
    /attach024/TestDescription.java fails with Graal
    + S8195650: Method references to VarHandle accessors
    + S8195986: Incorrect javac -h output with annotation
    processing and missing classes
    + S8196213: sun/security/tools/jarsigner/warnings/
    /NoTimestampTest.java test fails on ar_SA locale.
    + S8196402: AARCH64: create intrinsic for Math.log
    + S8196425: tools/javac/modules/AnnotationProcessing.java failed
    + S8196584: TLS 1.3 Implementation
    + S8197425: Liveset information for Old Object sample event
    + S8197532: Re-examine policy for the default set of modules
    when compiling or running code on the class path
    + S8198372: API to create a SelectableChannel to a
    FileDescriptor
    + S8198909: [Graal] compiler/codecache/stress/
    /UnexpectedDeoptimizationTest.java crashed with SIGSEGV
    + S8199124: (fs) Reduce allocation for file system methods that
    are invoked with no open options
    + S8199265: java/util/Arrays/TimSortStackSize2.java fails with
    OOM
    + S8199580: [TESTBUG] Un-quarantine vm/mlvm/indy/func/jdi/
    /breakpointOtherStratum and breakpoint
    + S8199940: Print more information about class loaders in
    IllegalAccessErrors.
    + S8200243: System error message is decoded as invalid encoding
    in Windows.
    + S8200720: Print additional information in thread dump (times,
    allocated bytes etc.)
    + S8201610: Broken link on the page
    api/java.rmi/java/rmi/server/UnicastRemoteObject.html
    + S8201815: Use Mozilla Public Suffix List
    + S8202292: java/io/FileOutputStream/UnreferencedFOSClosesFd.java
    fails with "raw fd count wrong"
    + S8202299: Java Keystore fails to load PKCS12/PFX certificates
    created in WindowsServer2016
    + S8202326: AARCH64: optimize string compare intrinsic
    + S8202331: Obsolete support for commercial features
    + S8202422: value of 'sizeCtl' in ConcurrentHashMap varies with
    the constructor called
    + S8202554: Remove hotspot tests for javafx.* modules
    + S8202608: CommonSeeder test needs a white-box testing
    mechanism to replace the default entropy source
    + S8202615: Remove NativeMonitorSpinLimit, NativeMonitorFlags
    and NativeMonitorTimeout experimental flags
    + S8202696: Remove exclusion range for phonetic chars in
    windows fontconfig.properties
    + S8202698: Update Graal for JEP 181 - Nest-based access control
    + S8202788: Explicitly reclaim cached thread-local direct
    buffers at thread exit
    + S8202922: Method reference identity is broken by serialization
    + S8203003: Several FileDialog Modality Tests fail on Linux due
    to X errors
    + S8203184: List.copyOf() fails to copy sublists
    + S8203188: Add JEP-181 support to the Zero interpreter
    + S8203228: Branch-free output conversion for X25519 and X448
    + S8203299: StringPoolBuffer access covered by exclusive access
    invariant, remove (problematic) cas operations
    + S8203481: Incorrect constraint for unextended_sp in
    frame:safe_for_sender
    + S8203664: JFR start failure after AppCDS archive created with
    JFR StartFlightRecording
    + S8203670: unmodifiable List iterator() implementations should
    not be ListIterators
    + S8203681: Miscellaneous changes imported from jsr166 CVS
    2018-06
    + S8203814: javac --release=8 "cannot find symbol" for
    NashornException.getEcmaError()
    + S8203864: Execution error in Java's Timsort
    + S8203929: Limit amount of data for JFR.dump
    + S8204082: Make names of Young GCs more uniform in logs
    + S8204157: Compiler.sunflow hangs after JDK-8192992
    + S8204209: [Graal] Compilation fails during nmethod printing
    with "assert(bci == 0 || 0 <= bci && bci < code_size())
    failed: illegal bci"
    + S8204233: Add configurable option for enhanced socket
    IOException messages
    + S8204289: AARCH64: enable math intrinsics usage in
    interpreter and C1
    + S8204331: AArch64: fix CAS not embedded in normal graph error
    + S8204492: Add deprecation annotation to Nashorn APIs and
    warning to nashorn, jjs
    + S8204524: Unnecessary memory barriers in
    G1ParScanThreadState::copy_to_survivor_space
    + S8204540: Automatic oop closure devirtualization
    + S8204661: Show error 'Port already in use' in
    HashedPasswordFileTest.java
    + S8204930: Reader:nullReader() spec does not match the behavior
    + S8204946: Clean-up problem list for JDK-8202933 and
    JDK-8202934
    + S8204967: Resolve disabled warnings for libunpack
    + S8205004: AArch64: fix failures in jtreg ArraysEqCmpTest
    + S8205053: Decouple type registration from framework lifecycle
    + S8205058: (fs) Files read/writeString should throw
    CharacterCodingException instead of IOException with an
    IllegalArgumentException as cause
    + S8205107: assert(c->Opcode() == Op_SafePoint) failed: broken
    outer loop
    + S8205111: Develop new Test to verify different key types for
    supported TLS protocols.
    + S8205113: Update JVMTI doc references to object allocation
    tracking
    + S8205119: SwingApplet demo should be removed
    + S8205136: Move StylePad demo to the open repository
    + S8205144: JSpinner may change the font after became visible
    + S8205153: Delete "standard instructions" machinery in the
    open automated tests
    + S8205158: Update the .md files for 3rd party software Unicode
    10.0, ICU 60.2, and CLDR v33.
    + S8205160: jQuery UI, jQuery-migrate, and jQuery license file
    to be updated to the revision present.
    + S8205175: Deprecate UnlinkSymbolsALot debugging option.
    + S8205184: Delegating Iterator implementations that don't
    delegate forEachRemaining()
    + S8205194: Improve the Array Comparison when there is mismatch
    at first element.
    + S8205195: NestedThreadsListHandleInErrorHandlingTest fails
    because hs_err doesn't contain _nested_thread_list_max
    + S8205197: Never default to using libc++ on Linux
    + S8205199: more Linux clang compile failures
    + S8205207: Port Graal unit tests under jtreg
    + S8205324: Part of java.awt.Desktop.browse(URI) spec is
    outdated after support of applets was removed
    + S8205342: windows : potential memleaks in getAdapter(s) in
    NetworkInterface_winXP.c
    + S8205397: InetAddress has wrong declaration for
    readObjectNoData
    + S8205398: AES-CBC decryption algorithm using AVX512
    instructions
    + S8205400: [Graal]
    compiler/jvmci/compilerToVM/DisassembleCodeBlobTest.java fails with
    can't be enqueued for compilation on level 4
    + S8205405: ZGC: Decouple JFR type registration
    + S8205416: windows: fix checking of CloseHandle return code in
    Java_java_io_FileCleanable_cleanupClose0
    + S8205419: [testbug] TestJmapCore failing without SA:
    introduce @requires vm.hasSAandCanAttach
    + S8205422: assert(false) failed: Bad verification_type_info
    + S8205424: Change to Xcode 9.4 for building on Macosx at Oracle
    + S8205438: Re-enable shebang tests in
    test/jdk/tools/launchers/SourceMode.java
    + S8205441: Upgrade to harfbuzz 1.8.1
    + S8205442: Avoid hard-coding --source value in
    SourceLauncherTest.java
    + S8205445: Add RSASSA-PSS Signature support to SunMSCAPI
    + S8205455: jdeprscan issues annotation processor warning
    regarding RELEASE_10
    + S8205456: Unification of iterations over arrays
    + S8205459: Rename Access API flag decorators
    + S8205474: AARCH64: wrong zr encoding for ccmp instruction
    + S8205475: AARCH64: optimize FPU loads and stores in
    C1_Runtime1_aarch64.cpp
    + S8205490: update ProblemList-graal
    + S8205494: Convert or remove all AWT applet demos
    + S8205498: Typo in fix for 8205119 breaks Solaris demo build
    + S8205499: C1 temporary code buffers are not removed with
  - XX:+UseDynamicNumberOfCompilerThreads
    + S8205508: hotspot/jtreg/vmTestbase/nsk/jdb/exclude/exclude001/
    /exclude001.java fails with Prompt is not received during
    300200 milliseconds.
    + S8205509: assert(_name_and_id != 0LL) failed: encountered a
    class loader null name and id
    + S8205528: Base64 encoding algorithm using AVX512 instructions
    + S8205531: jcmd VM.classloaders should fold similar loaders
    + S8205533: Class.getPackage() fails with InternalError if
    class is defined to the bootstrap class loader but module is
    not in the boot layer
    + S8205540: test/hotspot/jtreg/vmTestbase/nsk/jdb/trace/
    /trace001/trace001.java fails with Debuggee did not exit
    after 15 <cont> commands
    + S8205547: FileChannel/CleanerTest.java fails due to expected
    FD count
    + S8205559: Remove IN_CONCURRENT_ROOT Access decorator
    + S8205570: fix a number of typos in the JVMTI spec
    + S8205577: parallel/TestPrintGCDetailsVerbose.java fails
    assertion
    + S8205583: Crash in ConcurrentHashTable
    do_bulk_delete_locked_for
    + S8205605: [testbug][aix] Various test adaption to aix
    pecularities.
    + S8205607: Use oop_iterate instead of oop_iterate_no_header
    + S8205609: [PPC64] Fix PPC64 part of 8010319 and TLH without
    UseSIGTRAP on AIX
    + S8205612: (fc) Files.readAllBytes fails with
    ClosedByInterruptException when interrupt status set
    + S8205614: NestMates tests failing in CI jdk11-jdk.931
    + S8205616: Build fails with system headers after 8204572
    + S8205623: Replace use of Class::getPackage with
    Class::getPackageName
    + S8205625: linux-aarch64-cmp-baseline fails builds-tier5
    + S8205627: Replace hardcoded spec version value in
    build.tools.ExtLink taglet
    + S8205632: Include stack.inline.hpp in markSweep.inline.hpp
    + S8205641: Make java/nio/channels/Selector/RacyDeregister.java
    noisier and flush after prints
    + S8205648: fix for 8205195 breaks secondary error handling
    + S8205649: Make clang stack flags independent of OS
    + S8205663: ZGC: Log metaspace used/capacity/committed/reserved
    + S8205664: Move detailed metaspace logging from debug to trace
    + S8205671: Remove HTTP Client tests erroneously problem listed
    by the TLS 1.3 integration
    + S8205673: Problem list RmiRegistrySslTest.java and
    RmiSslBootstrapTest.sh
    + S8205676: ZGC: Remove TLAB allocations in relocation path
    + S8205678: ZGC: Remove unused ZAllocationFlags::java_thread()
    + S8205679: Remove unused
    ThreadLocalAllocBuffer::undo_allocate()
    + S8205681: [TEST_BUG] vmTestbase/nsk/jvmti/Allocate/alloc001/
    /TestDescription.java fails with exit code 98
    + S8205683: Refactor heap allocation to separate concerns
    + S8205694: AArch64: Add test to validate volatile load, store
    and CAS code generation
    + S8205696: Undo licence.md
    + S8205699: assert(_owner_offset != 0) failed in javaClasses.cpp
    + S8205701: Problem list serviceability/jvmti/HeapMonitor/
    /MyPackage/HeapMonitorGCCMSTest.java
    + S8205702: assert(UseCompressedClassPointers) failed in
    universe.hpp
    + S8205703: [JVMCI] Expose all GC selection flags
    + S8205719: Windows
    Java_sun_tools_attach_VirtualMachineImpl_enqueue() method
    should include exitCode in exception message
    + S8205721: Problem list serviceability/jvmti/HeapMonitor/
    /MyPackage/HeapMonitorStatArrayCorrectnessTest.java
    + S8205723: Problem list serviceability/jvmti/HeapMonitor/
    /MyPackage/HeapMonitorStatRateTest.java
    + S8205824: Update Graal
    + S8205906: jdk.jfr.jcmd.TestJcmdDumpLimited fails due to
    erronous processing of -XX:FlightRecorderOptions
    + S8205913: Inconsistent source code model
    + S8205916: [test] Fix jdk/tools/launcher/RunpathTest to handle
    both, RPATH and RUNPATH
    + S8205923: ZGC: Verification applies load barrier before
    verification
    + S8205923: ZGC: Verification applies load barriers before
    verification
    + S8205925: Print correct and more information about secondary
    errors
    + S8205926: Support invokeSpecialIFC in GenerateJLIClassesPlugin
    + S8205927: Update src/java.base/share/legal/public_suffix.md
    to match the actual file version
    + S8205940: LoadNode::find_previous_arraycopy fails with
    "broken allocation" assert
    + S8205942: Build failure on macosx after JDK-8189429
    + S8205945: Revert unintended changes to
    make/gensrc/Gensrc-jdk.hotspot.agent.gmk
    + S8205954: clean up hotspot ProblemList
    + S8205956: Fix usage of "OpenJDK" in build and test
    instructions
    + S8205959: Do not restart close if errno is EINTR
    + S8205985: Remove tools/javac/options/release/
    /ReleaseOptionUnsupported.java from problem list
    + S8205993: ZGC: Fix typos and incorrect indentations
    + S8205996: JDK-8205906 broke the build on Mac
    + S8206004: [BACKOUT] errant changeset for JDK-8137164
    + S8206006: Build failed on Windows
    + S8206088: 8205207 broke builds
- Removed patch:
  * generated-headers.patch
    + Integrated upstream
- Modified patch:
  * alternative-tzdb_dat.patch
    + Modify to upstream changes in the context
* Fri Jun 22 2018 fstrba@suse.com
- Added patch:
  * missing-return.patch
    + fix no-return-in-nonvoid-function
* Thu Jun 21 2018 fstrba@suse.com
- Update to upstream tag jdk-11+19
  * Fixes:
    + S6545967: sp05t003 failed ResumeThread() due to
    THREAD_NOT_SUSPENDED
    + S6608234: SwingWorker.get throws CancellationException
    + S7183985: (ann) Class.getAnnotation() throws an
    ArrayStoreException when the annotation class not present
    + S8029250: [macosx] There is no tray icon shown in the system
    tray area when case starts
    + S8042131: DateTimeFormatterBuilder Mapped-values do not work
    for JapaneseDate
    + S8043575: Dynamically parallelize reference processing work
    + S8149565: -locale option issues
    + S8153107: enabling ObjectSynchronizer::quick_enter() on ARM64
    causes hangs
    + S8170159: Improve the performance of BitSet traversal
    + S8177334: Update xmldsig implementation to Apache Santuario
    2.1.1
    + S8178150: Regression in logic for handling inference stuck
    constraints
    + S8184349: There should be some verification that EnableJVMCI
    is disabled if a GC not supporting JVMCI is selected
    + S8191512: T2K font rasterizer code removal
    + S8193302: Javac AssertionError: typeSig ERROR on usage of
    @Generated
    + S8194308: jdeprscan will need updates to deal with the
    removal of the Java EE modules
    + S8195115: G1 Old Gen MemoryPool CollectionUsage.used values
    don't reflect mixed GC results
    + S8195293: Issue more comprehensive warnings for use of
    \"var\" in earlier source versions
    + S8196618: Create API to list supported values for javac
  - -release option
    + S8196988: Resolve disabled warnings for libjimage
    + S8198669: Refactor annotation array value parsing to reduce
    duplication
    + S8198719: MethodHandleHelper.linkToStatic should drop MH arg
    + S8199433: (se) select(Consumer<SelectionKey> action) as
    alternative to selected-key set
    + S8199435: Unsafe publication of java.util.Properties.map
    + S8199441: Wrong caret position in multiline text components
    on Windows with a screen resolution higher than 100%%
    + S8199871: Deprecate pack200 and unpack200 tools
    + S8200115: System property java.vm.vendor value includes
    quotation marks
    + S8200121: Remove unused qualified exports in java.base
    + S8200353: Shift or Capslock not working in Textfield after
    accented keystrokes
    + S8200605: Create test for GridBagLayoutDemo
    + S8200867: Remove references to "jdk 9" in build system
    + S8201276: (fs) Add methods to Files for reading/writing a
    string from/to a file
    + S8202199: Provide public, unsupported JDK API for
    JavaFX/Swing interop
    + S8202216: Add Buffer mismatch methods
    + S8202537: CLDR33
    + S8202559: Tests which start VM using JNI start failing after
    compile upgrade to VC 2017
    + S8202605: Standardize on ClassLoaderData::loader_name()
    throughout the VM to obtain a class loader's name
    + S8202624: javadoc generates references to enum constructors,
    which are not documented
    + S8202740: runtime/8176717/TestInheritFD.java fails with
    java.lang.RuntimeException: could not match:
    VM RESULT => RETAINS FD
    + S8202768: [macos] Appkit thread slows when any Window Manager
    active
    + S8202845: Refactor reference processing for improved
    parallelism
    + S8202948: C2: assert(init_offset >= 0) failed: positive
    offset from object start
    + S8203030: Zero s390 31 bit size_t type conflicts in shared
    code
    + S8203157: Object equals abstraction for BarrierSetAssembler
    + S8203197: C2: consider all paths in loop body for loop
    predication
    + S8203301: Linux-sparc fails to build after JDK-8199712
    (Flight Recorder)
    + S8203338: Unboxing in return from lambda miscompiled to throw
    ClassCastException
    + S8203343: VM.{metaspace|classloaders|classhierarchy...} jcmd
    should show invocation targets for
    Generated{Method|Constructor}AccessorImpl classes
    + S8203344: Make C1 leal patchable on SPARC
    + S8203357: Container Metrics
    + S8203394: Implementation of JEP 331: Low-Overhead Heap
    Profiling
    + S8203479: JFR enabled ARM32 build assertion failure
    + S8203491: [TESTBUG] Port heapdump tests into java
    + S8203641: Refactor String Deduplication into shared
    + S8203667: Platform specific include files in jdk image in
    wrong sub directory
    + S8203680: os::stat() on Posix platform does not need to copy
    input path
    + S8203691: Test /runtime/containers/cgroup/PlainRead.java fails
    + S8203809: [Graal] JDI tests fail with:
    JDITestRuntimeException : ** event IS NOT a breakpoint **
    + S8203813: javac accepts an illegal name as a receiver
    parameter name
    + S8203838: javac performance regression in 11+11
    + S8203915: Induction variable of over-unrolled loop conflicts
    with range checks
    + S8204152: SignedObject throws NullPointerException for null
    keys with an initialized Signature object
    + S8204166: TLH: Semaphore may not be destroy until signal have
    returned.
    + S8204169: Humongous continues region remembered set states do
    not match the one from the corresponding humongous start
    region
    + S8204172: Predicate::not should explicitly mention
    "NullPointerException - if target is null"
    + S8204231: Update Graal
    + S8204236: JFR unit test of thread CPU load should be enabled
    + S8204240: Extend MDO to allow more reasons to be recorded per
    bci
    + S8204268: Improve some IncompatibleClassChangeError messages.
    + S8204330: Javadoc IllegalArgumentException: HTML special
    chars in constant value
    + S8204342: methods in java.time s TCKZoneRules OpenJDK test
    miss Test annotation
    + S8204353: AARCH64: optimize FPU load and stores in
    macroAssembler
    + S8204454: Remove of sun.applet.AppletAudioClip
    + S8204473: AARCH64: register post-index addressing mode is not
    supported directly
    + S8204509: Fix compilation error in harfbuzz 1.7.6 for Solaris
    Developer Studio 12.6
    + S8204531: Remove unused chars following '\0'
    + S8204538: Split ScanClosure and ScanClosureWithParBarrier
    + S8204571: Add support for launching multiple startup
    recordings
    + S8204613: StringTable: Calculates wrong number of uncleaned
    items.
    + S8204620: ModuleEntry::is_non_jdk_module() determination for
    what is a jdk module is incorrect
    + S8204654: [testbug] Fix pattern matching in jstat tests.
    + S8204663: clean up remaining native parts after JDK-8187631
    + S8204664: PrepareFailureLogs should be done after sequential
    make targets
    + S8204666: javadoc should be updated to use jQuery 3.3.1
    + S8204668: Cleanup management of the java.vm.info System
    property
    + S8204679: HTTP Client refresh
    + S8204685: Abstraction for TLAB dummy object
    + S8204701: [TESTBUG] runtime/SharedArchiveFile/
    /BootAppendTests.java should handle mapping failure
    + S8204857: ConcurrentHashTable: Fix parallel processing
    + S8204859: [macosx] Remove javax/swing/plaf/nimbus/8057791/
    /bug8057791.java from the ProblemList.txt
    + S8204915: (fs) Add some print diagnostics to
    java/nio/file/Files/CopyAndMove.java
    + S8204922: Create bootcycle jib profiles
    + S8204923: Restore Symantec root verisignclass2g2ca
    + S8204927: ZGC: assert(phase->idom(head) ==
    head->in(LoopNode::EntryControl)) failed
    + S8204929: Fonts with embedded bitmaps are not always rotated
    + S8204935: [aix] TOC overflow in libjvm.so (release build)
    + S8204939: Change Access nomenclature: root to native
    + S8204941: Refactor TemplateTable::_new to use MacroAssembler
    helpers for tlab and eden
    + S8204943: Improve message of ArrayStoreException.
    + S8204944: Remove java/util/Map/InPlaceOpsCollisions.java from
    ProblemList
    + S8204957: Remove TestBiasedLockRevocationEvents from
    ProblemList.txt
    + S8204958: Minor cleanups for the diagnostic framework
    + S8204961: JVMTI jtreg tests build warnings on 32-bit platforms
    + S8204965: Fix '--disable-cds' and disable CDS on AIX by
    default
    + S8204973: Add build support for filtering translations
    + S8204978: [Graal] Disable Epsilon GC tests from running with
    Graal
    + S8205003: Replace selected link tags with linkplain in
    java.lang.Class
    + S8205006: Assertion failure when rehashing stringtable
    + S8205020: ZGC: Apply workaround for buggy sem_post() in glibc
    < 2.21
    + S8205022: ZGC: SoftReferences not always cleared before
    throwing OOME
    + S8205024: ZGC: Worker threads boost mode not always enabled
    when is should be
    + S8205025: [AOT] make jdk.aot module upgradeable
    + S8205028: ZGC: Remove incorrect comment in
    ZHeap::object_iterate()
    + S8205033: [REDO] Induction variable of over-unrolled loop
    conflicts with range checks
    + S8205034: [BACKOUT] Induction variable of over-unrolled loop
    conflicts with range checks
    + S8205043: Make parallel reference processing default for G1
    + S8205050: ZGC: Incorrect use of RootAccess in ZHeapIterator
    + S8205052: No compilation error thrown when no valid
    parameterization exists for functional interface type
    + S8205054: Could not find "lsof" on test machine
    + S8205055: Fix compilation optimization errors with new
    Solaris toolchain
    + S8205062: (fs) Improve some print diagnostics in
    java/nio/file/Files/CopyAndMove.java
    + S8205064: Fail immediately if an unavailable GC is selected
    + S8205074: [Graal] Add rest of compiler/stable tests into
    ProblemList-graal.txt
    + S8205091: AIX: build errors in hotspot after 8203641:
    Refactor String Deduplication into shared
    + S8205096: Add missing files for 8203394
    + S8205108: [testbug] Fix pattern matching in jstatd tests.
    + S8205110: Fix xchip warnings with new Solaris toolchain
    + S8205112: Remove non-existent modules from
    test/jdk/jdk/modules/etc/UpgradeableModules.java
    + S8205116: jdeps --system $java.home fails with IAE
    + S8205141: runtime/exceptionMsgs/ArrayStoreException/
    /ArrayStoreExceptionTest.java failed with
    "assert(k->is_objArray_klass()) failed: cast to ObjArrayKlass
    + S8205148: Turn off logging in jQuery-migrate
    + S8205149: hs201t002 should be put on the problem list
    + S8205163: ZGC: Keeps finalizable marked PhantomReference
    referents strongly alive
    + S8205172: 32 bit build broken
    + S8205181: ProblemList
    applications/ctw/modules/java_desktop_2.java
    + S8205183: Warning about using VS2017 should be removed
    + S8205338: ZGC: LeakProfiler not yet supported
    + S8205339: ZGC: VerifyBeforeIteration not yet supported
    + S8205341: AARCH64: Clean up duplicate uzp1 & uzp2 instruction
    definition
    + S8205344: TraceMemoryManagerStats changes in JDK-8195115
    broke ZGC
    + S8205407: [windows, vs<2017] C4800 after 8203197
- Modified patches:
  * generated-headers.patch
    + Better version resulting from discussion with upstream
  * java11-improved-fonts.patch
    + Rediff to changed context
* Thu Jun 14 2018 fstrba@suse.com
- Update to upstream tag jdk-11+18
  * Fixes:
    + S6350055: (se) SelectionKey.interestOps variants to
    atomically update interest ops
    + S8174734: Safepoint sync time did not increase
    + S8178374: Problematic ByteBuffer handling in
    CipherSpi.bufferCrypt method
    + S8190326: Robot.mouseMove uses scaling factor of main display
    on unscaled second display
    + S8194073: Invalid SunNativeProvider.INSTANCE initialization
    + S8195097: Make it possible to process StringTable outside
    safepoint
    + S8196030: AWT Robot mouseMove fails on Windows 10 1709 with
    HiDPI
    + S8196141: Add GoDaddy root certificates
    + S8196990: Resolve disabled warnings for libjli
    + S8196993: Resolve disabled warnings for libunpack
    + S8197930: JNI exception pending in initializeEncoding of
    jni_util.c
    + S8200132: Remove jre images and bundles
    + S8200387: [Graal] fromTonga/nsk/jdi tests hang with Graal as
    JIT
    + S8201193: Use XMM/YMM for objects initialization
    + S8201274: Launch Single-File Source-Code Programs
    + S8201407: Files.move throws DirectoryNonEmptyException when
    moving directory across file system
    + S8201528: Add new test to check for package versioning
    information in OpenJDK
    + S8201608: fix broken links in javax/sql/rowset/package.html
    and javax/sql/rowset/spi/package.html
    + S8202049: G1: ReferenceProcessor doesn't handle mark stack
    overflow
    + S8202088: Japanese new era implementation
    + S8202611: [GRAAL] Exclude CMS GC testing from runs with Graal
    + S8202705: ARM32 build crashes on long JavaThread offsets
    + S8202747: C2: assert(mode == ControlAroundStripMined && use
    == sfpt) failed: missed a node
    + S8202772: NMT thread stack tracking causes crashes on AIX
    + S8202864: [TESTBUG] Need to replace the image used in two
    Swing tests
    + S8203033: [Testbug] vmTestbase/nsk/jdi/TypeComponent/
    /isSynthetic/issynthetic002/TestDescription.java fails with
    nestmates
    + S8203172: Primitive heap access for interpreter
    BarrierSetAssembler/aarch64
    + S8203224: java.awt.desktop.*Event classes could not be
    instantiated if Desktop feature is not supported
    + S8203308: Remove the appletviewer classes
    + S8203329: JDWP/JDI VM information string is incorrect
    + S8203353: Fixup inferred decorators in the interpreter
    + S8203367: Upgrade to freetype 2.9.1
    + S8203425: assert(is_Loop()) failed: invalid node class
    + S8203480: IncompatibleClassChangeError thrown at sites linked
    to default interface methods
    + S8203499: Uninitialised memory in WinAccessBridge.cpp
    + S8203679: AssertionError in DeferredAttr with parenthesized
    method reference
    + S8203682: Add jcmd "VM.classloaders" command to print out
    class loader hierarchy, details
    + S8203796: Define API to support specifying ownership of print
    dialogs
    + S8203822: AIX version of jsig.c was not removed in JDK-8200298
    + S8203839: API clarification: versioned jar entry verification
    in multi-release jar file
    + S8204081: Mismatch in rebuild policy and collection set
    chooser causes remembered sets to be kept errorneously
    + S8204084: Remove the G1RSBarrierRegionFilter develop flag
    + S8204097: Simplify OopStorage::AllocateList block entry access
    + S8204110: serviceability/sa/ClhsdbSymbol.java and
    ClhsdbInspect.java failed when running in CDS mode
    + S8204113: Upgrade linker used in AOT tests to be same version
    as build toolchain
    + S8204118: [macos] Nonsensical self == [super init] in
    CFileDialog.m
    + S8204126: MonospacedGlyphWidthTest.java failed again
    + S8204127: Change bundle format on Windows to zip
    + S8204180: Implementation: JEP 318: Epsilon, A No-Op Garbage
    Collector
    + S8204187: Remove proprietary JPEG code from javax.imageio
    + S8204210: Implementation: JEP 333: ZGC: A Scalable
    Low-Latency Garbage Collector (Experimental)
    + S8204211: windows : handle potential C++ exception in
    GDIRenderer
    + S8204229: Formatter and String.format ignore the width with
    the percent modifier (%%5%%)
    + S8204243: remove Thread.destroy() and Thread.stop(Throwable)
    + S8204287: Phase timings not updated correctly after
    JDK-6672778
    + S8204288: Matching the end of a string followed by an empty
    greedy regex and a word boundary fails
    + S8204290: Add check to limit number of capture groups
    + S8204303: Add redirect for overview-summary.html
    + S8204335: [ppc] Assembler::add_const_optimized incorrect for
    some inputs
    + S8204375: Add TimeUnit#convert(Duration)
    + S8204377: Rename Object#wait parameter name from "timeout" to
    "timeoutMillis"
    + S8204444: java.time cleanup
    + S8204474: Have instanceRefKlass use HeapAccess when loading
    the referent
    + S8204476: Add additional statistics to
    CodeCache::print_summary
    + S8204477: Count linkage errors and print in
    Exceptions::print_exception_counts_on_error
    + S8204479: Bitwise AND on byte value sometimes produces wrong
    result
    + S8204494: Fix for 8200530 triggered regression,
    closed/test/jdk/security/infra/java/security/KeyStore/
    /BouncyCastleInterop.java failed
    + S8204496: backout fix for 8203796 which was pushed under
    another ID
    + S8204504: Fix for 8198285 breaks slowdebug builds
    + S8204539: improve error messages in matchJavaTZ [windows]
    + S8204549: [aix][testbug] signal tests fail because vm can not
    start in primordial thread.
    + S8204554: JFR TLAB tracing broken after 8202776
    + S8204557: NMT: Linux os::committed_in_range() does not break
    out outer loop when contiguous region is found
    + S8204561: JVM_GetClassSigners: wrap signers oop in an
    objArrayHandle for subsequent safepoint
    + S8204563: UseAppCDS obsolete message confusing
    + S8204565: (spec) Document java.{vm.}?specification.version
    system properties' relation to $FEATURE
    + S8204572: SetupJdkLibrary should setup SRC and -I flags
    automatically
    + S8204576: (fs) java/nio/file/Files/CopyAndMove.java does not
    set isUnix = true on macOS
    + S8204577: jittester generator doesn't kill processes on
    timeout
    + S8204584: jdeps generates illegal dot file containing
    ranksep=0,600000
    + S8204585: Remove IN_ARCHIVE_ROOT from Access API
    + S8204588: Test failures after "Launch Single-File Source-Code
    Programs"
    + S8204589: ProblemList failing launcher tests
    + S8204598: add more thread-related system settings info to
    hs_error file on Linux
    + S8204602: Add devkit for linux-arm32
    + S8204606: [Aarch64] SIGSEGVs caused by C1 because of improper
    register usage
    + S8204610: Compiler confused by parenthesized "this" in final
    fields assignments
    + S8204617: ParallelGC parallel reference processing does not
    set MT degree in reference processor
    + S8204618: The parallel GC reference processing task executor
    enqueues a wrong number of tasks into the queue
    + S8204628: [AArch64] Assertion failure in
    BarrierSetAssembler::load_at
    + S8204648: test/jdk/tools/launchers/SourceMode.java fails with
    long shebang line
    + S8204652: [aix] fix thread stack allocation, too big stack
    sizes not recognized
    + S8204674: Inconsistent lambda parameter span
    + S8204680: Disassembly does not display code strings in stubs
    + S8204682: Parsing for LOG=report=none is broken when combined
    with other keywords
    + S8204684: [AIX] Build of libjli_static broken after change
    8204572 (SetupJdkLibrary)
    + S8204694: Add failed compiler/stable tests into
    ProblemList-graal.txt
    + S8204850: BarrierSet::make_* should be static
    + S8204861: fix for 8196993 has broken the build on linux
- Modified patch:
  * system-pcsclite.patch
    + rediff to changed context
- Added patch:
  * generated-headers.patch
    + fix a regression after JDK-8204572
* Thu Jun  7 2018 fstrba@suse.com
- Update tu upstream tag jdk-11+17
  * Fixes:
    + S5109146: PNGMetadata Background color initialization from
    standard metadata is incomplete
    + S8050818: Predicate::not - provide an easier way to negate a
    predicate
    + S8072996: Deprecate stream-based GSSContext methods
    + S8150156: Update bugs.sun.com references to bugs.java.com
    + S8153029: ChaCha20 Cipher Implementation
    + S8154736: enhancement of cmpxchg and copy_to_survivor for
    ppc64
    + S8177276: MethodHandles.insertArguments doesn't specify
    IllegalArgumentException on index mismatch
    + S8187289: NotifyFramePop request is not cleared if
    JVMTI_EVENT_FRAME_POP is disabled
    + S8189335: javac exception when referencing private inner
    class with same name as normal class with dollar_1
    + S8189949: Remove Baltimore Cybertrust Code Signing CA
    + S8190417: javadoc updates to java.util.regex.Matcher
    + S8190875: modules not listed in overview/index page
    + S8191031: Remove several Symantec Root CAs
    + S8191522: Remove Bigelow&Holmes Lucida fonts from JDK sources
    + S8193552: ISO 4217 amendment 165
    + S8194327: [macos] AWT windows have incorrect main/key window
    behaviors
    + S8195624: Desktop API cannot be used without permission to
    read "os.version"
    + S8196373: Introspector does not see overridden generic setter
    method
    + S8197387: jcmd started by "root" must be allowed to access
    all VM processes
    + S8197989: java/util/zip/ZipFile/TestCleaner.java failed with
    "cleaner failed to clean zipfile
    + S8198285: More consistent Access API for arraycopy
    + S8198378: javac crash when checking imports and a broken
    class is present
    + S8199150: Accessibility issues in java.desktop
    + S8199268:
    docs/api/jdk.javadoc/com/sun/javadoc/package-summary.html
    contain low contrast text
    + S8199371: [TESTBUG] Open source vm testbase JDWP tests
    + S8199380: [TESTBUG] Open source VM testbase AOD tests
    + S8199388: Test development for ChaCha20 and Poly1305
    algorithms
    + S8199530: Upgrade to harfbuzz 1.7.6
    + S8199723: Test java/awt/TextComponent/
    /DeselectionDuringDoSelectionNonVisibleTest/
    /DeselectionDuringDoSelectionNonVisibleTest.java fails
    + S8199882: compiler/uncommontrap/TestDeoptOOM.java failed w/
    fatal error: ExceptionMark constructor expects no pending
    exceptions
    + S8199893: the javadoc tool generates pages with a low
    constrast
    + S8200052: libjavajpeg: Fix compile warning in jchuff.c
    + S8200166: Repeating annotations refering to to-be-generated
    classes don't work.
    + S8200288: [SPARC] "assert(!(is_cti(prev) && is_cti(insn)))
    failed: CTI-CTI not allowed"
    + S8200530: '\r' is not supported as "newline" in
    java.util.jar.Manifest
    + S8200623: Primitive heap access for interpreter
    BarrierSetAssembler/x86
    + S8201279: javax.sound tests should not set java.home system
    property
    + S8201364: [macosx] Component.getLocation() gives inconsistent
    coordinate for a component at (0,0)
    + S8201429: Support AIX Input Method Editor (IME) for AWT Input
    Method Framework (IMF)
    + S8202026: ISO 4217 amendment 166
    + S8202051: Address compilation warnings in libawt with VS2017
    + S8202094: jdk/jfr/api/recording/event/TestEventTime.java
    intermittently times out
    + S8202095: JFR TestBiasedLockRevocationEvents should cope with
    multiple events during a single safepoint
    + S8202360: [TESTBUG] runtime/LoadClass/TestResize.java needs
    to print output when it fails
    + S8202547: Move G1 runtime calls used by generated code to
    G1BarrierSetRuntime
    + S8202627: javadoc generates broken links to deprecated items
    when -nodeprecated is used
    + S8202670: Update Graal
    + S8202758: SIGSEGV calling
    Class.forName(String,Boolean,ClassLoader) with mocked loader
    + S8202776: Modularize GC allocations in runtime
    + S8202812: [TESTBUG] Open source VM testbase compiler tests
    + S8202913: loader constraint message for fields specifies
    incorrect referring class
    + S8203027: Open source tests for "java.awt.geom"
    + S8203031: segfaults from jvmti_AddToBootstrapClassLoaderSearch
    + S8203182: Release session if initialization of SunPKCS11
    Signature fails
    + S8203219: VM.metaspace jcmd should optionally show loaded
    classes for loaders
    + S8203237: JFR TestBiasedLockRevocationEvents should ignore
    events unrelated to the test
    + S8203319: JDK-8201487 disabled too much queue balancing
    + S8203321: assert(current_query_index <
    process_query_set->size) failed: invariant
    + S8203324: Use out of scope in getMacOSXLocale of
    java_props_macosx.c:120
    + S8203380: Missing platform and bug information for
    MouseModifiersInKeyEvent test
    + S8203435: Circular nested dynamic constant test needed to
    confirm JVMS resolution behavior
    + S8203445: [TESTBUG] Remove
    appcds/jigsaw/limitmods/LimitModsTests.java
    + S8203474: Update description of "Cyrillic Supplementary"
    block name in Character.UnicodeBlock class.
    + S8203485: [freetype] text rotated on 180 degrees is too narrow
    + S8203498: The specification for java.applet package should be
    updated
    + S8203669: PPC64: Fix jtreg RTM tests after "8203305: Improve
    TM detection for enabling RTM on Linux / POWER9"
    + S8203765: java/nio/channels/Selector/SelectAndClose: add some
    prints and @intermittent tag
    + S8203780: javadoc should be updated to use jquery 1.12.4,
    jquery-ui 1.12.1 and jszip v3.1.5
    + S8203787: Hotspot build broken on linux-sparc after 8202377
    + S8203802: Jvmti test fails to build with VS2017
    + S8203827: Upgrade JLine to 2.14.6
    + S8203837: Split nmethod unloading from inline cache cleaning
    + S8203872: Upgrading JDK with latest available LSR data from
    IANA.
    + S8203891: Upgrade JOpt Simple to 5.0.4
    + S8203919: Remove "-add-modules" hint from error message
    + S8203921: JFR thread sampling is missing fixes from
    JDK-8194552
    + S8203923: Add @requires feature to check flag values for the
    running JVM
    + S8203924: Zero: bootcycle-images build fails on x86_64
    + S8203937: Not possible to read data from socket after write
    detects connection reset
    + S8203939: JVMFlag::printError missing ATTRIBUTE_PRINTF
    + S8203945: Cleanup nashorn build
    + S8203946: Move UnpackSecurity.gmk to closed
    + S8203948: Expand JVMTI callback notion of "internal threads"
    + S8203960: [TESTBUG] runtime/logging/DefaultMethodsTest.java
    failed when running in CDS mode
    + S8204055: SIGSEGV in java -XX:
    + S8204085: avoid printing uninitialized pointer in
    java.desktop/windows/native/libawt/java2d/windows/
    /GDIWindowSurfaceData.cpp
    + S8204087: C++ Interpreter code left over in MethodData
    + S8204091: Configure broken on MIPS when uname returns mipsel
    or mips64el
    + S8204094: assert(worker_i < _length) failed: Worker 15 is
    greater than max: 11 at ReferenceProcessorPhaseTimes
    + S8204095: [TESTBUG] TestPrintReferences.java fails if
    multiple concurrent mark happens
    + S8204103: Mark test
    serviceability/dcmd/compiler/CompilerQueueTest.java as
    intermittent and exclude it from tier1
    + S8204109: JDK-8203945 broke nashorn
    + S8204122: Update harfbuzz.md
    + S8204134: jtreg: Fix RTM abort provoker for various tests
    after "8149159: Clean up Unsafe"
    + S8204136: jtreg: Fix failing RTM test RTMSpinLoopCount
    + S8204160: BiasedLockingTest needs -XX:+UseBiasedLocking
    + S8204162: TestG1HeapRegion needs @requires vm.gc.G1
    + S8204163: Also detect concurrent GCs in MetaspaceBaseGC.java
    + S8204164: OOM-only logging in Metaspace
    + S8204165: Filter out tests requiring class unloading when
    ClassUnloading is disabled
    + S8204167: Filter out tests requiring compressed oops when
    CompressedOops is disabled
    + S8204168: Increase small heap sizes in tests to accommodate
    ZGC
    + S8204173: Lower the minimum number of heap memory pools in
    MemoryTest.java
    + S8204179: [BACKOUT] OopStorage should use GlobalCounter
    + S8204194: Lazily create
    MethodHandleImpl$AsVarargsCollector.asCollectorCache
    + S8204195: Clean up macroAssembler.inline.hpp and other
    inline.hpp files included in .hpp files
    + S8204199: Test fails after 8202670 Graal update
    + S8204237: Clean up incorrectly included .inline.hpp files
    from jvmciJavaClasses.hpp
    + S8204250: Problem list pkcs11 tests on windows
    + S8204269: ISO 4217 amendment 167
    + S8204277: [testbug] fix DisassembleCodeBlobTest.
    + S8204292: PPC64: Fix missing includes after 8204195
    + S8204295: [BACKOUT] - JVMFlag::printError missing
    ATTRIBUTE_PRINTF
    + S8204301: Make OrderAccess functions available to hpp rather
    than inline.hpp files
    + S8204321: javadoc tests fail after JDK-8203780
    + S8204322: "+=" applied to String operands can provoke side
    effects
    + S8204341: AArch64: AOT runtime does not need a workaround for
    far calls
    + S8204345: [s390]: no precompiled headers build broken
    + S8204348: AArch64: Remove C2 address reshaping code
* Tue Jun  5 2018 fstrba@suse.com
- Change the alternatives priority from 0 to 2105, since OpenJDK 11
  should now be in a shape to be able to be used.
* Tue Jun  5 2018 fstrba@suse.com
- Change build requirement to Java 10 or 11, since Java 9 cannot
  build OpenJDK 11 any more.
* Thu May 31 2018 fstrba@suse.com
- Update to upstream tag jdk-11+16
  * Fixes:
    + S8133564: Runtime - 2nd followup to Validate JVM Command-Line
    Flag Arguments
    + S8184030: TestUseRTMLockingOptionOnUnsupportedVM - RTM
    locking optimization not supported is missing
    + S8188248: NullPointerException on generic methods
    + S8189766: whitebox failure with -Xcheck:jni
    + S8191844: Remove SECOM root (secomevrootca1)
    + S8193717: Import resolution performance regression in JDK 9
    + S8194298: Add support for per Socket configuration of TCP
    keepalive
    + S8194630: Uninitialized initiator_address in native GSS
    + S8196202: Javadoc should not generate frames by default
    + S8196913: javadoc does not (over)write stylesheet.css
    + S8198323: testing.md not updated for repository layout change
    + S8199255: [TESTBUG] Open source VM testbase default methods
    tests
    + S8199307: NPE in
    jdk.javadoc.internal.doclets.toolkit.util.Utils.getLineNumber
    + S8199383: [TESTBUG] Open source VM testbase JVMTI tests
    + S8200172: String.split non-positive term incorrect use
    + S8200266: [Graal] Update ProblemList-graal.txt files
    + S8201518: add test for randomized iteration order of
    unmodifiable Set and Map
    + S8202178: type.getKind() for var is None instead of Error
    + S8202290: AtomicAppend tests fail on macOS 10.13 ("High
    Sierra")
    + S8202813: Move vm_weak processing from SystemDictionary to
    WeakProcessor
    + S8202832: cycle detection depends on ordering of requires
    directives
    + S8202842: G1 footprint regressions in jdk11+10
    + S8202945: OopStorage should use GlobalCounter
    + S8202947: Fix minor issues with taglets
    + S8202949: C2: assert(false) failed: Bad graph detected in
    build_loop_late
    + S8202950: C2: assert(found_sfpt) failed: no node in loop
    that's not input to safepoint
    + S8203014: jcmd should output command list if no command is
    given
    + S8203028: Simplify reference processing in light of
    JDK-8175797
    + S8203041: AArch64: fix overflow in immediate cmp/cmn
    instruction
    + S8203183:
    vmTestbase/vm/mlvm/anonloader/stress/oome/heap/Test.java times
    out
    + S8203221: Makefile fixes after Flight Recorder
    + S8203225: Fix of redefining a method that removes 1 or more
    lambda expressions failed to commit test cases
    + S8203233: (tz) Upgrade time-zone data to tzdata2018e
    + S8203262: Incorrect cmpxchg usage in
    MetaspaceGC::inc_capacity_until_GC
    + S8203297: java/net/URL/OpenStream.java fails intermittently
    + S8203327: Small cleanups in java.lang.ref
    + S8203328: Rename EFS in java.util.zip internals to something
    meaningful
    + S8203354: assert in
    ClassLoader::update_module_path_entry_list() could have
    incorrect message
    + S8203366: Tag added wrongly in Docs.gmk
    + S8203368: ObjectInputStream filterCheck method throws
    NullPointerException
    + S8203369: Check for both EAGAIN and EWOULDBLOCK error codes
    + S8203370: [JVMCI] UseJVMCICompiler should imply EnableJVMCI
    + S8203455: jcmd: VM.metaspace: print loader name for anonymous
    CLDs
    + S8203488: Remove error generation from TransTypes
    + S8203497: Bump Jib format version to 1.2
    + S8203628: Optimize (masked) byte memory comparisons on x86
    + S8203686: Add JDK 11 major version to
    javax/net/ssl/compatibility/JdkRelease.java
    + S8203689: Add failure code to threaddb exception messages`
    + S8203699: java/lang/invoke/SpecialInterfaceCall fails with
    SIGILL on aarch64
    + S8203766: Add some instrumentation to
    jdk/java/nio/channels/Selector/RacyDeregister.java
    + S8203769: ProblemList
    test/jdk/java/util/Map/InPlaceOpsCollisions.java
    + S8203774: jdk/jfr/api/recorder/TestStartStopRecording.java
    failed due to compilation failed
    + S8203793: cacerts/VerifyCACerts.java fails with
    java.lang.Exception: At least one cacert test failed
    + S8203795: Change default compiler on Windows to VS2017
    + S8203815: add tests failed because of 8203809 to the
    ProblemList-graal
    + S8203816: add tests failed because of 8203174 to the
    ProblemList-graal
    + S8203817: Monitor::try_lock() should not call
    check_prelock_state()
    + S8203843: BasicParState::default_estimated_thread_count(false)
    can return 0 in gtest
    + S8203865: Metaspace cleanup: Remove unused MemRegion in
    VirtualSpaceNode
    + S8203881: Print erroneous size in NegativeArraySizeException
    + S8203885: ConcurrentLocksDump::dump_at_safepoint() should not
    allocate array in resource area
    + S8203886: Invoke LambdaMetafactory::altMetafactory exactly
    from the BootstrapMethodInvoker
    + S8203892: Target interface added as marker interface in calls
    to altMetafactory
    + S8203926: Problem list
    test/langtools/tools/javac/importscope/T8193717.java
    + S8203932: Windows devkit has wrong dlls in 32 bit tools dir
    + S8203938: Fix build failures from JDK-8133564
* Fri May 25 2018 fstrba@suse.com
- Update to upstream tag jdk-11+15
  * Fixes:
    + S8027760: JFC schema condition should not have defaults
    + S8134537: Much nearly duplicated code for sun.misc.Signal
    support
    + S8146293: Add support for RSASSA-PSS Signature algorithm
    + S8148354: Errors targeting functional interface intersection
    types
    + S8176808: Split up metaspace.cpp
    + S8185803: JdbExprTest.sh fails in JDK10-hs nightly due to
    "Name unknown: java.lang.Long.MAX_VALUE "
    + S8192992: Test8007294.java failed: attempted to spill a
    non-spillable item
    + S8193332: MetaspaceShared::check_shared_class_loader_type is
    not used during archive creation
    + S8195098: Low latency hashtable for read-mostly scenarios
    + S8195817: JFR.stop should require name of recording
    + S8195818: JFR.start should increase autogenerated name by one
    + S8195819: Remove recording=x from jcmd JFR.check output
    + S8196048: thrown type variables should be roots in the
    minimum inference graph
    + S8196201: Generate pages to list all classes and all packages
    in javadoc output
    + S8196619: [TESTBUG] restore current version check in
    runtime/appcds/MultiReleaseJars.java
    + S8196987: Resolve disabled warnings for libzip
    + S8198315: Incomplete classpath causes NPE in TransTypes
    + S8198337: -XX:StartFlightRecording=dumponexit=true,disk=false
    doesn't work
    + S8198548: Initialization race in
    com.sun.org.apache.xerces.internal.impl.xpath.regex.Token.getRange()
    on Token.categories
    + S8199064: Test applications/jcstress/other/Test.java#id1108
    fails on Sparc
    + S8199257: [TESTBUG] Open source VM testbase metaspace tests
    + S8199271: [TESTBUG] open source VM testbase stress tests
    + S8199370: [TESTBUG] Open source vm testbase GC tests
    + S8199379: [TESTBUG] Open source vm testbase JDB tests
    + S8199384: [TESTBUG] Open source VM testbase MLVM tests
    + S8199807: AppCDS performs overly restrictive path matching
    check.
    + S8200380: String::lines
    + S8200436: String::isBlank
    + S8201331: Better test cleanup for
    jdk/jfr/api/consumer/TestRecordingFile.java
    + S8201386: Miscellaneous changes imported from jsr166 CVS
    2018-05
    + S8201627: Kerberos sequence number issues
    + S8201867: Kerberos keytabs with holes in certain places are
    parsed incorrectly
    + S8202014: Possible to receive signal before signal semaphore
    created
    + S8202076: test/jdk/java/io/File/WinSpecialFiles.java on
    windows with VS2017
    + S8202305: [Graal] org.graalvm.compiler.core.test.GraphResetDebugTest
    fails with java.util.ServiceConfigurationError
    + S8202377: Modularize C2 GC barriers
    + S8202427: Enhance os::print_memory_info on Windows
    + S8202466: Test serviceability/tmtools/jstat/GcTest01.java
    fails: Number of concurrent GC events is 1, but CGCT is 0
    + S8202479: Add missing try_resolve_jobject_in_native calls
    + S8202669: Intermittent crash in
    ClassLoadingService::compute_class_size()
    + S8202685: Optimize ArrayList subList replaceAll
    + S8202710: AARCH64: sporadic jtreg test fail
    + S8202713: Create a MacroAssembler::access_load/store_at
    wrapper for S390 and PPC
    + S8202771: Migrate Unicode character tests to JDK Repo
    + S8202848: -XX:+ExecuteInternalVMTests asserts with
    "assert(cd.valid() == true) failed: failed on a valid
    DirectivesParser string"
    + S8202853: NotifyCount is not initialized
    + S8202863: Rename OopStorage inner collection classes
    + S8202978: Incorrect tmp register passed to
    MacroAssembler::load_mirror()
    + S8202989: Add missing decorators in calls to to
    arraycopy_prologue/epilogue
    + S8203196: C1 emits incorrect code due to integer overflow in
    _tableswitch keys
    + S8203215: IdealLoopTree::split_outer_loop leaves phi-nodes
    with only one input
    + S8203227: Introduce os::processor_id() for Linux and Solaris
    + S8203279: Faster rounding up to nearest power of two
    + S8203287: Zero fails to build after JDK-8199712 (Flight
    Recorder)
    + S8203288: PPC64 and s390 fail to build after JDK-8199712
    (Flight Recorder)
    + S8203292: Print complete set of flags in the hs_err file
    + S8203305: PPC64: Improve TM detection for enabling RTM on
    Linux / POWER9
    + S8203318: compiler/stable/TestStableShort.java is broken
    + S8203339: Add oopDesc::field_offset()
    + S8203341: Add a safepoint-aware Semaphore
    + S8203346: JFR: Inconsistent signature of
    jfr_add_string_constant
    + S8203352: Improve java implementation of
    Integer/Long.numberOfLeadingZeros
    + S8203355: MITSHM define guarding missing
    + S8203377: Cleanup the usage of os::file_name_strcmp() in
    SharedPathsMiscInfo::check().
    + S8203381: Replace InstanceKlass::allocate_instance_handle
    with JavaCalls::construct_new_instance
    + S8203391: Update com/sun/jdi/JdbMethodExitTest.sh to pass
    valid URL[]
    + S8203398: Test test/langtools/tools/javac/options/release/
    /ReleaseOptionCurrent.java writes into the source directory
    + S8203400: Fix issue with "8199852: Print more information
    about class loaders in LinkageErrors."
    + S8203410: Zero: Disable jfr feature by default
    + S8203431: TestFloatsOnStackDeopt.java throws
    java.lang.LinkageError: loader <bootstrap> attempted duplicate
    class definition for
    java.lang.invoke.BoundMethodHandle$Species_LLL
    + S8203436: javac should fail early when emitting illegal
    signature attributes
    + S8203437: 8199370 broke build on linux-ppc64le (w/ GCC 4.8.5.)
    + S8203454: Minimal, Zero builds fail after JDK-8202377
    (Modularize C2 barriers)
    + S8203457: Add back missing full buffer notification
    + S8203486: skip type inference for non functional interface
    components of intersection types
    + S8203487: Typo in ICUBinary.java: s/Magin/Magic/
    + S8203490: StringTable::dump lacks a load barrier
    + S8203500: Fix broken links to Specification in "specs"
    directory
    + S8203626: ProblemList
    compiler/runtime/TestFloatsOnStackDeopt.java
    + S8203635: JFR sampler thread does not record stack info
    + S8203694: Add a safepoint-aware Semaphore - part 2
- Removed patch:
  * fix-s390x-and-ppc64-builds.patch
    + integrated upstream
* Tue May 22 2018 fstrba@suse.com
- Added patch:
  * fix-s390x-and-ppc64-builds.patch
    + upstream fix for broken s390x and ppc64/ppc64le builds
* Thu May 17 2018 fstrba@suse.com
- Update to upstream tag jdk-11+14
  * Fixes:
    + S8132287: obsolete the "InlineNotify" flag option
    + S8174995: SA: clhsdb 'where -a' throws Assertion Failure with
    illegal code 236 when CDS is used
    + S8176510: java/awt/font/GlyphVector/TestLayoutFlags.java
    fails with OpenJDK
    + S8183910: gc/arguments/TestAggressiveHeap.java fails
    intermittently
    + S8185505: AArch64: Port AOT to AArch64
    + S8189140: SystemDictionaryShared::initialize() should be
    renamed to be more meaningful
    + S8189271: Metaspace::_capacity_until_GC should be size_t
    + S8191533: jar --describe-module prints service provider class
    names in lower case
    + S8193935: Illegal countedLoops transformation
    + S8194998: broken error message for subclass of interface with
    private method
    + S8195613: [SA] HotSpotTypeDataBase.readVMLongConstants
    truncates values to int
    + S8196340: (coll) Examine overriding inherited methods in
    ArrayList and ArrayList.SubList
    + S8196360: java/awt/Dialog/SiblingChildOrder/
    /SiblingChildOrderTest.java fails
    + S8196616: java/awt/GraphicsDevice/DisplayModes/
    /CompareToXrandrTest.java fails
    + S8197948: Create test for SwingSet2 main window
    + S8198412: MonospacedGlyphWidthTest.java may fail on Solaris
    + S8198991: Move Java2D demo to the open repository
    + S8199252: [TESTBUG] Open source VM testbase system dictionary
    tests
    + S8199712: Flight Recorder
    + S8200377: String::strip, String::stripLeading,
    String::stripTrailing
    + S8201447: C1 does backedge profiling incorrectly
    + S8201491: G1 support for java.lang.ref.Reference precleaning
    + S8201532: Update idom to get correct dom depth calculation
    + S8201593: Print array length in
    ArrayIndexOutOfBoundsException.
    + S8201604: ARM64 - Build failure after JDK-8193260
    + S8202016: Use obj+offset in interpreter array access
    + S8202064: Jemmy JInternalFrameOperator: Add wait for close(),
    activate(), resize() and move() operations
    + S8202113: Reflection API is causing caller classes to leak
    + S8202289: Non-empty directory in module path is not handled
    properly at CDS/AppCDS dump time
    + S8202322: AIX: symbol visibility flags not support on xlc 12.1
    + S8202392: [TESTBUG] open source vm testbase heapdump tests
    + S8202395: AARCH64: wrong encoding for SIMD instructions zip,
    trn, uzp
    + S8202426: NPE thrown by Transformer when XMLStreamReader
    reports no xml attribute type
    + S8202476: ImageLib is broken in 32 bit Windows
    + S8202519: Crash during large AppCDS dump
    + S8202544: Hide unused exports in libzip
    + S8202553: Update FXLauncherTest as part of removing JavaFX
    from JDK
    + S8202557: OpenJDK fails to start in Windows 7 and 8.1 after
    upgrading compiler to VC 2017
    + S8202580: Dashed BasicStroke randomly painted incorrectly,
    may freeze application
    + S8202614: Add ability to validate links in JavadocTester
    + S8202679: Updates on windows failures in the problem list
    + S8202683: Minimal VM should build cleanly on 64-bit platforms
    + S8202708: Add a check of opening stream for not-existing UNC
    url
    + S8202714: Create a MacroAssembler::access_load/store_at
    wrapper for AArch64
    + S8202718: Jemmy JInternalFrameOperator: Dependency with
    orders of Minimize, Maximize and Close buttons
    + S8202738: vm_version Abstract_VM_Version::internal_vm_info_string()
    returns same string for different incremental builds
    + S8202745: Remove hyphens from "out-of-bounds".
    + S8202748: jtreg :hotspot_misc group shouldn't include
    vmTestbase tests
    + S8202756: move FilterUSRTest.java to openJDK
    + S8202763: failure_handler: list open files for macOS
    + S8202764: api/java_text/SimpleDateFormat/index.html#Format
    testcases started to fail with JDK11 b12
    + S8202767: java/awt/font/GlyphVector/TestLayoutFlags.java is
    missing null check
    + S8202773: Unhandled oop in JavaThread::collect_counters
    + S8202811: Problem List some tests that leave windows open on
    the desktop
    + S8202822: Add .git to .hgignore
    + S8202824: Cleanup discrepancies in ProblemList for java_awt
    jtreg tests
    + S8202829: Implement CollectedHeap::get_safepoint_workers()
    for G1
    + S8202843: langtools ant build fails
    + S8202878:
    com/apple/laf/ScreenMenu/ScreenMenuMemoryLeakTest.java fails
    + S8202889: Remove trailing LF from perf log
    + S8202914: Let custom makefile override jmod intput dir
    locations
    + S8202915: [JAXP] Performance enhancements and cleanups in
    com.sun.org.apache.xerces.internal.impl.dtd.XMLDTDValidator
    + S8202919: JDK-8202683 broke macosx build
    + S8202920: jvm.cfg generation incorrect
    + S8202974: Backout JDK-8202683
    + S8202976: Add C1 lea patching support for x86
    + S8202993: Add support for x86 testptr/testq with register and
    address
    + S8202994: Add support for undoing last TLAB allocation
    + S8202997: Split test/jdk/:tier1 to enable better parallel
    execution
    + S8203032: PrintMetaspaceDcmd fails: Non-Class: missing from
    stdout/stderr
    + S8203059: (so) Closing a socket channel registered with
    Selector and with SO_LINGER set to 0 does not reset connection
    + S8203176: javadoc handles non-ASCII characters incorrectly.
    + S8203220: Introduce ATTRIBUTE_ALIGNED macro
    + S8203223: Signed integer overflow in ImageStrings::hash_code
    (libjimage.so)
    + S8203250: runtime/LoadClass/test-classes/Hello.java has wrong
    legal notice
    + S8203251: Non-PCH build failed after JDK-8199712 (Flight
    Recorder)
    + S8203274: 32-bit build failures after JDK-8199712 (Flight
    Recorder)
    + S8203278: AArch64/PPC64 build failures after JDK-8199712
    (Flight Recorder)
    + S8203285: Minimal VM fails to build after JDK-8199712 (Flight
    Recorder)
* Mon May 14 2018 fstrba@suse.com
- s390x: avoid packaging files that are not present on this
  architecture
* Fri May 11 2018 fstrba@suse.com
- Update to ustream tag jdk-11+13
  * Fixes:
    + S4842658: DefaultListModel and DefaultComboBoxModel should
    support addAll (Collection c)
    + S6574555: PNGImageWriter incorrectly sets bKGD chunk
    + S6788458: PNGImageReader ignores tRNS chunk while reading
    non-indexed RGB/Gray images
    + S8153532: Add @throws NPE javadoc to
    UIManager.setLookAndFeel(String) method description
    + S8154463: New failure of
    closed/java/awt/font/Outline/OutlineInvarianceTest.java
    + S8171277: Elliptic Curves for Security in Crypto
    + S8176717: GC log file handle leaked to child processes
    + S8181594: Efficient and constant-time modular arithmetic
    + S8181910: [macos] Support dark title bars on macOS
    + S8185034: Cleanup and consolidate Metaspace coding
    + S8187123: (reflect) Class#getCanonicalName and
    Class#getSimpleName is a part of performance issue
    + S8187392: Deprecated methods in the peers can be removed
    + S8189687: Swing: Invalid position of candidate pop-up of
    InputMethod in Hi-DPI on Windows
    + S8189916: Dynamic Constant support for Sparc
    + S8191410: Unicode 10
    + S8194968: problem list actions for
    tools/javac/jvm/VerboseOutTest
    + S8195002: Fix test/hotspot/jtreg/gtest/GTestWrapper.java on
    Alpine/Musl
    + S8195717: test java/lang/invoke/MethodHandlesTest timed out
    running testAsCollector1
    + S8196113: Remove the Compact Profile builds
    + S8196572: Tests ColConvCCMTest.java and MTColConvTest.java
    fail
    + S8197388: Added not existing bug id in jdk/ProblemList.txt
    + S8197447: LogCompilation throws "couldn't find bytecode"
    + S8197954: Remove unnecessary intermediary APIs from AppCDS
    implementation
    + S8198342: Test FileSystemViewListenerLeak.java is unstable
    + S8199067: [REDO] NMT: Enhance thread stack tracking
    + S8199196: Add javadoc support for preview features
    + S8199382: [TESTBUG] Open source VM testbase JDI tests
    + S8199748: Touch keyboard is not shown, if text component gets
    focus from other text component
    + S8199852: Print more information about class loaders in
    LinkageErrors.
    + S8199912: jshell tool: /open from URI
    + S8199932: Missing copyright header in AWT source code
    + S8200083: Bump bootjdk requirement for JDK 11 to JDK 10
    + S8200094: Turkish locale reports NPE No enum constant
    com.sun.source.doctree.DocTree.Kind.SİNCE
    + S8200146: Remove the appletviewer launcher
    + S8200313: java/awt/Gtk/GtkVersionTest/GtkVersionTest.java
    fails
    + S8200372: String::trim JavaDoc should clarify meaning of space
    + S8200557: OopStorage parallel iteration scales poorly
    + S8200716: Object propertyIsEnumerable buggy behavior on short
    integer-string key
    + S8200729: Conditional compilation of GCs
    + S8201138: Defect in XMLEventReader.getElementText() may cause
    data to be skipped, duplicated or otherwise result in a
    ClassCastException
    + S8201433: Fix potential crash in BufImg_SetupICM
    + S8201492: Properly implement non-contiguous generations for
    Reference discovery
    + S8201524: [AIX] Don't link libfontmanager against
    libawt_headless
    + S8201572: Improve Metaspace Statistics
    + S8201598: Fix for 8181910: Support dark title bars on macOS
    broke the MacOS build
    + S8201602: ARM32 - Minimal Dynamic Constant support
    + S8201626: Typo in MakeWindowAlwaysOnTop test
    + S8201640: Use _ref_processor_* member variables directly in
    G1CollectedHeap
    + S8201793: (ref) Reference object should not support cloning
    + S8202017: Merge Reference Enqueuing phase with phase 3 of
    Reference processing
    + S8202018: Move card table clear before enqueuing pending
    references
    + S8202021: Improve variable naming in ReferenceProcesso
    + S8202050: Add javax/sound/midi/Sequencer/Recording.java to
    the problemList
    + S8202080: Introduce ordering semantics for Atomic::add and
    other RMW atomics
    + S8202083: Remove explicit CMS checks in CardTableBarrierSet
    + S8202143: Parts of 8193435 added in merge change set.
    + S8202181: Correctly specify size of hostname buffer in Unix
    Inet*AddressImpl_getLocalHostName implementations
    + S8202291: java/rmi/Naming/LookupIPv6.java failed with
    Connection refused
    + S8202301: Add tests related to JDK-8196572 to the ProblemList
    + S8202303: LogStream should autoflush on destruction
    + S8202319: Fix compilation warnings in Solaris debug builds
    for DevStudio 12.6
    + S8202387: javac --release 11 not supported
    + S8202424: Metaspace: on chunk retirement, use correct lower
    limit on chunksize when adding blocks to free blocks list
    + S8202435: [aix] print program break as part of memory info
    into hs-err file
    + S8202447: Fix unloading_occurred to mean unloading_occurred
    + S8202465: [C1] casts should not be eliminated for interface
    types
    + S8202548: Use reservation Object when creating SpeciesData
    + S8202552: [AOT][JVMCI] Incorrect usage of INCLUDE_JVMCI and
    INCLUDE_AOT
    + S8202563: BigInteger/BigDecimal not immune to overflow,
    contrary to spec
    + S8202564: java/lang/management/ThreadMXBean/ThreadCounts.java
    fails
    + S8202565: C1 compilation crashes with
    "assert(is_double_stack() && !is_virtual()) failed: type check"
    + S8202575: Remove java/lang/String/nativeEncoding/
    /StringPlatformChars.java from ProblemList
    + S8202581: failure_handler: gather more environment
    information on macOS
    + S8202582: DateTimeFormatterBuilder.parseOffsetBased
    unnecessarily calls toString()
    + S8202583: Remove experimental ClassForNamePlugin
    + S8202584: de-problem list tools/javac/jvm/VerboseOutTest
    + S8202591: Remove usage of CMSEdenChunksRecordAlways in
    defNewGeneration.cpp
    + S8202592: Remove unused EvacuateFollowersClosure
    + S8202597: javac is not inducing a notional interface if
    Object appears in an intersection type
    + S8202599: Mark intermittently failing jshell tests
    + S8202606: Deprecate AllowNonVirtualCalls option
    + S8202631: JVM_Clone to throw CloneNotSupportException for
    Reference object
    + S8202634: Metaspace: simplify SpaceManager lists
    + S8202639: Use concrete Generation classes in SerialHeap and
    CMSHeap
    + S8202640: Small C1 cleanups for BarrierSetC1
    + S8202641: Replace OOP_SINCE_SAVE_MARKS with templates
    + S8202642: Replace PAR_OOP_ITERATE with templates
    + S8202647: Add deduplicate_string function to CollectedHeap
    + S8202649: Move the Parallel GC specific task creation
    functions out of Threads
    + S8202650: Enforce group for attach listener file
    + S8202662: JFR tests fails: Could not find leak with class
    + S8202672: Build failed in metaspace.cpp with VS2017
    + S8202676: AArch64: Missing enter/leave around barrier leads
    to infinite loop
    + S8202684: Minimal VM build is broken after JDK-8199067,
    JDK-8202638
    + S8202686: Missing test case for 8200167 - final Object methods
    + S8202690: jdk/jshell/ToolBasicTest.java failed in
    testOpenFileOverHttp() and testOpenLocalFileUrl()
    + S8202709: Move oopDesc::is_archive_object to
    MetaspaceShared::is_archive_object
    + S8202711: Merge tiered compilation policies
    + S8202719: Use Collections.emptyEnumeration where possible
    + S8202722: Move marksweep_init into GC code
    + S8202744: Expired flag removal for JDK 11
    + S8202780: Remove EnqueueTask related code from
    ReferenceProcessor after JDK-8202017
    + S8202781: Fix typo in DiscoveredListIterator::complete_enqeue
    + S8202810: Remove class-for-name test
    + S8202816: Update JarSigning.keystore
- Removed patch:
  * aarch64-infinite-loop.patch
  - Integrated upstream
- Modified patch:
  * java11-improved-fonts.patch
  - Rediff to changed context
* Thu May 10 2018 fstrba@suse.com
- Fix s390x build, since INCLUDE_SA is false by default on this
  architecture
* Tue May  8 2018 fstrba@suse.com
- Added patch:
  * aarch64-infinite-loop.patch
    + Fix inifinite loop in aarch64 build
* Mon May  7 2018 guillaume.gardet@opensuse.org
- Update fix_armv6_build.patch
* Mon May  7 2018 fstrba@suse.com
- Update to upstream tag jdk-11+12
  * Fixes:
    + S6672778: G1 should trim task queues more aggressively during
    evacuation pauses
    + S8154204: [TESTBUG] Update DefaultUseWithClient test to
    handle client-less builds
    + S8174994: SA: clhsdb printmdo throws WrongTypeException when
    attached to a process with CDS
    + S8179071: Month value is inconsistent between CLDR and Java
    in some locales
    + S8179887: Build failure with glibc >= 2.24: error: 'int
    readdir_r(DIR*, dirent*, dirent**)' is deprecated
    + S8181157: CLDR Timezone name fallback implementation
    + S8182731: Odd handling of -XX:-UseAppCDS and
  - XX:SharedArchiveFile.
    + S8191471: Elastic TLABs for G1
    + S8191798: redo nested ThreadsListHandle to drop Threads_lock
    + S8193213: Make the UseAppCDS option obsolete.
    + S8197959: [TESTBUG] Some (App)CDS tests require modification
    due to the removal of the Java EE and CORBA modules
    + S8197960: [TESTBUG] remove/modify runtime tests which use
    java ee or corba modules
    + S8199375: [TESTBUG] Open source vm testbase monitoring tests
    + S8199643: [TESTBUG] Open source common VM testbase code
    + S8200167: Validate more special case invocations
    + S8200235: Generalize jniFastGetField jobject/jweak resolve
    + S8200466: Revisit the setting of _transitive_interfaces in
    InstanceKlass
    + S8200478: For boxing conversion javac uses Long.valueOf which
    does not guarantee caching according to its javadoc
    + S8201367: assert(current != first_mem) failed: corrupted
    memory graph in superword code
    + S8201509: Zero: S390 31bit atomic_copy64 inline assembler is
    wrong
    + S8201542: Remove unused _gc_timer field in GCMemoryManager
    + S8201543: Modularize C1 GC barriers
    + S8201545: InetAddress.getByName/getAllByName should clarify
    empty String behavior
    + S8201622: Reduce unnecessary Package.complete() calls in
    javadoc
    + S8201634: Random seedUniquifier uses incorrect LCG
    + S8201650: Move iteration order randomization of unmodifiable
    Set and Map to iterators
    + S8201786: Modularize interpreter GC barriers: leftovers for
    ARM32
    + S8201817: Taglet.init should be called with the "primary"
    doclet
    + S8202082: Remove explicit CMS checks in
    CardTableBarrierSetAssembler
    + S8202105: Console echo is disabled when exiting jshell
    + S8202130: [TESTBUG] Some appcds regression test cases fail
    with "Error: VM option 'PrintSystemDictionaryAtExit' is
    notproduct and is available only in debug version of VM"
    + S8202140: TLAB logging is not correct for G1
    + S8202150: [REDO] Split globals.hpp to factor out the Flag
    class
    + S8202179: Compilation fails with assert(n->is_expensive())
    failed: expensive nodes with non-null control here only
    + S8202186: AArch64: Debug build VM crashes with
    PrintC1Statistics option
    + S8202200: set INCLUDE_SA to false on s390x by default
    + S8202204: Rename hotspot runtime jtreg constantPool
    ConstantPool directories
    + S8202230: Provide accessors for JNIHandles storage objects
    + S8202261: (fc) FileChannel.map and RandomAccessFile.setLength
    should not preallocate space
    + S8202273: [AOT] Graal does not support the CMS collector
    + S8202284: FileChannel and FileOutpuStream variants of
    AtomicAppend should fail silently on macOS >= 10.13
    + S8202324: Avoid loading FileInput-/OutputStream$AltFinalizer
    + S8202325: [aix] disable warnings-as-errors by default
    + S8202330: Add Unreferenced{FOS,FIS,RAF}ClosesFd to problem
    list
    + S8202334: Update javax.lang.model.util visitors for 11
    + S8202364: Add GCConfig::hs_err_name() to avoid GC-specific
    code in error reporting
    + S8202366: Add macro for common loop in GCConfig
    + S8202367: AIX build broken after JDK-8201543
    + S8202372: Diagnostic with incorrect line info generated when
    compiling lambda expression
    + S8202373: Forcing eager initialization of CHM$ReservationNode
    avoids deoptimization
    + S8202379: ARM32 is broken after JDK-8201543 (Modularize C1 GC
    barriers)
    + S8202381: (Solaris) SIGBUS in # V [libjvm.so+0xcee494]
    jni_GetIntField+0x224
    + S8202382: Filter docs modules
    + S8202383: Custom extensions for jvmti doc
    + S8202397: Typo in X-Buffer javadoc
    + S8202398: Optimize Arrays.deepHashCode
    + S8202399: [C1] LIRGenerator::do_CheckCast needs to exclude
    is_invokespecial_receiver_check() when using PatchAlot
    + S8202417: [TESTBUG] Broken hard-coded dependency in
    serviceability/sa/ClhsdbJhisto.java
    + S8202418: Remove explicit CMS checks in
    CardTableBarrierSetAssembler: ARM32 leftovers
    + S8202419: Avoid creating Permission constants early
    + S8202423: Small HTTP Client refresh
    + S8202425: [s390] C2: Wrong unsigned comparison with 0
    + S8202452: Delete test files missed from commit for
    8193213 & 8182731.
    + S8202484: Unused field in TimeZone
    + S8202505: ctw2 tasks are timing out in hs-tier3
    + S8202507: Remove IO and NIO AtomicAppend tests from problem
    list
    + S8202520: JShell tests: move intermittently failing tests to
    tier2
* Mon May  7 2018 guillaume.gardet@opensuse.org
- Remove armv6 and armv7 overwrite conditions in _constraints to
  avoid OOM errors
* Fri Apr 27 2018 fstrba@suse.com
- Update to upstream tag jdk-11+11
  * Fixes:
    + S6341887: java.util.zip: Add ByteBuffer methods to
    Inflater/Deflater
    + S6805750: Improve handling of Attributes.Name
    + S8025091: VisibleMemberMap.java possible performance
    improvements
    + S8081519: Split globals.hpp to factor out the Flag class
    + S8144806: sun/security/tools/keytool/standard.sh fails
    intermittently at deleting x.jks
    + S8154528: Reclaim regions emptied by marking in Remark pause
    + S8157543: java/nio/channels/Selector/SelectAndCancel.java
    fails intermittently
    + S8161991: java/nio/channels/AsynchronousSocketChannel/Basic.java
    failed due to RuntimeException: WritePendingException expected
    + S8171404: java/nio/channels/AsynchronousSocketChannel/Basic.java
    failed with "AsynchronousCloseException expected"
    + S8178105: Switch mark bitmaps during Remark
    + S8178825: unused variable threadObj in jvmci_counters_include
    + S8184693: add Pattern.isEmpty
    + S8187490: HotSpotGraalMBean should be moved to Graal
    management module
    + S8187496: Possible memory leak in
    java.apple.security.KeychainStore.addItemToKeychain
    + S8188105: Make -Xshare:auto the default for server VM
    + S8190227: Forward port 8188880 to JDK10CPU
    + S8192789: Avoid using AtomicReference in
    sun.security.provider.PolicyFile
    + S8193524: Redefining a method that removes use of 1 or more
    lambda expressions causes the JVM to hang
    + S8196071: Change G1 Full GC heap and thread sizing ergonomics
    + S8196325: GarbageCollectionNotificationInfo has same
    information for before and after
    + S8196433: use the new error diagnostic approach at javac.Main
    + S8196540: [Testbug] java/security/AccessController/
    /DoPrivAccompliceTest.java doesn't handle unrelated warnings
    + S8198756: Lazy allocation of compiler threads
    + S8198793: Add launcher support for preview features
    + S8198816: AbstractScriptEngine.getScriptContext creation of
    SimpleScriptContext is inefficient
    + S8198890: The standard doclet incorrectly produces wrong
    method signatures in certain cases.
    + S8199193: jshell tool: Add support for preview features
    + S8199519: Several GC tests fails with:
    java.lang.NumberFormatException: Unparseable number: "-"
    + S8199755: Update Graal
    + S8200101: sun/security/krb5/auto/Renewal.java fails
    intermittently
    + S8200196: [Graal] implement Object.notify/notifyAll intrinsics
    + S8200303: C2 should leverage profiling for
    lookupswitch/tableswitch
    + S8200426: Make G1 code use _g1h members
    + S8200450: Root cause analysis for JDK-8200366
    + S8200477: Integer dot product no longer autovectorised
    + S8200555: OopHandle should use Access API
    + S8200556: AArch64: assertion failure in slowdebug builds
    + S8200723: Suppress rs_length and predicted_cards sampling
    during mixed gcs
    + S8200730: Fix debug=gc+phases time tracking in Remark and
    Cleanup
    + S8201172: Parallelize Remset Tracking Update Before Rebuild
    phase
    + S8201226: missing JNIEXPORT / JNICALL at some places in
    function declarations/implementations
    + S8201259: Fix warning with VS2017 in jdk.pack
    + S8201281: Truncated error message with Incompatible : null
    + S8201315: (se) Allow SelectableChannel.register to be invoked
    while selection operation is in progress
    + S8201368: IfNode::fold_compares() may lead to incorrect
    execution
    + S8201369: Inet4AddressImpl_getLocalHostName reverse lookup on
    Solaris only
    + S8201466: Nashorn: defineProperty setters/getters on
    prototype object ignored with numeric property names
    + S8201487: Do not rebalance reference processing queues if not
    doing parallel reference processing
    + S8201490: Improve concurrent mark keep alive closure
    performance
    + S8201505: Use WeakHandle for ProtectionDomainCacheTable and
    ResolvedMethodTable
    + S8201510: Merge TwoStacksPlainSocketImpl into
    DualStackPlainSocketImpl [win]
    + S8201520: AsynchronousSocketChannel/Basic.java timeout
    intermitently
    + S8201527: Bump default value of G1RefProcDrainInterval
    + S8201536: configure fails compiler check due to bad -m32 flag
    + S8201537: Remove is_alive closure from
    Klass::is_loader_alive()
    + S8201540: [AIX] Extend the set of supported charsets in
    java.base
    + S8201556: Disallow reading oops in ClassLoaderData if
    unloading
    + S8201596: java.lang.ref.Reference processing total time
    logging broken
    + S8201597: AArch64: Update relocs for CompiledDirectStaticCall
    + S8201616: Hotspot crashes on linux-sparc after 8189941
    + S8201646: Introduce ReferenceDiscoverer interface
    + S8201647: Make initial clearing of CHeapBitMap optional
    + S8201649: Remove dubious call_jio_print in ostream.cpp
    + S8201766: Mark TimSortStackSize2.java as intermittently
    failing
    + S8201785: Make ModRefBarrierSetAssembler abstract on all
    platforms
    + S8201788: Number of make jobs wrong for bootcycle-images
    target
    + S8201794: [Graal] fix regressions from JDK-8187490
    + S8201799: Build failures after JDK-8195099 (Concurrent
    safe-memory-reclamation mechanism)
    + S8201800: Add support for adjusting heap addresses in a TLAB
    + S8201826: G1: Don't invoke WeakProcessor if mark stack has
    overflowed
    + S8201850: [AOT] vm crash when run test
    compiler/aot/fingerprint/SelfChangedCDS.java
    + S8202000: AIX build broken after JDK-8195099
    + S8202037: Split slow ctw_1 tests
    + S8202052: Disable warnings when building libawt with VS2017
    + S8202060: Add javax/net/ssl/DTLS/CipherSuite.java to
    ProblemList
    + S8202062: Put FileChannel and FileOutpuStream variants of
    AtomicAppend on problem list
    + S8202070: Cleanup code after JDK-8200450, JDK-8200366
    + S8202073: MetaspaceAllocationTest gtest shall lock during
    space creation
    + S8202074: Metaspace: If humongous chunk is added to
    SpaceManager, previous current chunk may not get retired correctly.
    + S8202075: Crash when running
    compiler/codecache/OverflowCodeCacheTest.java
    + S8202079: [s390]: Build failure w/o precompiled headers
    + S8202081: Introduce CollectedHeap::is_oop()
    + S8202091: Rename DualStackPlainSocketImpl to PlainSocketImpl
    [win]
    + S8202134: Non-PCH build for arm32 fails
    + S8202141: Unique symbols for .class
    + S8202151: [BACKOUT] Split globals.hpp to factor out the Flag
    class
    + S8202152: test/hotspot/jtreg/runtime/whitebox/WBStackSize.java
    fails
    + S8202154: Remove unused code in
    java.base/windows/native/libnet
    + S8202155: quarantine test com/sun/jdi/JdbExprTest.sh on all
    platforms
    + S8202157: remove the use of string keys at
    InapplicableMethodException
    + S8202164: Remove some unneeded BoolObjectClosure* is_alive
    parameters
    + S8202169: Reduce ctw_2 duration by parallelizing CtwRunner
    invocations
    + S8202184: Reduce time blocking the ClassSpecializer cache
    creating SpeciesData
    + S8202210: jlink uses little-endian for big-endian
    cross-compilation targets
    + S8202276: Update test/hotspot/jtreg/ProblemList-graal.txt
- Removed patch:
  * bootcycle_jobs.patch
    + Integrated upsteam
* Fri Apr 20 2018 fstrba@suse.com
- Update to upstream tag jdk-11+10 (April 2018 CPU)
  * Security fixes:
    + S8194238: Trying exceptions in MethodHandles (CVE-2018-2826,
    bsc#1090197)
    + S8194233: Improve support for array handles (CVE-2018-2825,
    bsc#1090196)
    + S8192025: Less referential references (CVE-2018-2814,
    bsc#1090032)
    + S8189997: Enhance keystore mechanisms (CVE-2018-2794,
    bsc#1090024)
    + S8189977: Improve permission portability (CVE-2018-2795,
    bsc#1090025)
    + S8189993: Improve document portability (CVE-2018-2799,
    bsc#1090029)
    + S8189989: Improve container portability (CVE-2018-2798,
    bsc#1090028)
    + S8189985: Improve tabular data portability (CVE-2018-2797,
    bsc#1090027)
    + S8189981: Improve queuing portability (CVE-2018-2796,
    bsc#1090026)
    + S8189969: Manifest better manifest entries (CVE-2018-2790,
    bsc#1090023)
  * Security-In-Depth fixes:
    + S8182362: Update CipherOutputStream Usage
    + S8183032: Upgrade to LittleCMS 2.9
    + S8189123: More consistent classloading
    + S8190478: Improved interface method selection
    + S8190877: Better handling of abstract classes
    + S8191696: Better mouse positioning
    + S8192030: Better MTSchema support
    + S8193409: Improve AES supporting classes
    + S8193414: Improvements in MethodType lookups
  * Fixes:
    + S8009632: (fs) FileStore.supportsFileAttributeView does not
    detect user_xattr enabled on ext4
    + S8049695: nsk/jdb/options/connect/connect003 fails with
    "Launched jdb could not attach to debuggee during 300000
    milliseconds"
    + S8057732: sun/jvmstat/monitor/MonitoredVm/
    /MonitorVmStartTerminate.java: Invalid PerfMemory size
    + S8078221: java/rmi/Naming/DefaultRegistryPort.java fails
    intermittently
    + S8151171: Bring g1ConcurrentMark files up to current coding
    conventions
    + S8152821: Merge jdk.internal.misc.JavaSecurityAccess and
    jdk.internal.misc.JavaSecurityProtectionDomainAccess shared
    secrets
    + S8175075: Add 3DES to the default disabled algorithm security
    property
    + S8180415: Rebuild remembered sets during the concurrent cycle
    + S8183238: Obsolete CheckEndorsedAndExtDirs and remove checks
    for lib/endorsed and lib/ext
    + S8184692: add Pattern.asMatchPredicate
    + S8186032: Disable XML Signatures signed with EC keys less
    than 224 bits
    + S8187472: AARCH64: array_equals intrinsic doesn't use
    prefetch for large arrays
    + S8189101: AARCH32 - 'minimal' build fails because CMS bits
    are referred unconditionally
    + S8189765: Improve error reporting for compiling against
    package not visible due to modules
    + S8191101: Show register content in hs-err file on assert
    + S8191358: Restore TSA certificate expiration check
    + S8193067: gc/g1/TestVerifyGCType.java still unstable
    + S8194259: keytool error: java.io.IOException: Invalid secret
    key format
    + S8194260: Point-to-point interface should be excluded from
    java/net/ipv6tests/*
    + S8194734: Handle to jimage file inherited into child
    processes (win)
    + S8194750: Console.readPassword does not save/restore tty
    settings
    + S8194812: Extend class-data sharing to support the module path
    + S8195099: Concurrent safe-memory-reclamation mechanism
    + S8195662: Add T6587786.java to problem list before
    JDK-8195589 is resolved
    + S8195972: Refactor oops in JNI to use the Access API
    + S8196289: Update src/java.desktop/share/legal/lcms.md for
    LCMS 2.9
    + S8196485: FromCardCache default card index can cause crashes
    + S8196516: libfontmanager must be built with LDFLAGS allowing
    unresolved symbols
    + S8196865: G1 log for active workers is wrong
    + S8197441: Signature#initSign/initVerify for an invalid
    private/public key fails with ClassCastException for SunPKCS11
    provider
    + S8197443: ArrayIndexOutOfBoundsException in
    UcryptoException.getError
    + S8197564: HTTP Client implementation
    + S8197569: Refactor eager reclaim for concurrent remembered
    set rebuilding
    + S8197570: Make rules for choosing collection set candidates
    more explicit
    + S8197573: Remove concurrent cleanup and secondary free list
    handling
    + S8197850: Calculate liveness in regions during marking
    + S8197928: Only enqueue deferred cards with references into
    regions that have a tracked remembered set during GC
    + S8197931: Null pointer dereference in Unique_Node_List::push
    of node.hpp:1510
    + S8197932: Better split work in rebuild remembered sets phase
    + S8197972: Always verify non-system classes during CDS dump
    time
    + S8198240: Allow cacerts test to pass when GTECyberTrust root
    expires
    + S8198313: Wrap holder object for ClassLoaderData in a
    WeakHandle
    + S8198335: java/awt/FullScreen/UninitializedDisplayModeChangeTest/
    /UninitializedDisplayModeChangeTest.java fails in headless mode
    + S8198393: Instrumentation.retransformClasses() throws
    NullPointerException when handling a zero-length array
    + S8198655: test/lib/jdk/test/lib/apps/LingeredApp shouldn't
    inherit cout/cerr
    + S8198691: CodeHeap State Analytics
    + S8198760: Move global lock SpaceManager::_expand_lock to
    MutexLocker.cpp
    + S8198908: Add JVM support for preview features
    + S8198915: [Graal] 3rd testcase of compiler/types/
    /TestMeetIncompatibleInterfaceArrays.java takes more than 10
    mins
    + S8198950: AArch64:
    org.openjdk.jcstress.tests.varhandles.DekkerTest fails
    + S8199007: ClassLoaderDataGraph::unload_list_contains() is
    wrong
    + S8199194: Add javac support for preview features
    + S8199326: Remove G1 gc time stamp logic
    + S8199360: Rework the support for the 'ignored' module options
    in CDS
    + S8199406: Performance drop with Java JDK 1.8.0_162-b32
    + S8199417: Modularize interpreter GC barriers
    + S8199619: Building HotSpot on Windows should define NOMINMAX
    + S8199627: Use "Per-Monitor V2" High DPI awareness for Windows
    10 v1703
    + S8199717: Avoid calculating primordial thread stack bounds on
    VM startup
    + S8199735: Mark word updates need to use Access API
    + S8199736: Define WIN32_LEAN_AND_MEAN before including
    windows.h
    + S8199742: Clean up state flags in G1CollectorState
    + S8199780: SetMemory0 and CopyMemory0 in unsafe.cpp need to
    resolve their operands
    + S8199781: Don't use naked == for comparing oops
    + S8199782: Fix compilation warnings detected by Solaris
    Developer Studio 12.6
    + S8199793: [Graal] runtime/CommandLine/
    /PrintTouchedMethods.java crashes with assertion "reference
    count underflow for symbol"
    + S8199813: SIGSEGV in ThreadsList::includes()
    + S8199850: Move parsing of VerifyGCType to G1
    + S8199918: Shorten names of CollectedHeap::Name members
    + S8199925: Break out GC selection logic from GCArguments to
    GCConfig
    + S8199927: Make WhiteBox more GC agnostic
    + S8199946: Move load/store and encode/decode out of oopDesc
    + S8200067: Add support for vpclmulqdq for crc32
    + S8200074: Remove
    G1ConcurrentMark::_concurrent_marking_in_progress
    + S8200078: [Graal] runtime/appcds/GraalWithLimitedMetaspace.java
    crashes in visit_all_interfaces
    + S8200091: [TESTBUG] Update jittester for jdk11
    + S8200105: Remove cyclic dependency between oop.inline.hpp and
    collectedHeap.inline.hpp
    + S8200106: Move NoSafepointVerifier out from gcLocker.hpp
    + S8200111: MallocArrayAllocator::free should not take a length
    parameter
    + S8200113: Make Access load proxys smarter
    + S8200126: [TESTBUG] Open source VM runtime signal tests
    + S8200149: The "com.sun.awt.AWTUtilities" class can be dropped
    + S8200168: Remove DONT_USE_REGISTER_DEFINES on Sparc
    + S8200169: Flatten G1Allocator class hierarchy
    + S8200187: Exclude 3 long-running tests from tier1
    + S8200195: serviceability/jvmti/FieldAccessWatch/
    /FieldAccessWatch.java crashes with
    "assert(thread->thread_state() == _thread_in_native) failed:
    coming from wrong thread state"
    + S8200197: Zero fails to build after 8200105
    + S8200202: Remove unused _boot_modules_array and
    _platform_modules_array from classLoader.*.
    + S8200203: Missing platform definitions for ia64
    + S8200227: [Graal] Test times out with Graal due to low
    compile threshold
    + S8200228: Change default value of HeapSizePerGCThread
    + S8200230: [Graal] Compilations should not be enqueued before
    Graal is initialized
    + S8200232: Build failures after JDK-8200106 (Move
    NoSafepointVerifier out from gcLocker.hpp)
    + S8200233: Simple G1 evacuation path performance enhancements
    + S8200234: Cleanup Remark and Cleanup pause code
    + S8200238: Reduce number of exceptions created when calling
    MemberName$Factory::resolveOrNull
    + S8200245: Zero fails to build on linux-ia64 due to
    ia64-specific cruft
    + S8200246: AIX build fails after adjustments of
    src/hotspot/share/trace/traceEventClasses.xsl
    + S8200251: AArch64::CPUFeature out of sync with
    VM_Version::Feature_Flag
    + S8200255: Remove G1CMTask::_concurrent
    + S8200261: Regression with JVM anonymous class
    + S8200276: Cleanup allocation.hpp includes
    + S8200290: Scratch buffer creation fails with
    "assert(!current_thread_in_native()) failed: must not be in
    native" on SPARC
    + S8200292: Move PushAndMarkVerifyClosure::do_oop_work to
    concurrentMarkSweepGeneration.cpp
    + S8200297: Build failures after JDK-8198691 (CodeHeap State
    Analytics)
    + S8200299: Non-PCH build for aarch64 fails
    + S8200302: ppc, s390 (non-pch) build errors
    + S8200305: Update gc,liveness output with remset state after
    rebuild remset concurrently changes
    + S8200343: Minor JViewport documentation typo
    + S8200360: MeetIncompatibleInterfaceArrays fails with
    "MeetIncompatibleInterfaceArrays0ASM.run() must be compiled at
    tier 0 !"
    + S8200362: G1Mux2Closure should disable implicit oop
    verification
    + S8200366: SIGSEGV in CodeHeapState::print_names()
    + S8200371: In g1, rename ConcurrentMarkThread to
    G1ConcurrentMarkThread
    + S8200374: Add
    ThreadsSMRSupport::verify_hazard_pointer_scanned() to verify
    threads_do().
    + S8200383: Can't build on SPARC Hotspot with code which use
    math functions
    + S8200384: jcmd help output should be sorted
    + S8200385: Eagerly reclaimed humongous objects leave mark in
    prev bitmap
    + S8200391: clean up test/hotspot/jtreg/ProblemList.txt
    (compiler related)
    + S8200423: Non-PCH build for x86_32 fails
    + S8200424: Windows build fails due to implicit jboolean to
    bool conversion
    + S8200429: Adjust object pinning interface on CollectedHeap
    + S8200438: Non-PCH x86_32 build failure: err_msg is not defined
    + S8200461: MeetIncompatibleInterfaceArrays test fails with
  - Xcomp
    + S8200468: Port the native GSS-API bridge to Windows
    + S8200524: AArch64: CPUFeature and Flag enums are not passed
    through JVMCI
    + S8200525: test java/awt/event/SequencedEvent/SequencedEventTest.java
    fails to compile
    + S8200526: Test sun/java2d/marlin/ClipShapeTest.java times out
    + S8200550: Xcode 9.3 produce warning -Wexpansion-to-defined
    + S8200607: Add missing include dependency in bitMap.hpp
    + S8200608: Build failures after JDK-8191101 (Show register
    content in hs-err file on assert)
    + S8200626: Restore history for g1ConcurrentMarkThread.*
    + S8200627: aarch32 - Broken build after JDK-8198949
    + S8200628: aarch32 - Broken build after JDK-8199809
    + S8200630: Globally suppress Visual Studio warning C4351
    + S8200697: Add utility for spin wait with fallback to
    yield/sleep
    + S8200719: Cannot connect to IPv6 host when exists any active
    network interface without IPv6 address
    + S8200735: Move CMS specific code from binaryTreeDictionary
    and freeList to CMS files
    + S8200736: Move CMSGCStats to the cms directory
    + S8200737: Move GC code out of
    Arguments::check_vm_args_consistency into GCArguments
    + S8200759: Move GC entries in vmStructs.cpp to GC specific
    files
    + S8201136: Move GC flags from globals.hpp to GC specific files
    + S8201167: Remove MacroAssembler::cmp_heap_oop on x86
    + S8201168: Move GC command line constraint functions to GC
    specific files
    + S8201171: Cleanup in g1CollectedHeap, change CamelCase to
    snake_case
    + S8201175: Move FilteringClosure::do_oop to genOopClosures
    + S8201185: AARCH64: bfm instruction encoding hits assert on
    zero register
    + S8201209: Separate out CMS specific functions into
    CMSCardTable
    + S8201212: Remove INCLUDE_ALL_GCS from OopStorage files
    + S8201213: Remove INCLUDE_ALL_GCS from
    memset_with_concurrent_readers
    + S8201217: Split specialized_oop_closures.hpp into GC specific
    files
    + S8201218: PPC64: Avoid use of yield instruction on spinlock
    + S8201227: Add ALL_GCS_ONLY
    + S8201240: Improve releasing native resources of
    BufImgSurfaceData.ICMColorData
    + S8201242: Include source file/line number when reporting
    native call stack on supported platforms
    + S8201244: Clean out unnecessary includes of heap headers
    + S8201247: Various cleanups in the attach framework
    + S8201265: Native memory leak in
    ClassLoader::add_to_exploded_build_list
    + S8201316: Move G1-related static members from JavaThread to
    G1BarrierSet
    + S8201318: Introduce GCThreadLocalData to abstract GC-specific
    data belonging to a thread
    + S8201321: NMT: Unnecessary re-recording thread stack and size
    when attaching listener to JavaThread
    + S8201330: Add java/lang/management/ThreadMXBean/
    /ThreadMXBeanStateTest.java to the ProblemList
    + S8201334: Move runtime/NMT/MallocStressTest.java to
    hotspot_tier3_runtime
    + S8201359: Incorrect header guards after JDK-8198949
    (Modularize arraycopy stub routine GC barriers)
    + S8201362: Remove CollectedHeap::barrier_set()
    + S8201365: Remove G1Policy::should_process_references()
    + S8201370: GC specific data is referred from common
    precompiled headers and defNewGeneration.cpp
    + S8201427: Fix Minimal VM builds on Linux x64
    + S8201430: [TESTBUG] Remove script from runtime/6626217
    + S8201442: objArrayOopDesc::atomic_compare_exchange_oop() must
    use obj+offset in HeapAccess call
    + S8201443: NoSuchMethodException JarFile.open when jar file is
    used in classpath
    + S8201450: Provide access to LogHandle tagset
    + S8201474: (so) Socket adaptor connect(InetAddress, timeout)
    succeeds when connection fails
    + S8201475: 8199417 breaks AIX and non-pch on s390 (and
    presumably aarch64)
    + S8201480: ISA/CPU feature detection code crashes on
    linux-sparc
    + S8201483: Make it possible to disable JVM features
    + S8201494: Avoid early initialization of java.nio.Bits
    + S8201495: [Zero] Reduce limits of max heap size for boot JDK
    on s390
    + S8201498: test/langtools/tools/javac/diags/CheckExamples.java
    6 errors occurred
    + S8201507: Generate alias entries in j.t.f.ZoneName from tzdb
    at build time
    + S8201508: Macosx builds fail in GenerateLinkOptData.gmk
    + S8201554: Disable failing tier1 test for JDK-8201498
    + S8201584: Fix configure on SLES 11 after 8201483
    + S8201591: JVM features with "-" in name is not correctly
    handled
    + S8201609: Split test/jdk/:tier2 to enable better parallel
    execution
- Removed patch
  * fix-arm-build.patch
    + Integrated upstream
- Modified patch:
  * memory-limits.patch
    + Rediff with changes in the right files
* Thu Apr 19 2018 guillaume.gardet@opensuse.org
- Fix armv6 build with fix_armv6_build.patch
* Fri Apr 13 2018 fstrba@suse.com
- Update to upstream tag jdk-11+9
  * Fixes
    + S8071367: JMX: Remove SNMP support
    + S8164781: Pattern.asPredicate specification is incomplete
    + S8178867: tools/jlink/multireleasejar/
    /JLinkMultiReleaseJarTest.java failed to clean up files
    + S8180570: Refactor sun/security/mscapi shell tests to plain
    java tests
    + S8188897: java/rmi/registry/reexport/Reexport.java failed
    with Port already in use
    + S8189784: Parsing with Java 9 AKST timezone returns the
    SystemV variant of the timezone
    + S8190333: sun/security/ssl/X509KeyManager/PreferredKey.java
    failed with "Failed to get the preferable key aliases"
    + S8196200: Implement a navigation builder in javadoc
    + S8196724: Change macosx deployment target to 10.9
    + S8196750: [Testbug] tools/launcher tests need to tolerate
    unrelated warnings
    + S8196775: java/net/Socket/asyncClose/Race.java failed
    intermittently on Windows with ConnectException: Connection
    refused
    + S8197418: Move java/util/RandomAccess/ tests into OpenJDK
    + S8197531: Miscellaneous changes imported from jsr166 CVS
    2018-04
    + S8199539: Provide a standard way for the build to filter
    un-needed legal .md files
    + S8199608: Clean up LDFLAGS for libfontmanager
    + S8199744: Incorrect compiler message for ReceiverParameter in
    inner class constructor
    + S8199875: Require first parameter type of a condy bootstrap
    to be Lookup
    + S8200125: Fix some classloader/module typos
    + S8200127: Replace collection.stream().forEach() with
    collection.forEach()
    + S8200128: Fix some "annoations" typos
    + S8200131: Improve lazy init of InetAddress.canonicalHostName
    and NativeObject.pageSize
    + S8200134: Improve ModuleHashesBuilder
    + S8200152: KerberosString should use UTF-8 by default
    + S8200258: Improve CopyOnWriteArrayList subList code
    + S8200298: Unify all unix versions of libjsig/jsig.c
    + S8200358: Remove mapfiles for JDK executables
    + S8200359: (tz) Upgrade time-zone data to tzdata2018d
    + S8200458: (se) Readiness information previously recorded in
    the ready set not preserved
    + S8200520: forkjoin tasks interrupted after shutdown
    + S8200583: (se) Selector clean-up, part 4
    + S8200664: fix broken links in java.base docs
    + S8200706: Better cleanup for open/test/jdk/java/lang/
    /ProcessBuilder/DestroyTest.java
    + S8200727: linux-aarch64 profile should use bundled freetype
    + S8200728: Docs (Comparison of Stack and Deque methods) for
    Deque is not correct
    + S8200788: Optimal initial capacity of
    java.lang.VarHandle.AccessMode.methodNameToAccessMode
    + S8200792: PKCS12Attribute#hashCode is always constant -1
    + S8200888: typo in name of exception in @throws
    + S8201178: Remove sun.nio.cs.FastCharsetProvider
    + S8201179: Regression due loading
    java.nio.charset.StandardCharsets during bootstrap
    + S8201194: Handle local variable declarations in lambda
    deduplication
    + S8201221: JDK-8199608 introduced a build race on macosx
    + S8201222: JDK-8199539 broke the OpenJDK build
    + S8201236: Straighten out dtrace build logic
    + S8201246: Export native function to set platform encoding
    + S8201251: The tests for JDK-8187247 should be under
    test/langtools
    + S8201263: Trailing backslash in VS120COMNTOOLS leads to ugly
    error message when running tests
    + S8201267: Disable warnings for VS2017 to enable building
    + S8201320: Allow PrintFailureReports to be turned off
    + S8201327: Make Sensor deeply immutably thread safe
    + S8201328: SynthParser should use Boolean.parseBoolean
    + S8201348: ProblemList update for bugid associated with
    SSLSocketParametersTest.sh
    + S8201357: ALSA_CFLAGS is needed; was dropped in JDK-8071469
    + S8201396: fix broken links generated by javadoc doclet
    + S8201439: Enable linux-arm-vfp-hflt profile to be configured
    with jib again
    + S8201440: javac should create unique DynamicMethodSymbols at
    LambdaToMethod
- Modified patches:
  * java11-improved-fonts.patch
    + Rediff to changed context
  * fix-arm-build.patch
    + Use upstream fixes
* Wed Apr 11 2018 fstrba@suse.com
- Modified patch:
  * fix-arm-build.patch
    + fix more duplicate commas in headers
* Fri Apr  6 2018 fstrba@suse.com
- Update to upstream tag jdk-11+8
  * Fixes
    + S4954348: JPGWriter.getNumThumbnailsSupported does not return
  - 1 when passing null values
    + S8074286: Add getSelectedIndices() to ListSelectionModel
    + S8178370: [TEST_BUG]
    java/security/Signature/SignatureLength.java fails
    + S8191957: JFileChooser shows empty name for external drives
    shown under Desktop
    + S8193032: Remove terminally deprecated SecurityManager APIs
    + S8195649: reorganize tests for java.util.Optional
    + S8198314: javac hidden options violate standard syntax for
    options
    + S8198801: JShell: user exception chained cause not retained
    + S8198885: upgrade Marlin (java2d) to 0.9.1
    + S8198990: Move SwingSet2 from closed to OpenJDK
    + S8199176: Accessibility issues in java.base docs
    + S8199800: Optimize Boolean.parseBoolean(String)
    + S8199947: Rename HTML element id in ClassLoader javadoc to
    avoid name conflict with private elements
    + S8200200: test java/awt/image/ColorModel/Non_sRGBCMTest.java
    fails with open profiles
    + S8200257: (se) More Selector cleanup
    + S8200267: a.out created at top dir by Solaris build
    + S8200364: Remove unnecessary boxing via primitive wrapper
    valueOf(String) methods
    + S8200375: Change to GCC 7.3.0 for building Linux at Oracle
    + S8200469: Update link to license in Docs.gmk
    + S8200538: cl : Command line warning D9014 : invalid value
    '2220' for '/wd'
    + S8200586: Update JDK11 release date to 2018-09-25
    + S8200658: Fix incremental builds of hotspot on solaris
    + S8200696: Optimal initial capacity of
    java.lang.Class.enumConstantDirectory
    + S8200703: Problem list jdk/jshell/ExceptionsTest.java fails
    on windows
* Thu Apr  5 2018 fstrba@suse.com
- Added patch:
  * fix-arm-build.patch
    + fix a duplicate comma in a header
* Tue Apr  3 2018 fstrba@suse.com
- Update to upstream tag jdk-11+7
  * Fixes:
    + S4912693: Behavior of null arguments not specified in Java
    Sound
    + S6686236: GIF native IIOMetadata assumes
    characterCellWidth/Height as 2bytes
    + S7031957: DIB header of type BITMAPV2INFOHEADER &
    BITMAPV3INFOHEADER is not supported in BMPImageReader
    + S7108280: JList.getSelectedValuesList fails if
    JList.setSelectionInterval larger than list
    + S7158623: Should an unfocusable maximized Frame be resizable
    + S8071282: remove misc dead code
    + S8071469: Cleanup include and exclude of sound native
    libraries
    + S8140359: get_locked_message_ext() should return Flag::MsgType
    + S8144300: http.nonProxyHosts value having wildcard * both at
    end and start are not honored
    + S8146201: [AOT] Class static initializers that are not pure
    should not be executed during static compilation
    + S8152974: AWT hang occurrs when sequenced events arrive out
    of sequence
    + S8153333: [REDO] STW phases at Concurrent GC should count in
    PerfCounte
    + S8159850: Remove unneeded parsing of optional-size when
    parsing array types
    + S8166642: serviceability/dcmd/framework/* timeout
    + S8170541: serviceability/jdwp/AllModulesCommandTest.java
    fails intermittently on Windows and Solaris
    + S8173070: Remove ValueObj class for allocation subclassing
    for runtime code
    + S8173100: AArch64: -XX:-UseOnStackReplacement does not work
    together with -XX:+TieredCompilation
    + S8175312: SA: clhsdb: Provide an improved heap summary for
    'universe' for G1GC
    + S8180410: ByteArrayOutputStream should not throw IOExceptions
    + S8180451: ByteArrayInputStream should override readAllBytes,
    readNBytes, and transferTo
    + S8191102: Incorrect include file use in classLoader.hpp
    + S8191418: List.of().indexOf(null) doesn't throw
    NullPointerException
    + S8191585: VM anonymous classes created during CDS dump time
    cause crash
    + S8191924: Adjust DelegatingClassLoader's metadata space
    sizing algorithm
    + S8191954: AArch64: disable UseCISCSpill in C2
    + S8193128: Reduce number of implementation classes returned by
    List/Set/Map.of()
    + S8193130: Bad graph when unrolled loop bounds conflicts with
    range checks
    + S8193266: AArch64: TestOptionsWithRanges.java SIGSEGV
    + S8193369: post_field_access does not work for some functions,
    possibly related to fast_getfield
    + S8193429: "assert(false) failed: GetModuleFileName failed
    (126)" in symbolengine.cpp
    + S8193434: [GRAAL] Graal classes are not loaded with
  - Xshare:dump
    + S8194054: [TESTBUG] Test runtime/CommandLine/
    /OptionsValidation/TestOptionsWithRanges.java failed with
  - 1073740940 (FFFFFFFFC0000374)
    + S8194490: [JVMCI] Move `iterateFrames` to C++
    + S8194746: (fs) Add equivalents of Paths.get to Path interface
    + S8194759: Support caching class mirror objects.
    + S8194978: Javac produces dead code for try-with-resource
    + S8195095: Images are not scaled correctly in JEditorPane
    + S8195109: ServiceUtil::visible_oop is not needed anymore
    + S8195148: Collapse G1SATBCardTableModRefBS and
    G1SATBCardTableLoggingModRefBS into a single G1BarrierSet
    + S8196028: JMX: Not enough JDP packets received before timeout
    + S8196121: runtime/appcds/ClassLoaderTest.java fails silently
    + S8196294: LoopStripMiningIterShortLoop is set to zero by
    default
    + S8196337: Add commit methods that take all event properties
    as argument
    + S8196399: Formatting a decimal using locale-specific grouping
    separators causes ArithmeticException (division by zero).
    + S8196519: Incomplete classpath causes infinite recursion in
    Resolve.isAccessible
    + S8196590: Enable docker container related tests for linux
    AARCH64
    + S8196626: [Graal] runtime/appcds/UseAppCDS.java crashes with
    "VM thread using lock Heap_lock (not allowed to block on)"
    + S8196668: revisit test SunPackageAccess and
    GrantedSunPackageAccess
    + S8196876: OopStorage::assert_at_safepoint clashes with
    assert_at_safepoint macros in g1CollectedHeap.hpp
    + S8197235: src/hotspot/share/jvmci/jvmciCompilerToVM.cpp takes
    4 minutes to compile on windows
    + S8197405: Improve messages of AbstractMethodErrors and
    IncompatibleClassChangeErrors.
    + S8197429: Increased stack guard causes segfaults on x86-32
    + S8197554: Create test for SwingSet TableDemo
    + S8197595: Serialization javadoc should link to security best
    practices
    + S8197842: Remove unused macros VM_STRUCTS_EXT and VM_TYPES_EXT
    + S8197843: Remove unused method
    G1EvacuationRootClosures::create_root_closures_ext
    + S8197844: JVMTI GetLoadedClasses should use the Access API
    + S8197845: Remove unnecessary method
    G1CollectedHeap::create_g1_policy
    + S8197847: Remove unused file g1ParScanThreadState_ext.cpp
    + S8197852: Move G1DefaultPolicy into G1Policy
    + S8197944: Condy tests fails on Windows
    + S8198243: Add build time check for global operator new/delete
    in object files
    + S8198358: Align organization of TwoStacksPlainSocketImp with
    DualStackPlainSocketImpl [win]
    + S8198423: Improve metaspace chunk allocation
    + S8198424: Remove G1AllocationContext
    + S8198430: Remove G1Allocator extension point
    + S8198431: Remove G1FullCollector extension point
    + S8198432: Remove Thread extension point
    + S8198433: Remove WhiteBox extension point
    + S8198445: Access API for primitive/native arraycopy
    + S8198447: Remove ClassLoaderExt::check().
    + S8198510: Enable UseDynamicNumberOfGCThreads by default
    + S8198546: [Redo] JDK-8196883 G1RemSet::refine_card_concurrently
    doesn't need to check for cards in collection set
    + S8198552: Multiple javac plugins do not work at the same time.
    + S8198571: [JVMCI] must not install wide vector code unless
    runtime supports it
    + S8198591: compiler/aot/fingerprint tests should be moved to
    open
    + S8198608: Improvements to command-line flags printing
    + S8198649: Switch AWT/Swing's default GTK version to 3
    + S8198652: Stop linking with -base:0x8000000 on Windows
    + S8198753: (dc) DatagramChannel throws unspecified exceptions
    + S8198789: [TESTBUG] CTW of java.base and java.desktop takes
    long time
    + S8198794: Hotspot crash on Cassandra 3.11.1 startup with
    libnuma 2.0.3
    + S8198796: Create test case for CDS + condy
    + S8198826: -XX:+VerifyStack fails with fatal error:
    ExceptionMark constructor expects no pending exceptions
    + S8198833: TestMemoryAwareness Docker container fails with too
    small maximum heap
    + S8198845: Missing resource mark results disassembling
    generated code failure in hs error report
    + S8198894: [PPC64] More generic vector CRC implementation
    + S8198895: Compilation errors in java.desktop with VS 2017
    + S8198896: Remove dead code: cardTableModRefBSForCTRS.hpp
    + S8198897: Compilation errors in jdk.accessibility with VS 2017
    + S8198906: JDK-8196882 breaks VS2013 Win32 builds
    + S8198924: [Graal] java/lang/StackWalker/LocalsAndOperands.java
    timeouts with Graal
    + S8198926: Move ClassLoaderData::_dependencies to
    ClassLoaderData::_handles
    + S8198948: Remove unused parameter evacuation_info from
    G1CollectedHeap::evacuate_collection_set
    + S8198949: Modularize arraycopy stub routine GC barriers
    + S8198950: AArch64:
    org.openjdk.jcstress.tests.varhandles.DekkerTest fails
    + S8198957: Remove unused function
    ArgumentsExt::set_gc_specific_flags
    + S8198969: Update Graal
    + S8198987: [Graal] compiler/intrinsics/sha/sanity tests fail
    on macos with Graal as JIT
    + S8198997: Cache normalized/resolved user.dir property
    + S8199010: attachListener.hpp: Fix potential null termination
    issue found by coverity scans
    + S8199012: SEGV in jni_DetachCurrentThread during VM shutdown
    + S8199024: Remove unneccessary protected and virtual modifiers
    from G1CollectedHeap
    + S8199027: Make protected members private in G1Policy
    + S8199050: reenable concurrent execution of compiler tests
    + S8199066: [JVMCI] EagerJVMCI option should also initialize
    the JVMCI compiler
    + S8199133: [BACKOUT] NMT: Enhance thread stack tracking
    + S8199137: StringInternSync test crashes in exit verification
    + S8199212: [TESTBUG] don't run compiler/aot tests with -Xcomp
    + S8199219: Build failures after JDK-8195148 (Collapse
    G1SATBCardTableModRefBS and G1SATBCardTableLoggingModRefBS
    into a single G1BarrierSet)
    + S8199220: Zero build broken after 8195103, 8191102 and 8189871
    + S8199243: aarch32: ARM 32 build broken after 8165929
    + S8199263: Split interfaceSupport.hpp to not require including
    .inline.hpp files
    + S8199264: Remove universe.inline.hpp to simplify include
    dependencies
    + S8199272: Broken assertion in ClassLoaderData::remove_handle
    + S8199275: Fix inclusions of allocation.inline.hpp
    + S8199278: Javadoc search results does not link to anchors on
    a page
    + S8199282: Remove ValueObj class for allocation subclassing
    for gc code
    + S8199283: Remove ValueObj class for allocation subclassing
    for compiler code
    + S8199319: Remove handles.inline.hpp include from
    reflectionUtils.hpp
    + S8199323: hsdis could not be loaded which are located on long
    path
    + S8199328: Fix unsafe field accesses in heap dumper
    + S8199342: The constant pool forgets it has a Dynamic entry if
    there are overpass methods
    + S8199356: Fix hotspot to allow stdlib to use libc++ and to
    allow changing the deployment target to 10.9
    + S8199421: Add support for vector popcount
    + S8199422: Hotspot build is broken after push of 8197235
    + S8199425: JTReg failure:
    runtime/stringtable/StringTableVerifyTest.java
    + S8199430: Rename MetaspaceAux to something more meaningful
    + S8199431: Split up class Metaspace into a static and a
    non-static part
    + S8199432: metaspace: fix wrong comment and condition in
    SpaceManager::verify()
    + S8199465: {@docRoot} references need to be updated to reflect
    new module/package structure
    + S8199467: Compilation Errors in libinstrument Reentrancy.c
    with VS2017
    + S8199472: Fix non-PCH build after JDK-8199319
    + S8199489: [TESTBUG] don't run CTW tests with -Xcomp
    + S8199511: Do not generate g1_{pre|post}_barrier_slow_id
    without CardTable-enabled barrier set
    + S8199516: Remove dead code overlooked during Full GC work
    + S8199518: test/hotspot/jtreg/runtime/SelectionResolution
    tests take a lot longer to run with fastdebug after JDK-8198423
    + S8199532: [TESTBUG] AbstractMethodErrorTest.java test failed
    with -Xcomp
    + S8199533: ProblemList tests failing after JDK-8153333
    + S8199557: Assert in fromTonga/vm/runtime/defmeth/scenarios/
    /Stress_noredefine/TestDescription.java
    + S8199559: objArrayKlass::oop_iterate() and friends must use
    base_raw() instead of base()
    + S8199561: Fix two typos in the JVMTI documentation
    + S8199603: Build failures after JDK-8199421 "Add support for
    vector popcount"
    + S8199604: Rename CardTableModRefBS to CardTableBarrierSet
    + S8199620: Support for JNI object pinning
    + S8199624: [Graal] Blocking jvmci compilations time out
    + S8199656: Make slow metaspace verifications switchable in
    debug builds
    + S8199667: Unify metaspace list index handling and
    reinstantiate ChunkManager listindex gtest
    + S8199672: ClassCastException is thrown by java.util.Formatter
    when an NumberFormatProvider SPI is used.
    + S8199674: Improve G1 Full GC array marking
    + S8199685: Access arraycopy build failure with GCC 7.3.1
    + S8199696: Remove Runtime1::arraycopy
    + S8199698: Change 8199275 breaks template instantiation for
    xlC (and potentially other compliers)
    + S8199705: Docs.gmk needs to be updated to remove the -html5
    option
    + S8199716: Unused AdjustKlassClosure in psParallelCompact.hpp
    + S8199728: Remove oopDesc::is_scavengable
    + S8199739: Use HeapAccess when loading oops from static fields
    in javaClasses.cpp
    + S8199741: NMT: Tag safepoint polling pages
    + S8199752: NMT: Memory allocated by Unsafe.allocateMemory
    should be tagged as mtOther
    + S8199756: Simplify language, country, script, and variant
    property initialization
    + S8199762: JShell API: Failed to detect override when snippet
    to be overridden has been changed before
    + S8199773: (bf) XXXBuffer:compareTo method is not working as
    expected
    + S8199777: Deprecate -XX:+AggressiveOpts
    + S8199784: PhaseIdealLoop::place_near_use() might return wrong
    control with loop strip mining
    + S8199789: Emit a warning message when t2k is selected via
    system property
    + S8199791: (se) More Selector cleanup
    + S8199809: Don't include frame.inline.hpp and other.inline.hpp
    from .hpp files
    + S8199843: Optimize Integer/Long.highestOneBit()
    + S8199870: colorimaging.md needs to remove mention of KCMS
    + S8199880: runtime/appcds/condy/CondyHelloTest.java missing at
    requires vm.cds
    + S8199886: gc/cslocker/TestCSLocker.java crashes
    + S8199896: [Graal] build Graal on all x86 platforms
    + S8199902: {@docRoot} references need to be updated to reflect
    new module/package structure
    + S8199910: Compiler crashes with -g option and variables of
    intersection type inferred by `var`
    + S8199924: Solaris: Correctly enqueue null arguments of attach
    operations
    + S8200071: Fix test/hotspot/jtreg/ProblemList-graal.txt
    + S8200072: Remove un-needed qualified export from java.base to
    java.desktop
    + S8200116: ConstructInflaterOutput, ConstructDeflaterInput
    still spamming test logs
    + S8200118: [TESTBUG] String concat tests should test
    toString() application order
    + S8200122: Remove unused field Thread.threadQ
    + S8200123: Replace Thread.init with telescoping constructor
    + S8200124: Various cleanups in jar/zip
    + S8200129: Remove D3D Performance Counter.
    + S8200135: test/hotspot/jtreg/compiler/jvmci/compilerToVM/
    /GetExceptionTableTest.java is failing after JDK-8194978
    + S8200136: Problem list test/hotspot/jtreg/compiler/jvmci/
    /compilerToVM/GetExceptionTableTest.java
    + S8200174: compare.sh improvements
    + S8200178: Remove mapfiles for JDK native libraries
    + S8200179: (se) More Selector cleanup
    + S8200180: fix a typo in run-test framework documentation
    + S8200181: Remove superflous non-IPv4 code from
    Java_java_net_TwoStacksPlainSocketImpl_socketListen
    + S8200198: javah man pages were not removed by JDK-8191054
    + S8200199: javac suggests to use var even when var is used
    + S8200213: Configure broken on MIPS
    + S8200215: 17th loop of "let foo = ''"; throws ReferenceError
    + S8200229: Simplify building of libjsig
    + S8200241: [TESTBUG] java/lang/String/concat/ tests should not
    force source/target = 9 anymore
    + S8200256: java/nio/channels/AsynchronousChannelGroup/Basic.java
    fails intermittently
    + S8200289: Reduce number of exceptions created when calling
    Lookup::canBeCached
    + S8200301: deduplicate lambda methods
    + S8200304: TwoStacksPlainDatagramSocketImpl and socket cleaner
    + S8200310: Avoid charset lookup machinery in
    java.nio.charset.StandardCharsets
    + S8200355: local variable inference regression test generates
    classfile in test folder
    + S8200357: Inline SoundLibraries.gmk into Lib-java.desktop.gmk
    + S8200409: jdk11 nightly solaris sparc build failure
    + S8200449: ReadAllReadNTransferTo fails occasionally
- Modified patch:
  * system-pcsclite.patch
    + Rediff to changed context
* Fri Mar 23 2018 fstrba@suse.com
- Update to upstream tag jdk-11+6
  * Fixes:
    + S8186228: sun/security/krb5/auto/KdcPolicy.java fails with
    "java.lang.Exception: Does not match. Output is
    c30000c30000c30000"
    + S8193033: remove terminally deprecated
    sun.misc.Unsafe.defineClass
    + S8196298: Add null Reader and Writer
    + S8199437: Improve diagnostic system assertion message in
    com.sun.net.httpserver impl
    + S8199682: Clean up building the saproc library
    + S8199749: Debug symbols are not copied to exploded image on
    Mac
    + S8199768: jdk/test/lib/compiler/CompilerUtils.java needs to
    provide more control over compilation
    + S8199792: Wrong license header in XMLLimitAnalyzer.java
    + S8199858: solaris-x86_64 : unpack200 fails linking with SS12u4
    + S8199862: Examine ProxyBuilder::referencedTypes startup cost
    + S8199865: Avoid initializing ShortCache in ProxyGenerator
    + S8199869: Missing copyright headers in nashorn source code
    + S8199884: JDK-8199749 broke build with make 3.81
* Tue Mar 20 2018 fstrba@suse.com
- Update to upstream tag jdk-11+5
  * Fixes:
    + S8160767: [TEST_BUG]
    java/awt/Frame/MaximizedToIconified/MaximizedToIconified.java
    + S8182684: Further clarify InputStream#available()
    + S8183554: Add constructors with Charset parameter for
    FileReader and FileWriter
    + S8187635: On Windows Swing changes keyboard layout on a
    window activation
    + S8188240: Reflection Proxy should skip static methods
    + S8189230: JDK method:
    java.lang.Integer.numberOfLeadingZeros(int) can be optimized
    + S8190347: [TESTBUG] Test javax/swing/JWindow/
    /ShapedAndTranslucentWindows/TranslucentJComboBox.java fails
    + S8190767: if JFrame is maximized on OS X, all new JFrames
    will be maximized by default
    + S8193017: Import freetype sources into OpenJDK source tree
    + S8193584: (testbug) TestSocketFactory fails intermittently
    with ConcurrentModificationException
    + S8194767: Regression automated Test
    'javax/swing/JEditorPane/6917744/bug6917744.java' fails
    + S8194943: Regression automated test 'open/test/jdk/javax/
    /swing/JInternalFrame/8020708/bug8020708.java' fails
    + S8195738: scroll poistion in ScrollPane is reset after
    calling validate()
    + S8196435: Regression automated Test 'java/awt/Mouse/
    /GetMousePositionTest/GetMousePositionWithOverlay.java' fails
    + S8196748: tools/jar tests need to tolerate unrelated warnings
    + S8197785: javax.accessibility.AccessibleBundle will reload
    the ResourceBundle for every call to toDisplayString
    + S8198406: Test TestAATMorxFont is unstable
    + S8198605: Touch keyboard is shown for a non-focusable text
    component
    + S8198606: Touch keyboard does not hide, when a text component
    looses focus
    + S8198613: Test cases result in failure or timeout when run
    with OpenGL backend
    + S8198777: JList.getPreferredScrollableViewportSize(): fix
    mistake in doc for height calc
    + S8198889: Clarify the throwing of exceptions from
    ConstantBootstraps.invoke
    + S8198922: Provide instrumentation for
    sanity/client/SwingSet/src/ButtonDemoScreenshotTest.java
    + S8198989: Provide more diagnostic IAE messages
    + S8199009: test/jdk/java/util/Locale/SoftKeys.java fails with
    OutOfMemoryError
    + S8199022: New failures should be added to ProblemList
    + S8199215: Re-examine getFreePort method in test
    infrastructure library
    + S8199258: BigInteger.bitLength() should explicitly specify
    behavior when the value is zero
    + S8199329: Remove code that attempts to read bytes after
    connection reset reported
    + S8199420: Update javadoc tags in java.lang.System and related
    + S8199423: Create builds-infra Mach5 job
    + S8199428: install-file macro fails on filenames with space on
    Solaris
    + S8199443: Nashorn multithread bottleneck with "use strict"
    + S8199451: Create linux-aarch64 cross-compilation devkit, and
    fix cross-compilation
    + S8199453: Enable link-time generation of constructor forms
    + S8199462: Use Reference.reachabilityFence in direct
    ByteBuffer methods
    + S8199464: Remove remaining vestiges of
    Java_sun_reflect_Reflection_getCallerClass
    + S8199469: Disable generate-jli-classes when building
    interim-image
    + S8199470: Remove unused property file.encoding.pkg
    + S8199471: Enable generation of callSiteForms at link time
    + S8199473: Support Visual Studio BuildTools with VS2017
    + S8199483: Clean up some non-standard LDFLAGS usage
    + S8199606: Set -lc as global LIBS on solstudio
    + S8199611: (se) Minor selector implementation clean-up
    + S8199616: Fix @module declarations in tier1 tests
    + S8199636: Unify naming for jaas_unix and jaas_nt
    + S8199639: Introduce SetupJdkLibrary and SetupJdkExecutable
    + S8199640: Split up BUILD_LIBKRB5 into the two, unrelated
    compilations it consists of
    + S8199647: java/util/Locale/SoftKeys.java fails with
    OutOfMemoryError again
    + S8199668: make/lib cleanup
    + S8199681: Remove boilerplate code from creating native jtreg
    tests
    + S8199745: JDK-8199668 introduced a build race on macosx
- Modified patches:
  * system-pcsclite.patch
  * java10-improved-fonts.patch -> java11-improved-fonts.patch
    + Rediff to changed context
* Tue Mar 13 2018 fstrba@suse.com
- Update to upstream tag jdk-11+4
  * Fixes:
    + S4993841: (str) java.lang.Character should have a
    toString(int) method
    + S5076761: JList.setSelectedValue(null, ...) doesn't do
    anything
    + S6372077: JarFile.getManifest() should handle manifest
    attribute name 70 bytes
    + S8041626: Shutdown tracing event
    + S8129569: [TEST_BUG] Test java/awt/Frame/
    /MaximizedToUnmaximized/MaximizedToUnmaximized.java fails
    + S8137326: Methods for comparing CharSequence, StringBuilder,
    and StringBuffer
    + S8148871: Possible wrong expression stack depth at deopt point
    + S8153945: Track if log configuration has changed during
    runtime
    + S8168722: Unified Logging configuration output needs
    simplifying
    + S8169358: httpserver does not close connections when
    RejectedExecutionException occurs
    + S8170976: [TESTBUG] LogTestFixture does not restore previous
    logging state
    + S8171000: Robot.createScreenCapture() crashes in wayland mode
    + S8182765: HTML5 must be the default javadoc codegen mode in
    the near future
    + S8186513: [TESTBUG] javax/swing/JInternalFrame/8160248/
    /JInternalFrameDraggingTest.java
    + S8187066: -Xlog:help "=debug" example is not quite accurate
    + S8187653: Lock in CoderResult.Cache becomes performance
    bottleneck
    + S8187950: javax.lang.model APIs throws CompletionFailure or a
    subtype of CompletionFailure.
    + S8190346: improve unified JVM logging help message and
    warnings
    + S8190679: java/util/Arrays/TimSortStackSize2.java fails with
    "Initial heap size set to a larger value than the maximum heap
    size"
    + S8191139: Remove deprecated javax.security.auth.Policy API
    + S8191369: NMT: Enhance thread stack tracking
    + S8191421: Deprecate PrintSafepointStatistics,
    PrintSafepointStatisticsTimeout and
    PrintSafepointStatisticsCount options
    + S8193262: JNI array not released in libsunmscapi
    convertToLittleEndian
    + S8193660: Check SOURCE line in "release" file for closedjdk
    + S8194085: Obsolete the deprecated SafepointSynchronize flags
    and remove related code
    + S8194296: Check copyright of files in make/langtools/tools
    + S8194870: Some regression tests throw NPE exception on a
    specific Solaris 11.2 sun4v sparc machine
    + S8195065: runtime/appcds/ProhibitedPackage.java intermittent
    failure
    + S8195131: Dead code removal for changes present in JDK-8176795
    + S8195142: Refactor out card table from CardTableModRefBS to
    flatten the BarrierSet hierarchy
    + S8195632: [Graal] Introduce EagerJVMCI flag to force eager
    JVMCI initialization
    + S8196064: AArch64: Merging ld/st into ldp/stp in
    macro-assembler
    + S8196133: JShell crashes when attempting to use bad source
    file in class path
    + S8196196: Headful tests should not be run in headless mode
    + S8196322: [macosx] When the screen menu bar is used, clearing
    the default menu bar should permit AWT shutdown
    + S8196338: [TEST_BUG] sanity/client/SwingSet/src/
    /TextFieldDemoTest.java Failed with timeout
    + S8196868: AARCH64: ld/st instructions hit guarantee assert
    while using sp
    + S8196882: VS2017 Hotspot Defined vsnprintf Function Causes
    C2084 Already Defined Compilation Error
    + S8197408: Bad pointer comparison and small cleanup in
    os_linux.cpp
    + S8197453: Add support of extra problem list
    + S8197482: Make Jemmy ComponentChooser lambda friendly
    + S8197499: RepaintManager does not increase double buffer
    after attaching a device with higher resolution
    + S8197533: Move javax.transaction.xa  to its own module
    + S8197538: Remove mention of hotjava paths in MimeTable.java
    + S8197546: Fix for 8171000 breaks Solaris + Linux builds
    + S8197549: Implement a new method similar to waitState() on
    Operator which run the check on event queue
    + S8197594: String#repeat
    + S8197808: Test java/awt/Dialog/MakeWindowAlwaysOnTop/
    /MakeWindowAlwaysOnTop.java fails on Windows
    + S8197841: Remove unused function Universe::create_heap_ext
    + S8197864: VS2017 (C4334) Result of 32-bit Shift Implicitly
    Converted to 64 bits
    + S8197926: java/awt/dnd/ImageTransferTest/ImageTransferTest.java
    doesnt close the windows in HiDPI setting
    + S8198004: javax/swing/JFileChooser/6868611/bug6868611.java
    throws error
    + S8198005: javax/swing/JFileChooser/7199708/bug7199708.java
    throws error
    + S8198252: Null pointer dereference in fold_compares_helper
    + S8198253: ThreadInfo.from(CompositeData) incorrectly accepts
    CompositeData with missing JDK 6 attributes
    + S8198293: AARCH64 - Add CPU detection code for Cavium Thunder
    X2
    + S8198302: VS2017 (C4477) java.base/windows/native/libnet/
    /NetworkInterface_winXP.c incorrect printf format strings
    + S8198304: VS2017 (C4838, C4312) Various conversion issues
    with gtest tests
    + S8198312: VS2017: Upgrade HOTSPOT_BUILD_COMPILER in
    vm_version.cpp
    + S8198333: ProblemList should be updated for headless mode
    + S8198474: Move JNIHandles::resolve into jniHandles.inline.hpp
    + S8198554: Add fuzzy matching for log levels and tags when
    parsing -Xlog
    + S8198628: further simplifications to lambda classification at
    JavacParser
    + S8198640: VS2017 (LNK4281) Link Warning Against Missed ASLR
    Optimization
    + S8198693: Update ProblemsList for mac
    + S8198697: Simplify initialization of platform encoding
    + S8198703: Missing #include "gc/shared/cardTableModRefBS.hpp"
    in graphKit.hpp
    + S8198724: Refactor FLAGS handling in configure
    + S8198750: [s390+x86_32+aarch64] Fix build after jdk-8195142
    + S8198810: URLClassLoader does not specify behavior when URL
    array contains null
    + S8198821: fix test methods access for test
    java/text/Normalizer/NormalizerAPITest.java
    + S8198825: Resolve missing review feedback for JDK-8170976
    + S8198833: TestMemoryAwareness Docker container fails with too
    small maximum heap
    + S8198834: (ch) Enable java/nio/channels/spi/SelectorProvider/
    /inheritedChannel/InheritedChannelTest.java on linux-x64
    + S8198841: Thread.interrupt should set interrupt status while
    holding blockerLock
    + S8198844: Clean up GensrcX11Wrappers
    + S8198859: Use elfedit to silence linker warnings on solaris
    + S8198862: Stop doing funky compilation stuff for dtrace
    + S8198887: JDK-8168722 broke the build on macosx
    + S8198888: Reduce string allocation churn in
    InvokerBytecodeGenerator
    + S8198898: Compilation errors in jdk.crypto.mscapi with VS 2017
    + S8198899: Compilation errors in java.prefs with VS 2017
    + S8198928: (so) SocketChannel connect may deadlock if closed
    at around same time that connect fails
    + S8198931: remove java.xml.bind module dependency for
    com/sun/jndi tests
    + S8198933: Update JDI tests to pass valid URL[]
    + S8198955: String#repeat loop optimization
    + S8198966: To make CoderResult.Cache.cache final and allocate
    it eagerly
    + S8198970: jnu_util.c compilation error on Solaris
    + S8199015: (se) SocketChannelImpl.translateXXXOps access
    channel state without synchronization
    + S8199018: Test crypto provider not registering
    + S8199052: Configure broken on aarch64
    + S8199103: Can't use COMPARE_BUILD with PATCH from custom root
    + S8199118: Filtering of filename for microsoft CL broken on
    newer Cygwin
    + S8199120: (so) SocketChannelImpl read/write don't need
    stateLock when channel is configured non-blocking
    + S8199125: --disable-warnings-as-errors does not work for
    native jtreg test code
    + S8199152: Configure broken on arm32
    + S8199154: Accessibility issues in jdk.security.auth
    + S8199197: Set _NT_SYMBOL_PATH when running tests on windows
    + S8199198: Remove unused functions in jdk.crypto.mscapi native
    code
    + S8199224: Refactor add_native_source in SetupNativeCompilation
    + S8199236: Nashorn uses deprecated HTML tags in Javadoc
    + S8199266: Update boot and build jdk requirements in configure
    + S8199327: nuke var type name after a lambda has been accepted
    + S8199331: Don't limit debug information for fastdebug JDK
    native libraries
    + S8199338: Use -g0 on solstudio also for compiling C programs
    + S8199339: JDK-8198859 broke solaris x64
    + S8199347: Always use -Z7 for debug symbols when compiling on
    Windows
    + S8199352: The Jib artifact resolver in test lib needs to
    print better error messages
    + S8199403: Require binutils 2.18 or newer
    + S8199405: Bump lowest supported gcc to 4.8
    + S8199416: Remove debug output left over since JDK-8198844
- Removed patches:
  * sorted-diff.patch
    + context changed completely
  * jdk10-gcc6.patch
    + not needed
  * boot_jdk_version.patch
    + correct boot versions handled upsteam
- Changed patch:
  * java10-improved-fonts.patch
    + rediffed to changed context
* Fri Mar  2 2018 fstrba@suse.com
- Update to upstream tag jdk-11+3
  * Fixes:
    + S4916621: Update those still using JDIScaffold to use
    TestScaffold instead.
    + S7127700: G1: Replace G1PLAB with PLAB
    + S8038043: Xerces Update: XInclude update
    + S8060094: java/util/Formatter/Basic.java failed in tr locale
    + S8068593: Remove or repurpose unused PerfCounters from
    objectMonitor
    + S8165929: Constify arguments of Copy methods
    + S8166232: jshell tool: cannot access previous history
    + S8175384: SA: clhsdb 'printall' throws ClassCastException
    while printing out the bytecodes
    + S8176298: Log tags in -Xlog:help not sorted
    + S8179249: Improve process output analysis in CDS tests
    + S8182847: Copy class should use assert macros
    + S8184289: Obsolete -XX:+UnsyncloadClass and
  - XX:+MustCallLoadClassInternal options
    + S8186211: Negative tests for CONSTANT_Dynamic
    + S8186688: javax.lang.model.util.Elements.hides does not work
    correctly with interfaces
    + S8189330: Cleanup FileDescriptor implementation
    + S8190428: Minimal Dynamic Constant support for AArch64
    + S8191375: Add high-level jtreg VMProps to filter out CDS tests
    + S8193056: Title from build failure with Xcode 9.1
    + S8193150: Create a jtreg version of the test from JDK-8187143.
    + S8193373: Cleanup ElfFile and family
    + S8193846: Obsolete the VM option UseUTCFileTimestamp
    + S8193892: Impact of noncloneable MessageDigest implementation
    + S8193909: Obsolete(remove) Co-operative Memory Management (CMM)
    + S8194084: Obsolete FastTLABRefill and remove the related code
    + S8194691: Cleanup unnecessary casts in Atomic/OrderAccess uses
    + S8194994: Remove redundant string streams used for logging
    + S8195103: Refactor out card table from CardTableModRefBS to
    flatten the BarrierSet hierarchy
    + S8195112: x86 (32 bit): implementation for Thread-local
    handshakes
    + S8196308: Update tests AllLineLocations and ClassesByName to
    use TestScaffold instead of JDIScaffold.
    + S8196324: Update tests FilterMatch and FilterNoMatch to use
    TestScaffold.
    + S8196405: [REDO] NMT: add_committed_regions doesn't merge
    succeeding regions
    + S8196602: Change HeapRegionClosure to comply to naming
    conventions
    + S8196759: Move two java/text/Normalizer tests into OpenJDK
    + S8196783: Refactor LogTagLevelExpression into separate classes
    + S8196786: [PPC64+s390] ConstantDynamic support
    + S8196830: publicLookup().findVirtual should not return method
    handle to AccessibleObject.setAccessible
    + S8196880: VS2017 Addition of Global Delete Operator with Size
    Parameter Conflicts with Arena's Chunk Provided One
    + S8196884: VS2017 Multiple Type Cast Conversion Compilation
    Errors
    + S8196889: VS2017 Unable to Instantiate
    OrderAccess::release_store with an Incomplete Class Within an
    Inlined Method
    + S8196909: gcc 7.2.1 compiler warning in libdt_socket
    + S8196920: VerifierTest_1A.java and VerifierTest_1B.java fail:
    assert(receiver_klass->is_subtype_of(static_receiver_klass))
    failed: actual receiver must be subclass of static receiver
    klass
    + S8196930: [Testbug] serviceability/sa/ClhsdbFindPC.java fails
    to find expected output
    + S8196992: Resolve disabled warnings for libdt_socket
    + S8196997: VS2017 The non-Standard std::tr1 namespace and
    TR1-only machinery are deprecated and will be removed
    + S8197412: Enable docker container related tests for linux
    s390x
    + S8197454: Need Access decorator for storing oop into
    uninitialized location
    + S8197518: Kerberos krb5 authentication: AuthList's put method
    leads to performance issue
    + S8197563: assert(is_Loop()) crash in
    PhaseIdealLoop::try_move_store_before_loop()
    + S8197572: s390 build broken after 8165929
    + S8197589: Update CPU count algorithm when both cpu shares and
    quotas are used
    + S8197608: MacroAssembler::unimplemented calls global operator
    new[]
    + S8197772: metaspace uses global operator new/delete for gtest
    testing
    + S8197780: Null pointer dereference in
    Klass::is_instance_klass of klass.hpp:532
    + S8197789: os::SuspendedThreadTask causes references to global
    operator delete
    + S8197827: [windows] Small cleanups after JDK-8185712
    + S8197828: Null pointer dereference in
    MultiNode::proj_out_or_null
    + S8197857: fieldDescriptor prints incorrect 32-bit
    representation of compressed oops
    + S8197859: VS2017 Complains about UINTPTR_MAX definition in
    globalDefinitions_VisCPP.hpp
    + S8197868: VS2017 (C2065) 'timezone': Undeclared Identifier in
    share/runtime/os.cpp
    + S8197901: Crash during GC when logging level is debug
    + S8197906: Enable CDS mode execution of jtreg tests via make
    + S8197945: Qurarantine failing condy tests
    + S8197956: VS2017 (C4838) Narrowing conversion required from
    __int64 to julong
    + S8197968: [Backout] JDK-8196883
    G1RemSet::refine_card_concurrently doesn't need to check for
    cards in collection set
    + S8197992: Move the OopStorage::ParState type out of inline.hpp
    + S8197993: Remove last use of
    JavaThread::flush_barrier_queues()
    + S8197994: Move JavaThread::initialize_queues() logic to
    G1SATBCardTableLoggingModRefBS
    + S8197999: Accessors in typeArrayOopDesc should use new Access
    API
    + S8198225: os::attempt_reserve_memory_at records memory as
    committed
    + S8198249: Remove deprecated Runtime::runFinalizersOnExit and
    System::runFinalizersOnExit
    + S8198251: [Graal] compiler/intrinsics/bmi/verifycode tests
    fail with Graal on macos
    + S8198265: Make
    CollectorPolicy::satisfy_failed_metadata_allocation() virtual
    + S8198267: Allow GCId::current_raw() calls from
    non-NamedThreads
    + S8198268: Add time argument to
    ConcurrentGCTimer::register_gc_pause_start/_end
    + S8198269: Allow GCCauseSetter to be used outside of safepoints
    + S8198270: Remove dangerous assert in HandleArea::oops_do()
    + S8198271: Make CollectedHeap::create_heap_space_summary()
    virtual
    + S8198275: AIX build broken after latest whitebox.cpp changes
    + S8198286: Direct memory accessors in typeArrayOop.hpp should
    use Access API
    + S8198287: Cleanup ElfFile usage in whitebox.cpp
    + S8198311: Avoid uses of global malloc and free
    + S8198341: Build failures after 8194084 (Obsolete
    FastTLABRefill and remove the related code)
    + S8198369: Clean up GCId and GCIdMark
    + S8198373: Remove CollectorPolicy::is/as functions
    + S8198375: Passing 'null' value to lookup param of
    ConstantBootstraps.invoke does not throw NullPointerException
    + S8198420: Remove unused extension point AllocationContextStats
    + S8198439: Fix aarch64 code for handling generate_code_for
    after FastTLABFill obsolete code
    + S8198480: Improve ClassLoaders static init block
    + S8198481: Coding style cleanups for
    src/java.base/share/classes/jdk/internal/loader
    + S8198482: The URLClassPath field "urls" should be renamed to
    "unopenedUrls"
    + S8198484: URLClassPath should use an ArrayDeque instead of a
    Stack
    + S8198485: Simplify a URLClassPath constructor
    + S8198490: java/util/logging/TestLogConfigurationDeadLock.java
    timed out.
    + S8198492: Bootstrapping java.lang.invoke can cause deadlock
    after JDK-8198418
    + S8198507: Remove CollectorPolicy::create_rem_set
    + S8198509: Move satisfy_failed_metadata_allocation out from
    CollectorPolicy
    + S8198511: Move allocation functions from GenCollectorPolicy
    to GenCollectedHeap
    + S8198515: Extract SoftReferencePolicy code out of
    CollectorPolicy
    + S8198522: Javadoc search broken after output files
    organization for modules
    + S8198525: Move _size_policy out of GenCollectorPolicy into
    GenCollectedHeap
    + S8198528: Move GenerationSpecs from GenCollectorPolicy to
    GenCollectedHeap
    + S8198530: Move _gc_policy_counters from GenCollectorPolicy to
    GenCollectedHeap
    + S8198533: Remove obsolete JDIScaffold class from repo.
    + S8198539: Cleanup of unused imports in
    java/util/jar/Attributes.java (java.base) and
    JdpController.java (jdk.management.agent)
    + S8198551: Rename hotspot_tier1 test group to tier1
    + S8198553: jcmd: separate Metaspace statistics from NMT
    + S8198558: Windows does not build without precompiled headers
    + S8198560: Remove implicit casts from oop to JavaThread* and
    jlong*
    + S8198562: (ch) Separate blocking and non-blocking code paths
    (part 1)
    + S8198564: Multiple crashes on SPARC
    + S8198568: clean up test/hotspot/jtreg/ProblemList.txt
    + S8198569: SetupTextFileProcessing should use sed with 'g'
    + S8198573: JShell: class replace loses instances
    + S8198585: add asserts to verify that ServiceUtil::visible_oop
    is not needed
    + S8198627: JDK-8198318 broke readlink testing
    + S8198635: Remove unused safepoint message functions and
    ShowSafepointMsgs
    + S8198645: Use System.lineSeparator() instead of
    getProperty("line.separator")
    + S8198653: ClassLoader::getSystemClassLoader throws
    InternalError when called after shutdown
    + S8198656: Update copyright to 2018
    + S8198658: Docs still point to JDK 9 docs
    + S8198670: [testbug] Test
    jdk/internal/jline/extra/HistoryTest.java is broken after
    8166232
    + S8198726: Quarantine SADebugDTest.java again
    + S8198751: Refactor SetupNativeCompilation to take NAME and
    TYPE
    + S8198754: (ch) Separate blocking and non-blocking code paths
    (part 2)
    + S8198755: Reduce cost of
    InvokerBytecodeGenerator::isStaticallyInvocable/-Nameable
    + S8198808: jdi tests failing after JDK-8198484
    + S8198820: Problem list tools/jimage/JImageExtractTest.java
    + S8198831: Lazy initialization of ValueConversions
    MethodHandles
- Modified patch:
  * system-pcsclite.patch
    + Fix merge error in the patch
* Mon Feb 26 2018 fstrba@suse.com
- Update to upstream tag jdk-11+2
  * Fixes:
    + S8058965: Remove IPv6 support from TwoStacksPlainSocketImpl
    [win]
    + S8153294: Solaris devkit uses linker from system instead of
    in devkit
    + S8170120: jimage throws IOException when the given file is
    not a jimage file
    + S8176474: test/jdk/jshell/JdiBogusHostListenExecutionControlTest.java
    fails with java.net.BindException
    + S8190904: Incorrect currency instance returned by
    java.util.Currency.getInstance()
    + S8194154: System property user.dir should not be changed
    + S8194892: add compiler support for local-variable syntax for
    lambda parameters
    + S8194922: jlink --exclude-resources should never exclude
    module-info.class
    + S8196959: NullPointerException in discovery003.java
    + S8197439: Crash with -XDfind=lambda for anonymous class in
    anonymous class.
    + S8197812: (ref) Data race in Finalizer
    + S8198227: Fix COMPARE_BUILD after forest consolidation
    + S8198228: Spec clarification: j.u.Locale.getDisplayName()
    + S8198301: jdk11+1 was built as 'fcs' instead of 'ea'
    + S8198303: jdk11+1 was build with incorrect GA date as
    2018-03-20
    + S8198306: Add post custom extension hooks to two launchers
    + S8198318: Make build comparisons clean again
    + S8198328: Create devkit for Solaris with developer studio
    12.6 and Solaris11.3
    + S8198379: tools/jimage/JImageListTest.java failing
    + S8198380: tools/jimage/JImageExtractTest.java failing
    + S8198385: Remove property sun.locale.formatasdefault
    + S8198417: Exclude tools/jimage/JImageExtractTest.java and
    tools/jimage/JImageListTest.java on Windows
    + S8198418: Invoke LambdaMetafactory::metafactory exactly from
    the BootstrapMethodInvoker
    + S8198425: make/Main.gmk Add extra extension/override points
    to the make file
    + S8198441: Replace native Runtime::runFinalization0 method
    with shared secrets
    + S8198450: Make jdk.internal.vm.compiler/module-info.java.extra
    reproducable
    + S8198479: JDK build is broken by 8194892
    + S8198502: Exception at runtime due to lambda analyzer
    reattributes live AST
    + S8198512: compiler support for local-variable syntax for
    lambda parameters
    + S8198523: Refactor BootstrapMethodInvoker to further avoid
    runtime type checks
    + S8198563: Test langtools/tools/javac/analyzer/AnonymousInAnonymous.java
    failing after JDK-8198502
* Mon Feb 19 2018 fstrba@suse.com
- Update to upstream tag jdk-11+1
- Removed patches:
  * JDK-8194739-zero.patch
  * aarch64-form_address.patch
    + Integrated upstream
- Modified patch:
  * system-pcsclite.patch
    + Rediff to changed context
* Mon Jan 29 2018 fstrba@suse.com
- Added patch:
  * aarch64-form_address.patch
  - Fix crash due to mistake in committed patch for JDK-8195859
* Fri Jan 26 2018 fstrba@suse.com
- Upgrade to the tip of jdk repository of January 26th, 2018
- Modified patches:
  * disable-doclint-by-default.patch
  * jdk10-gcc6.patch
    + Rediffed to a changed context
- Removed patches:
  * java-10-openjdk-linuxfilestore.patch
  * remove_javah_for_real.patch
    + Integrated upstream
- Added patch:
  * JDK-8194739-zero.patch
    + S8194739: Zero port of 8174962: Better interface invocations
* Tue Jan 16 2018 fstrba@suse.com
- Recommend tzdata-java8 instead of depending on it. This fixes
  build cycles.
* Fri Dec 15 2017 fstrba@suse.com
- Initial package of jdk-11+0
  * java-11-openjdk technology preview
